@@ -235,7 +235,7 @@ double Fgetlag(
 	int count, count0;
 	int len1, len2;
 	int totallen;
-	float dumfl = 0.0;
+	double dumdb = 0.0;
 	int headgp, tailgp;
 
 	len1 = strlen( seq1[0] );
@@ -714,7 +714,7 @@ system( "/usr/bin/gnuplot list.plot" );
 				if( clus1 == 1 && clus2 == 1 )
 					G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
 				else
-					A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, headgp, tailgp );
+					A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, headgp, tailgp );
 				break;
 			default:
 				fprintf( stderr, "alg = %c\n", alg );
@@ -763,7 +763,7 @@ system( "/usr/bin/gnuplot list.plot" );
 
 
 
-float Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicmtx,
+double Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicmtx,
 			  char  **seq1, char  **seq2, 
 			  double *eff1, double *eff2, 
 			  double **eff1s, double **eff2s,
@@ -809,8 +809,8 @@ float Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicm
 	int count, count0;
 	int len1, len2;
 	int totallen;
-	float totalscore;
-	float dumfl = 0.0;
+	double totalscore;
+	double dumdb = 0.0;
 	int headgp, tailgp;
 
 
@@ -1523,10 +1523,10 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 				{
 					if( scoringmatrices ) // called by tditeration.c
 					{
-						totalscore += A__align_variousdist( NULL, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+						totalscore += A__align_variousdist( NULL, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 					}
 					else
-						totalscore += A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+						totalscore += A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 				}
 				break;
 			default:
@@ -1597,7 +1597,7 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 /*
 sakujo wo kentou (2010/10/05)
 */
-float Falign_udpari_long( 
+double Falign_udpari_long( 
 			  double **offsetmtx, double ***scoringmatrices, 
 			  double **n_dynamicmtx,
 			  char  **seq1, char  **seq2, 
@@ -1644,10 +1644,10 @@ float Falign_udpari_long(
 	int count, count0;
 	int len1, len2;
 	int totallen;
-	float totalscore;
+	double totalscore;
 	int nkouho = 0;
 	int headgp, tailgp;
-//	float dumfl = 0.0;
+//	double dumfl = 0.0;
 
 	if( seq1 == NULL )
 	{
