@@ -6,7 +6,7 @@
 #define USE_PENALTY_EX  1
 
 #if 1
-static void match_calc_mtx( double **mtx, float *match, char **s1, char **s2, int i1, int lgth2 ) 
+static void match_calc_mtx( double **mtx, double *match, char **s1, char **s2, int i1, int lgth2 ) 
 {
 	char *seq2 = s2[0];
 	double *doubleptr = mtx[(int)s1[0][i1]];
@@ -15,7 +15,7 @@ static void match_calc_mtx( double **mtx, float *match, char **s1, char **s2, in
 		*match++ = doubleptr[(int)*seq2++];
 }
 #else
-static void match_calc( float *match, char **s1, char **s2, int i1, int lgth2 )
+static void match_calc( double *match, char **s1, char **s2, int i1, int lgth2 )
 {
 	int j;
 
@@ -24,7 +24,7 @@ static void match_calc( float *match, char **s1, char **s2, int i1, int lgth2 )
 }
 #endif
 
-static float Atracking( float *lasthorizontalw, float *lastverticalw, 
+static double Atracking( double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp,
@@ -37,7 +37,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 	gap = newgapstr;
 	lgth1 = strlen( seq1[0] );
 	lgth2 = strlen( seq2[0] );
-	float wm;
+	double wm;
 
 
 #if 0
@@ -162,7 +162,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 }
 
 
-float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen, int headgp, int tailgp )
+double G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen, int headgp, int tailgp )
 {
 //	int k;
 	register int i, j;
@@ -170,36 +170,36 @@ float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen,
 	int lastj;
 	int lgth1, lgth2;
 	int resultlen;
-	float wm;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
-	float fpenalty = (float)penalty;
-	float fpenalty_shift = (float)penalty_shift;
-	float fpenalty_tmp;
+	double wm;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
+	double fpenalty = (double)penalty;
+	double fpenalty_shift = (double)penalty_shift;
+	double fpenalty_tmp;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi = 0.0;
-	static TLS float *m = NULL;
+	static TLS double mi = 0.0;
+	static TLS double *m = NULL;
 	static TLS int **ijp = NULL;
 	static TLS int mpi = 0;
 	static TLS int *mp = NULL;
-	static TLS float *w1 = NULL;
-	static TLS float *w2 = NULL;
-	static TLS float *match = NULL;
-	static TLS float *initverticalw = NULL;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw = NULL;    /* kufuu sureba iranai */
+	static TLS double *w1 = NULL;
+	static TLS double *w2 = NULL;
+	static TLS double *match = NULL;
+	static TLS double *initverticalw = NULL;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw = NULL;    /* kufuu sureba iranai */
 	static TLS char **mseq1 = NULL;
 	static TLS char **mseq2 = NULL;
 	static TLS char **mseq = NULL;
 	static TLS int **intwork = NULL;
-	static TLS float **floatwork = NULL;
+	static TLS double **doublework = NULL;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
 	static TLS double **amino_dynamicmtx = NULL; // ??
 
@@ -209,12 +209,12 @@ float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen,
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
 
@@ -239,7 +239,7 @@ float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen,
 
 
 
-			if( floatwork ) FreeFloatMtx( floatwork ); floatwork = NULL;
+			if( doublework ) FreeFloatMtx( doublework ); doublework = NULL;
 			if( intwork ) FreeIntMtx( intwork ); intwork = NULL;
 
 			if( amino_dynamicmtx ) FreeDoubleMtx( amino_dynamicmtx ); amino_dynamicmtx = NULL;
@@ -339,7 +339,7 @@ float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen,
 
 
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 			FreeDoubleMtx( amino_dynamicmtx );
 		}
@@ -364,7 +364,7 @@ float G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen,
 		mseq = AllocateCharMtx( njob, ll1+ll2 );
 
 
-		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 		amino_dynamicmtx = AllocateDoubleMtx( 0x80, 0x80 );
 
@@ -684,7 +684,7 @@ fprintf( stderr, "\n" );
 	return( wm );
 }
 
-float G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char **seq1, char **seq2, int alloclen )
+double G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char **seq1, char **seq2, int alloclen )
 /* warp mitaiou */
 {
 //	int k;
@@ -692,25 +692,25 @@ float G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char *
 	int lasti;                      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 //	int resultlen;
-	float wm;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
-	float fpenalty = (float)penal;
+	double wm;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
+	double fpenalty = (double)penal;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penal_ex;
+	double fpenalty_ex = (double)penal_ex;
 #endif
 #if 1
-	float *wtmp;
-	float *mjpt, *prept, *curpt;
+	double *wtmp;
+	double *mjpt, *prept, *curpt;
 //	int *mpjpt;
 #endif
-	static TLS float mi, *m;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double mi, *m;
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS int **intwork;
-	static TLS float **floatwork;
+	static TLS double **doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
 	static TLS double **amino_dynamicmtx;
 
@@ -728,7 +728,7 @@ float G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char *
 			free( m );
 
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 			FreeDoubleMtx( amino_dynamicmtx );
 		}
@@ -769,7 +769,7 @@ float G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char *
 
 
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 
 			FreeDoubleMtx( amino_dynamicmtx );
@@ -793,7 +793,7 @@ float G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char *
 
 
 
-		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 
 
