@@ -10,7 +10,7 @@
 static TLS int localstop; // 060910
 
 #if 1
-static void match_calc_mtx( double **mtx, float *match, char **s1, char **s2, int i1, int lgth2 ) 
+static void match_calc_mtx( double **mtx, double *match, char **s1, char **s2, int i1, int lgth2 ) 
 {
 	char *seq2 = s2[0];
 	double *doubleptr = mtx[(int)s1[0][i1]];
@@ -19,7 +19,7 @@ static void match_calc_mtx( double **mtx, float *match, char **s1, char **s2, in
 		*match++ = doubleptr[(int)*seq2++];
 }
 #else
-static void match_calc( float *match, char **s1, char **s2, int i1, int lgth2 )
+static void match_calc( double *match, char **s1, char **s2, int i1, int lgth2 )
 {
 	int j;
 
@@ -29,11 +29,11 @@ static void match_calc( float *match, char **s1, char **s2, int i1, int lgth2 )
 #endif
 
 #if 0
-static void match_calc_bk( float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc_bk( double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 	int j, k, l;
-	float scarr[nalphabets];
-	float **cpmxpd = floatwork;
+	double scarr[nalphabets];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
 	int count = 0;
 
@@ -61,9 +61,9 @@ static void match_calc_bk( float *match, float **cpmx1, float **cpmx2, int i1, i
 		for( k=0; k<nalphabets; k++ )
 			scarr[l] += n_dis[k][l] * cpmx1[k][i1];
 	}
-#if 0 /* ȤȤfloatworkΥȤդˤ */
+#if 0 /* ȤȤdoubleworkΥȤդˤ */
 	{
-		float *fpt, **fptpt, *fpt2;
+		double *fpt, **fptpt, *fpt2;
 		int *ipt, **iptpt;
 		fpt2 = match;
 		iptpt = cpmxpdn;
@@ -88,7 +88,7 @@ static void match_calc_bk( float *match, float **cpmx1, float **cpmx2, int i1, i
 }
 #endif
 
-static float Ltracking( float *lasthorizontalw, float *lastverticalw, 
+static double Ltracking( double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int *off1pt, int *off2pt, int endi, int endj,
@@ -205,7 +205,7 @@ static float Ltracking( float *lasthorizontalw, float *lastverticalw,
 }
 
 
-float L__align11( double **n_dynamicmtx, float scoreoffset, char **seq1, char **seq2, int alloclen, int *off1pt, int *off2pt )
+double L__align11( double **n_dynamicmtx, double scoreoffset, char **seq1, char **seq2, int alloclen, int *off1pt, int *off2pt )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -213,40 +213,40 @@ float L__align11( double **n_dynamicmtx, float scoreoffset, char **seq1, char **
 	int lasti, lastj;                      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 	static TLS int **ijp;
 	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS char **mseq1;
 	static TLS char **mseq2;
 	static TLS char **mseq;
 //	static TLS int **intwork;
-//	static TLS float **floatwork;
+//	static TLS double **doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
 	static TLS double **amino_dynamicmtx = NULL; // ??
-	float maxwm;
+	double maxwm;
 	int endali = 0, endalj = 0; // by D.Mathog, a guess
 //	int endali, endalj;
-	float localthr = -offset + scoreoffset * 600; // 2013/12/13
-	float localthr2 = -offset + scoreoffset * 600; // 2013/12/13
-//	float localthr = -offset;
-//	float localthr2 = -offset;
-	float fpenalty = (float)penalty;
-	float fpenalty_ex = (float)penalty_ex;
-	float fpenalty_shift = (float)penalty_shift;
-	float fpenalty_tmp; // atode kesu
+	double localthr = -offset + scoreoffset * 600; // 2013/12/13
+	double localthr2 = -offset + scoreoffset * 600; // 2013/12/13
+//	double localthr = -offset;
+//	double localthr2 = -offset;
+	double fpenalty = (double)penalty;
+	double fpenalty_ex = (double)penalty_ex;
+	double fpenalty_shift = (double)penalty_shift;
+	double fpenalty_tmp; // atode kesu
 
 	int *warpis = NULL;
 	int *warpjs = NULL;
@@ -254,12 +254,12 @@ float L__align11( double **n_dynamicmtx, float scoreoffset, char **seq1, char **
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
 
@@ -340,7 +340,7 @@ float L__align11( double **n_dynamicmtx, float scoreoffset, char **seq1, char **
 			if( amino_dynamicmtx ) FreeDoubleMtx( amino_dynamicmtx ); amino_dynamicmtx = NULL;
 
 
-//			FreeFloatMtx( floatwork );
+//			FreeFloatMtx( doublework );
 //			FreeIntMtx( intwork );
 		}
 
@@ -364,7 +364,7 @@ float L__align11( double **n_dynamicmtx, float scoreoffset, char **seq1, char **
 		mseq = AllocateCharMtx( njob, ll1+ll2 );
 
 
-//		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+//		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 //		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 
 #if DEBUG
@@ -735,6 +735,8 @@ fprintf( stderr, "\n" );
 	fprintf( stderr, ">\n%s\n", mseq1[0] );
 	fprintf( stderr, ">\n%s\n", mseq2[0] );
 
+	fprintf( stderr, "*off1pt = %d, *off2pt = %d\n", *off1pt, *off2pt );
+
 	fprintf( stderr, "maxwm = %f\n", maxwm );
 	fprintf( stderr, "   wm = %f\n",    wm );
 #endif
@@ -743,7 +745,7 @@ fprintf( stderr, "\n" );
 }
 
 
-float L__align11_noalign( double **n_dynamicmtx, char **seq1, char **seq2 )
+double L__align11_noalign( double **n_dynamicmtx, char **seq1, char **seq2 )
 // warp mitaiou
 {
 //	int k;
@@ -751,38 +753,38 @@ float L__align11_noalign( double **n_dynamicmtx, char **seq1, char **seq2 )
 	int lasti, lastj;                      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 //	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if 1
-	float *wtmp;
+	double *wtmp;
 //	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 //	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 //	static TLS int **ijp;
 //	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 //	static TLS char **mseq1;
 //	static TLS char **mseq2;
 //	static TLS char **mseq;
 //	static TLS int **intwork;
-//	static TLS float **floatwork;
+//	static TLS double **doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
 	static TLS double **amino_dynamicmtx = NULL; // ??
-	float maxwm;
+	double maxwm;
 //	int endali = 0, endalj = 0; // by D.Mathog, a guess
 //	int endali, endalj;
-	float localthr = -offset;
-	float localthr2 = -offset;
-//	float localthr = 100;
-//	float localthr2 = 100;
-	float fpenalty = (float)penalty;
-	float fpenalty_ex = (float)penalty_ex;
+	double localthr = -offset;
+	double localthr2 = -offset;
+//	double localthr = 100;
+//	double localthr2 = 100;
+	double fpenalty = (double)penalty;
+	double fpenalty_ex = (double)penalty_ex;
 
 	if( seq1 == NULL )
 	{
@@ -838,7 +840,7 @@ float L__align11_noalign( double **n_dynamicmtx, char **seq1, char **seq2 )
 
 
 
-//			FreeFloatMtx( floatwork );
+//			FreeFloatMtx( doublework );
 //			FreeIntMtx( intwork );
 			if( amino_dynamicmtx ) FreeDoubleMtx( amino_dynamicmtx ); amino_dynamicmtx = NULL;
 		}
@@ -863,7 +865,7 @@ float L__align11_noalign( double **n_dynamicmtx, char **seq1, char **seq2 )
 //		mseq = AllocateCharMtx( njob, ll1+ll2 );
 
 
-//		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+//		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 //		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 
 #if DEBUG
