@@ -10,32 +10,34 @@
 #define MCD 0
 
 
-static TLS float **impmtx = NULL;
+static TLS double **impmtx = NULL;
 static TLS int impalloclen = 0;
-float imp_match_out_sc( int i1, int j1 )
+double imp_match_out_sc( int i1, int j1 )
 {
 //	fprintf( stderr, "imp+match = %f\n", impmtx[i1][j1] * fastathreshold );
 //	fprintf( stderr, "val = %f\n", impmtx[i1][j1] );
 	return( impmtx[i1][j1] );
 }
 
-static void imp_match_out_vead_gapmap( float *imp, int i1, int lgth2, int *gapmap2 )
+#if 0
+static void imp_match_out_vead_gapmap( double *imp, int i1, int lgth2, int *gapmap2 )
 {
 #if FASTMATCHCALC
-	float *pt = impmtx[i1];
+	double *pt = impmtx[i1];
 	int *gapmappt = gapmap2;
 	while( lgth2-- )
 		*imp++ += pt[*gapmappt++];
 #else
 	int j;
-	float *pt = impmtx[i1];
+	double *pt = impmtx[i1];
 	for( j=0; j<lgth2; j++ )
 		*imp++ += pt[gapmap2[j]];
 #endif
 }
 
 
-static void imp_match_out_vead_tate_gapmap( float *imp, int j1, int lgth1, int *gapmap1 )
+
+static void imp_match_out_vead_tate_gapmap( double *imp, int j1, int lgth1, int *gapmap1 )
 {
 #if FASTMATCHCALC
 	int *gapmappt = gapmap1;
@@ -47,21 +49,24 @@ static void imp_match_out_vead_tate_gapmap( float *imp, int j1, int lgth1, int *
 		*imp++ += impmtx[gapmap1[i]][j1];
 #endif
 }
+#endif
 
-static void imp_match_out_vead( float *imp, int i1, int lgth2 )
+static void imp_match_out_vead( double *imp, int i1, int lgth2 )
 {
 #if FASTMATCHCALC 
-	float *pt = impmtx[i1];
+	double *pt = impmtx[i1];
 	while( lgth2-- )
 		*imp++ += *pt++;
 #else
 	int j;
-	float *pt = impmtx[i1];
+	double *pt = impmtx[i1];
 	for( j=0; j<lgth2; j++ )
 		*imp++ += pt[j];
 #endif
 }
-static void imp_match_out_vead_tate( float *imp, int j1, int lgth1 )
+
+
+static void imp_match_out_vead_tate( double *imp, int j1, int lgth1 )
 {
 	int i;
 	for( i=0; i<lgth1; i++ )
@@ -73,11 +78,11 @@ void imp_rna( int nseq1, int nseq2, char **seq1, char **seq2, double *eff1, doub
 	foldrna( nseq1, nseq2, seq1, seq2, eff1, eff2, grouprna1, grouprna2, impmtx, gapmap1, gapmap2, pair );
 }
 
-void imp_match_init_strict( float *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, double *eff1_kozo, double *eff2_kozo, LocalHom ***localhom, int forscore )
+void imp_match_init_strict( double *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, double *eff1_kozo, double *eff2_kozo, LocalHom ***localhom, int forscore )
 {
 	int i, j, k1, k2, tmpint, start1, start2, end1, end2;
-	float effij;
-	float effij_kozo;
+	double effij;
+	double effij_kozo;
 	double effijx;
 	char *pt, *pt1, *pt2;
 	static TLS char *nocount1 = NULL;
@@ -147,8 +152,8 @@ for( i = 0; i<impalloclen; i++ )
 	{
 		for( j=0; j<clus2; j++ )
 		{
-			effij = (float)( eff1[i] * eff2[j] * effijx );
-			effij_kozo = (float)( eff1_kozo[i] * eff2_kozo[j] * effijx );
+			effij = (double)( eff1[i] * eff2[j] * effijx );
+			effij_kozo = (double)( eff1_kozo[i] * eff2_kozo[j] * effijx );
 			tmpptr = localhom[i][j];
 			while( tmpptr )
 			{
@@ -305,7 +310,7 @@ for( i = 0; i<impalloclen; i++ )
 }
 
 #if 0
-void imp_match_init( float *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, LocalHom ***localhom )
+void imp_match_init( double *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, LocalHom ***localhom )
 {
 	int dif, i, j, k1, k2, tmpint, start1, start2, end1, end2;
 	static TLS int impalloclen = 0;
@@ -458,7 +463,7 @@ for( i = 0; i<impalloclen; i++ )
 #endif
 
 #if MCD
-static void match_calc_dynamicmtx( double **pairoffset, double **n_dynamicmtx, float *match, int n1, char **seq1, double *eff1, int n2, char **seq2, double *eff2, int i1, int lgth2, float **floatwork, int **intwork, int initialize, int flip ) 
+static void match_calc_dynamicmtx( double **pairoffset, double **n_dynamicmtx, double *match, int n1, char **seq1, double *eff1, int n2, char **seq2, double *eff2, int i1, int lgth2, double **doublework, int **intwork, int initialize, int flip ) 
 {
 // osoi!
 	int i, j, k;
@@ -493,23 +498,23 @@ static void match_calc_dynamicmtx( double **pairoffset, double **n_dynamicmtx, f
 }
 #endif
 
-static void fillzero( float *s, int l )
+static void fillzero( double *s, int l )
 {
 	while( l-- ) *s++ = 0.0;
 }
 
-static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc_add( double **scoreingmtx, double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 #if FASTMATCHCALC
 //	fprintf( stderr, "\nmatch_calc... %d", i1 );
 	int j, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *matchpt, *cpmxpdpt, **cpmxpdptpt;
+	double *matchpt, *cpmxpdpt, **cpmxpdptpt;
 	int *cpmxpdnpt, **cpmxpdnptpt;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 	if( initialize )
 	{
 		int count = 0;
@@ -555,11 +560,11 @@ static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, f
 //	fprintf( stderr, "done\n" );
 #else
 	int j, k, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 // simple
 	if( initialize )
 	{
@@ -596,18 +601,18 @@ static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, f
 	free( scarr );
 #endif
 }
-static void match_calc( double **n_dynamicmtx, float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc( double **n_dynamicmtx, double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 #if FASTMATCHCALC
 //	fprintf( stderr, "\nmatch_calc... %d", i1 );
 	int j, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *matchpt, *cpmxpdpt, **cpmxpdptpt;
+	double *matchpt, *cpmxpdpt, **cpmxpdptpt;
 	int *cpmxpdnpt, **cpmxpdnptpt;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 	if( initialize )
 	{
 		int count = 0;
@@ -653,11 +658,11 @@ static void match_calc( double **n_dynamicmtx, float *match, float **cpmx1, floa
 //	fprintf( stderr, "done\n" );
 #else
 	int j, k, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 // simple
 	if( initialize )
 	{
@@ -695,14 +700,14 @@ static void match_calc( double **n_dynamicmtx, float *match, float **cpmx1, floa
 #endif
 }
 
-static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *lastverticalw, 
+static void Atracking_localhom( double *impwmpt, double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
 						int *warpis, int *warpjs, int warpbase )
 {
 	int i, j, l, iin, jin, ifi, jfi, lgth1, lgth2, k, limk;
-	float wm;
+	double wm;
 	char *gaptable1, *gt1bk;
 	char *gaptable2, *gt2bk;
 	lgth1 = strlen( seq1[0] );
@@ -816,7 +821,7 @@ static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *l
 			;
 		else
 		{
-			*impwmpt += imp_match_out_sc( iin, jin );
+			*impwmpt += (double)imp_match_out_sc( iin, jin );
 
 //		fprintf( stderr, "impwm = %f (iin=%d, jin=%d) seq1=%c, seq2=%c\n", *impwmpt, iin, jin, seq1[0][iin], seq2[0][jin] );
 		}
@@ -834,7 +839,7 @@ static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *l
 	free( gt2bk );
 }
 
-static float Atracking( float *lasthorizontalw, float *lastverticalw, 
+static double Atracking( double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
@@ -842,7 +847,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 						int *warpis, int *warpjs, int warpbase )
 {
 	int i, j, l, iin, jin, ifi, jfi, lgth1, lgth2, k, limk;
-	float wm;
+	double wm;
 	char *gaptable1, *gt1bk;
 	char *gaptable2, *gt2bk;
 	lgth1 = strlen( seq1[0] );
@@ -969,7 +974,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 	return( 0.0 );
 }
 
-float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, float *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
+double A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -977,52 +982,52 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 	int lasti, lastj;      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
-//	float fpenalty = (float)penalty;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
+//	double fpenalty = (double)penalty;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 	static TLS int **ijp;
 	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS char **mseq1;
 	static TLS char **mseq2;
 	static TLS char **mseq;
-	static TLS float *ogcp1;
-	static TLS float *ogcp2;
-	static TLS float *fgcp1;
-	static TLS float *fgcp2;
-	static TLS float **cpmx1;
-	static TLS float **cpmx2;
+	static TLS double *ogcp1;
+	static TLS double *ogcp2;
+	static TLS double *fgcp1;
+	static TLS double *fgcp2;
+	static TLS double **cpmx1;
+	static TLS double **cpmx2;
 	static TLS int **intwork;
-	static TLS float **floatwork;
+	static TLS double **doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
-	static TLS float *gapfreq1;
-	static TLS float *gapfreq2;
-	float fpenalty = (float)penalty;
-	float fpenalty_shift = (float)penalty_shift;
-	float *fgcp2pt;
-	float *ogcp2pt;
-	float fgcp1va;
-	float ogcp1va;
-	float *gf2pt;
-	float *gf2ptpre;
-	float gf1va;
-	float gf1vapre;
-	float headgapfreq1;
-	float headgapfreq2;
+	static TLS double *gapfreq1;
+	static TLS double *gapfreq2;
+	double fpenalty = (double)penalty;
+	double fpenalty_shift = (double)penalty_shift;
+	double *fgcp2pt;
+	double *ogcp2pt;
+	double fgcp1va;
+	double ogcp1va;
+	double *gf2pt;
+	double *gf2ptpre;
+	double gf1va;
+	double gf1vapre;
+	double headgapfreq1;
+	double headgapfreq2;
 
 	int *warpis = NULL;
 	int *warpjs = NULL;
@@ -1030,14 +1035,17 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
+//	for( i=0; i<icyc; i++ ) fprintf( stderr, "%s, %f\n", seq1[i], eff1[i] );
+//	for( i=0; i<jcyc; i++ ) fprintf( stderr, "%s, %f\n", seq2[i], eff2[i] );
+
 
 	if( seq1 == NULL )
 	{
@@ -1074,7 +1082,7 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 
 		}
@@ -1198,7 +1206,7 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 		}
 
@@ -1233,10 +1241,10 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 		gapfreq2 = AllocateFloatVec( ll2+2 );
 
 #if FASTMATCHCALC
-		floatwork = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
+		doublework = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 		intwork = AllocateIntMtx( MAX( ll1, ll2 )+2, nalphabets+1 ); 
 #else
-		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 #endif
 
@@ -1290,7 +1298,7 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 
 #if 0
 	{
-		float t = 0.0;
+		double t = 0.0;
 		for( i=0; i<icyc; i++ )
 			t += eff1[i];
 	fprintf( stderr, "## totaleff = %f\n", t );
@@ -1370,11 +1378,11 @@ float A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, d
 	currentw = w1;
 	previousw = w2;
 
-	match_calc( n_dynamicmtx, initverticalw, cpmx2, cpmx1, 0, lgth1, floatwork, intwork, 1 );
+	match_calc( n_dynamicmtx, initverticalw, cpmx2, cpmx1, 0, lgth1, doublework, intwork, 1 );
 	if( localhom )
 		imp_match_out_vead_tate( initverticalw, 0, lgth1 ); // 060306
 
-	match_calc( n_dynamicmtx, currentw, cpmx1, cpmx2, 0, lgth2, floatwork, intwork, 1 );
+	match_calc( n_dynamicmtx, currentw, cpmx1, cpmx2, 0, lgth2, doublework, intwork, 1 );
 	if( localhom )
 		imp_match_out_vead( currentw, 0, lgth2 ); // 060306
 #if 0 // -> tbfast.c
@@ -1469,7 +1477,7 @@ for( i=0; i<lgth2; i++ )
 
 		previousw[0] = initverticalw[i-1];
 
-		match_calc( n_dynamicmtx, currentw, cpmx1, cpmx2, i, lgth2, floatwork, intwork, 0 );
+		match_calc( n_dynamicmtx, currentw, cpmx1, cpmx2, i, lgth2, doublework, intwork, 0 );
 #if XXXXXXX
 fprintf( stderr, "\n" );
 fprintf( stderr, "i=%d\n", i );
@@ -1723,7 +1731,7 @@ fprintf( stderr, "\n" );
 	return( wm );
 }
 
-float A__align_gapmap( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, float *impmatch, int *gapmap1, int *gapmap2 )
+double A__align_gapmap( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int *gapmap1, int *gapmap2 )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 	fprintf( stderr, "Unexpected error.  Please contact kazutaka.katoh@aist.go.jp\n" );
@@ -1731,7 +1739,7 @@ float A__align_gapmap( char **seq1, char **seq2, double *eff1, double *eff2, int
 }
 
 
-float A__align_variousdist( double **pairoffset, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, float *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
+double A__align_variousdist( double **pairoffset, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 
@@ -1740,52 +1748,52 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 	int lasti, lastj;      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
-//	float fpenalty = (float)penalty;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
+//	double fpenalty = (double)penalty;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 	static TLS int **ijp;
 	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS char **mseq1;
 	static TLS char **mseq2;
 	static TLS char **mseq;
-	static TLS float *ogcp1;
-	static TLS float *ogcp2;
-	static TLS float *fgcp1;
-	static TLS float *fgcp2;
-	static TLS float ***cpmx1s;
-	static TLS float ***cpmx2s;
+	static TLS double *ogcp1;
+	static TLS double *ogcp2;
+	static TLS double *fgcp1;
+	static TLS double *fgcp2;
+	static TLS double ***cpmx1s;
+	static TLS double ***cpmx2s;
 	static TLS int ***intwork;
-	static TLS float ***floatwork;
+	static TLS double ***doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
-	static TLS float *gapfreq1;
-	static TLS float *gapfreq2;
-	float fpenalty = (float)penalty;
-	float fpenalty_shift = (float)penalty_shift;
-	float *fgcp2pt;
-	float *ogcp2pt;
-	float fgcp1va;
-	float ogcp1va;
-	float *gf2pt;
-	float *gf2ptpre;
-	float gf1va;
-	float gf1vapre;
-	float headgapfreq1;
-	float headgapfreq2;
+	static TLS double *gapfreq1;
+	static TLS double *gapfreq2;
+	double fpenalty = (double)penalty;
+	double fpenalty_shift = (double)penalty_shift;
+	double *fgcp2pt;
+	double *ogcp2pt;
+	double fgcp1va;
+	double ogcp1va;
+	double *gf2pt;
+	double *gf2ptpre;
+	double gf1va;
+	double gf1vapre;
+	double headgapfreq1;
+	double headgapfreq2;
 
 	int *warpis = NULL;
 	int *warpjs = NULL;
@@ -1793,12 +1801,12 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
 
@@ -1837,7 +1845,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatCub( floatwork );
+			FreeFloatCub( doublework );
 			FreeIntCub( intwork );
 
 		}
@@ -1963,7 +1971,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatCub( floatwork );
+			FreeFloatCub( doublework );
 			FreeIntCub( intwork );
 		}
 
@@ -1997,7 +2005,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 		gapfreq1 = AllocateFloatVec( ll1+2 );
 		gapfreq2 = AllocateFloatVec( ll2+2 );
 
-		floatwork = AllocateFloatCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets ); 
+		doublework = AllocateFloatCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets ); 
 		intwork = AllocateIntCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets+1 ); 
 
 #if DEBUG
@@ -2050,7 +2058,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 
 #if 0
 	{
-		float t = 0.0;
+		double t = 0.0;
 		for( i=0; i<icyc; i++ )
 			t += eff1[i];
 	fprintf( stderr, "## totaleff = %f\n", t );
@@ -2140,7 +2148,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 //	for( j=0; j<jcyc; j++ ) fprintf( stderr, "seq2[j] = %s\n", seq2[j] );
 
 #if MCD
-	match_calc_dynamicmtx( pairoffset, n_dynamicmtx, initverticalw, jcyc, seq2, eff2, icyc, seq1, eff1, 0, lgth1, *floatwork, *intwork, 1, 1 );
+	match_calc_dynamicmtx( pairoffset, n_dynamicmtx, initverticalw, jcyc, seq2, eff2, icyc, seq1, eff1, 0, lgth1, *doublework, *intwork, 1, 1 );
 //	for( i=0; i<lgth1; i++ ) fprintf( stderr, "%d - %f\n", i, initverticalw[i] );
 #else
 	fillzero( initverticalw, lgth1 );
@@ -2149,7 +2157,7 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 //		fprintf( stderr, "c=%d matrices[c][W][W] = %f\n", c, matrices[c][amino_n['W']][amino_n['W']] );
 //		for( i=0; i<lgth1; i++ ) fprintf( stderr, "seq1[i] = %c, cpmx1s[c][3][%d] = %f\n", seq1[0][i], i, cpmx1s[c][3][i] );
 //		for( i=0; i<lgth2; i++ ) fprintf( stderr, "seq2[i] = %c, cpmx2s[c][3][%d] = %f\n", seq2[0][i], i, cpmx2s[c][3][i] );
-		match_calc_add( matrices[c], initverticalw, cpmx2s[c], cpmx1s[c], 0, lgth1, floatwork[c], intwork[c], 1 );
+		match_calc_add( matrices[c], initverticalw, cpmx2s[c], cpmx1s[c], 0, lgth1, doublework[c], intwork[c], 1 );
 //		for( i=0; i<lgth1; i++ ) fprintf( stderr, "c=%d, %d - %f\n", c, i, initverticalw[i] );
 	}
 //	for( i=0; i<lgth1; i++ ) fprintf( stderr, "%d - %f\n", i, initverticalw[i] );
@@ -2161,13 +2169,13 @@ float A__align_variousdist( double **pairoffset, double ***matrices, double **n_
 		imp_match_out_vead_tate( initverticalw, 0, lgth1 ); // 060306
 
 #if MCD
-	match_calc_dynamicmtx( pairoffset, n_dynamicmtx, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, 0, lgth2, *floatwork, *intwork, 1, 0 );
+	match_calc_dynamicmtx( pairoffset, n_dynamicmtx, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, 0, lgth2, *doublework, *intwork, 1, 0 );
 //	for( i=0; i<lgth2; i++ ) fprintf( stderr, "%d - %f\n", i, currentw[i] );
 //	exit( 1 );
 #else
 	fillzero( currentw, lgth2 );
 	for( c=0; c<maxdistclass; c++ )
-		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, floatwork[c], intwork[c], 1 );
+		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, doublework[c], intwork[c], 1 );
 //	for( i=0; i<lgth2; i++ ) fprintf( stderr, "%d - %f\n", i, currentw[i] );
 //	exit( 1 );
 #endif
@@ -2267,11 +2275,11 @@ for( i=0; i<lgth2; i++ )
 		previousw[0] = initverticalw[i-1];
 
 #if MCD
-		match_calc_dynamicmtx( pairoffset, n_dynamicmtx, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, i, lgth2, *floatwork, *intwork, 0, 0 );
+		match_calc_dynamicmtx( pairoffset, n_dynamicmtx, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, i, lgth2, *doublework, *intwork, 0, 0 );
 #else
 		fillzero( currentw, lgth2 );
 		for( c=0; c<maxdistclass; c++ )
-			match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], i, lgth2, floatwork[c], intwork[c], 0 );
+			match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], i, lgth2, doublework[c], intwork[c], 0 );
 #endif
 #if 0
 		if( i == 1 )
