@@ -15,8 +15,12 @@ static int noalign;
 static int multidist;
 static int maxdist = 2; // scale -> 2bai
 static int allowlongadds;
+static int keeplength;
+static int ndeleted;
+static int mapout;
+static int smoothing;
 
-static float lenfaca, lenfacb, lenfacc, lenfacd;
+static double lenfaca, lenfacb, lenfacc, lenfacd;
 static int tuplesize;
 
 #define PLENFACA 0.01
@@ -41,8 +45,8 @@ typedef struct _thread_arg
 	char **name; 
 	char **seq; 
 	LocalHom **localhomtable; 
-	float **iscore; 
-	float **nscore; 
+	double **iscore; 
+	double **nscore; 
 	int *istherenewgap; 
 	int **newgaplist;
 	RNApair ***singlerna; 
@@ -50,8 +54,9 @@ typedef struct _thread_arg
 	int alloclen;
 	Treedep *dep;
 	int  ***topol;
-	float  **len;
+	double  **len;
 	Addtree *addtree;
+	int **deletelist;
 #ifdef enablemultithread
 	int *iaddshare;
 	int thread_no;
@@ -82,9 +87,9 @@ typedef struct _distancematrixthread_arg
 	int *jobpospt;
 	int **pointt;
 	int *nogaplen;
-	float **imtx;
-	float **nmtx;
-	float *selfscore;
+	double **imtx;
+	double **nmtx;
+	double *selfscore;
 	pthread_mutex_t *mutex;
 } distancematrixthread_arg_t;
 
@@ -98,8 +103,8 @@ typedef struct _dndprethread_arg
 {
 	int njob;
 	int thread_no;
-	float *selfscore;
-	float **mtx;
+	double *selfscore;
+	double **mtx;
 	char **seq;
 	Jobtable2d *jobpospt;
 	pthread_mutex_t *mutex;
@@ -128,6 +133,7 @@ static void countnewres( int len, Blocktorealign *realign, int *posmap, int *gap
 	len1 = len+1;
 	for( i=0; i<len1; i++ )
 	{
+
 		if( realign[i].nnewres || gaplist[i] )
 		{
 			regend = posmap[i]-1;
@@ -850,6 +856,9 @@ void arguments( int argc, char *argv[] )
 	tuplesize = -1;
 	legacygapcost = 0;
 	allowlongadds = 0;
+	keeplength = 0;
+	mapout = 0;
+	smoothing = 0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -938,12 +947,14 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "nthread = %d\n", nthread );
 					--argc; 
 					goto nextoption;
+#if 0
 				case 'R':
 					rnaprediction = 'r';
 					break;
 				case 's':
 					RNAscoremtx = 'r';
 					break;
+#endif
 #if 1
 				case 'a':
 					fmodel = 1;
@@ -1028,7 +1039,7 @@ void arguments( int argc, char *argv[] )
 				case 'N':
 					nevermemsave = 1;
 					break;
-				case 'B':
+				case 'B':  // hitsuyou! memopt -M -B no tame
 					break;
 				case 'F':
 					use_fft = 1;
@@ -1043,6 +1054,9 @@ void arguments( int argc, char *argv[] )
 				case 'V':
 					allowlongadds = 1;
 					break;
+				case 'p':
+					smoothing = 1;
+					break;
 #if 0
 				case 'V':
 					topin = 1;
@@ -1080,12 +1094,20 @@ void arguments( int argc, char *argv[] )
 					fftWinSize = myatoi( *++argv );
 					--argc;
 					goto nextoption;
+#if 0
 				case 'Z':
 					checkC = 1;
 					break;
+#endif
 				case 'L':
 					legacygapcost = 1;
 					break;
+				case 'Y':
+					keeplength = 1;
+					break;
+				case 'Z':
+					mapout = 1;
+					break;
                 default:
                     fprintf( stderr, "illegal option %c\n", c );
                     argc = 0;
@@ -1118,13 +1140,14 @@ void arguments( int argc, char *argv[] )
 }
 
 
-static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, double *effarr, int *alloclen, LocalHom **localhomtable, RNApair ***singlerna, double *effarr_kozo )
+static double treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, double *effarr, int *alloclen, LocalHom **localhomtable, RNApair ***singlerna, double *effarr_kozo )
 {
+
 	int i, l, m;
 	int len1nocommongap, len2nocommongap;
 	int len1, len2;
 	int clus1, clus2;
-	float pscore, tscore;
+	double pscore, tscore;
 	char *indication1, *indication2;
 	double *effarr1 = NULL;
 	double *effarr2 = NULL;
@@ -1136,7 +1159,8 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 	int *gaplen;
 	int *gapmap;
 	int *alreadyaligned;
-	float dumfl = 0.0;
+//	double dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	RNApair ***grouprna1, ***grouprna2;
 
@@ -1245,8 +1269,8 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 		}
 		else
 		{
-			clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1 );
-			clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2 );
+			clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1, 0.0 );
+			clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2, 0.0 );
 		}
 
 		if( mergeoralign[l] == '1' || mergeoralign[l] == '2' )
@@ -1350,7 +1374,7 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000 );
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000 ); // v6.708
-//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (float)len1/fftlog[m1], clus1, (float)len2/fftlog[m2], clus2 );
+//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
 //		fprintf( stderr, "f=%d, clus1=%d, fftlog[m1]=%d, clus2=%d, fftlog[m2]=%d\n", ffttry, clus1, fftlog[m1], clus2, fftlog[m2] );
 		if( constraint == 2 )
 		{
@@ -1364,7 +1388,7 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'Q' )
 			{
@@ -1397,7 +1421,7 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 					pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
@@ -1413,14 +1437,14 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 		fprintf( stderr, "score = %10.2f\n", pscore );
 #endif
 		tscore += pscore;
-/*
-		fprintf( stderr, "after align 1 %s \n", indication1 );
-		display( mseq1, clus1 );
-		fprintf( stderr, "\n" );
-		fprintf( stderr, "after align 2 %s \n", indication2 );
-		display( mseq2, clus2 );
-		fprintf( stderr, "\n" );
-*/
+#if 0 // New gaps = '='
+		fprintf( stderr, "Original msa\n" );
+		for( i=0; i<clus1; i++ )
+			fprintf( stderr, "%s\n", mseq1[i] );
+		fprintf( stderr, "Query\n" );
+		for( i=0; i<clus2; i++ )
+			fprintf( stderr, "%s\n", mseq2[i] );
+#endif
 
 //		writePre( nseq, name, nlen, aseq, 0 );
 
@@ -1428,8 +1452,9 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 
 		if( mergeoralign[l] == '1' ) // jissainiha nai. atarashii hairetsu ha saigo dakara.
 		{
+//			if( deleteadditionalinsertions ) ndeleted += deletenewinsertions( clus2, clus1, mseq2, mseq1, deleterecord );
 			adjustgapmap( strlen( mseq2[0] )-len2nocommongap+len2, gapmap, mseq2[0] );
-			restorecommongaps( nseq, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+			restorecommongaps( nseq, nseq-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
 			findnewgaps( clus2, 0, mseq2, gaplen );
 			insertnewgaps( nseq, alreadyaligned, aseq, topol[l][1], topol[l][0], gaplen, gapmap, *alloclen, alg, '-' );
 //			for( i=0; i<nseq; i++ ) eq2dash( aseq[i] );
@@ -1437,8 +1462,9 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 		}
 		if( mergeoralign[l] == '2' )
 		{
+//			if( deleteadditionalinsertions ) ndeleted += deletenewinsertions( clus1, clus2, mseq1, mseq2, deleterecord );
 			adjustgapmap( strlen( mseq1[0] )-len1nocommongap+len1, gapmap, mseq1[0] );
-			restorecommongaps( nseq, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+			restorecommongaps( nseq, nseq-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
 			findnewgaps( clus1, 0, mseq1, gaplen );
 			insertnewgaps( nseq, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, *alloclen, alg, '-' );
 //			for( i=0; i<nseq; i++ ) eq2dash( aseq[i] );
@@ -1452,6 +1478,10 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 #endif
 	}
 
+//for( i=0; i<nseq; nseq++ )
+//reporterr( "In treebase() before deletenewinsertions, %s\n", aseq[i] );
+//	if( keeplength ) ndeleted += deletenewinsertions_withoutusingequal( nseq-1, 1, 0, aseq, aseq+nseq-1, NULL, deletemapiadd, deletelagiadd, deletelistiadd );
+
 #if SCOREOUT
 	fprintf( stderr, "totalscore = %10.2f\n\n", tscore );
 #endif
@@ -1476,16 +1506,17 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 	free( effarr1_kozo );
 	free( effarr2_kozo );
 
+
 	return( pscore );
 }
 
 
 
 
-static void mtxcpy( int norg, int njobc, float ***iscorec, float **iscore )
+static void mtxcpy( int norg, int njobc, double ***iscorec, double **iscore )
 {
 	int i, nlim, n;
-	float *fpt, *fptc;
+	double *fpt, *fptc;
 	
 	*iscorec = AllocateFloatHalfMtx( njobc );
 	nlim = norg-1;
@@ -1505,25 +1536,25 @@ static void mtxcpy( int norg, int njobc, float ***iscorec, float **iscore )
 static void	*addsinglethread( void *arg )
 	{
 		thread_arg_t *targ = (thread_arg_t *)arg;
-		int *nlenc;
-		char **namec;
-		Treedep *depc;
-		char **mseq1, **mseq2;
-		float **iscorec;
-//		float **iscorecbk; // to speedup
-		double *effc;
-		int ***topolc;
-		float **lenc;
+		int *nlenc = NULL;
+		char **namec = NULL;
+		Treedep *depc = NULL;
+		char **mseq1 = NULL, **mseq2 = NULL;
+		double **iscorec;
+//		double **iscorecbk; // to speedup
+		double *effc = NULL;
+		int ***topolc = NULL;
+		double **lenc = NULL;
 		LocalHom **localhomtablec = NULL;
-		int *memlist0;
-		int *memlist1;
-		int *addmem;
+		int *memlist0 = NULL;
+		int *memlist1 = NULL;
+		int *addmem = NULL;
 		int njobc, norg;
-		char **bseq;
+		char **bseq = NULL;
 		int i, j, k, m, iadd, rep, neighbor;
-		char *mergeoralign;
-		int *nogaplenjusttodecideaddhereornot;
-		char *tmpseq;
+		char *mergeoralign = NULL;
+		int *nogaplenjusttodecideaddhereornot = NULL;
+		char *tmpseq = NULL;
 
 #ifdef enablemultithread
 		int thread_no = targ->thread_no;
@@ -1536,8 +1567,8 @@ static void	*addsinglethread( void *arg )
 		char **name = targ->name;
 		char **seq = targ->seq;
 		LocalHom **localhomtable = targ->localhomtable;
-		float **iscore = targ->iscore;
-		float **nscore = targ->nscore;
+		double **iscore = targ->iscore;
+		double **nscore = targ->nscore;
 		int *istherenewgap = targ->istherenewgap;
 		int **newgaplist = targ->newgaplist;
 		RNApair ***singlerna = targ->singlerna;
@@ -1545,10 +1576,13 @@ static void	*addsinglethread( void *arg )
 		int alloclen = targ->alloclen;
 		Treedep *dep = targ->dep;
 		int ***topol = targ->topol;
-		float **len = targ->len;
+		double **len = targ->len;
 		Addtree *addtree = targ->addtree;
-		float pscore;
-		int *alnleninnode;
+		int **deletelist = targ->deletelist;
+		double pscore;
+		int *alnleninnode = NULL;
+		char *targetseq;
+
 
 
 //		fprintf( stderr, "\nPreparing thread %d\n", thread_no );
@@ -1564,16 +1598,16 @@ static void	*addsinglethread( void *arg )
 		namec = AllocateCharMtx( njob, 0 );
 		nlenc = AllocateIntVec( njob );
 		mergeoralign = AllocateCharVec( njob );
-		nogaplenjusttodecideaddhereornot = AllocateIntVec( njob );
+		nogaplenjusttodecideaddhereornot = AllocateIntVec( njobc );
 		tmpseq = calloc( alloclen, sizeof( char ) );
 
-		if( allowlongadds )
+		if( allowlongadds ) // hontou ha iranai.
 		{
-			for( i=0; i<njob; i++ ) nogaplenjusttodecideaddhereornot[i] = 0;
+			for( i=0; i<njobc; i++ ) nogaplenjusttodecideaddhereornot[i] = 0;
 		}
 		else
 		{
-			for( i=0; i<njob; i++ ) 
+			for( i=0; i<norg; i++ ) 
 			{
 				gappick0( tmpseq, seq[i] );
 				nogaplenjusttodecideaddhereornot[i] = strlen( tmpseq );
@@ -1660,6 +1694,7 @@ static void	*addsinglethread( void *arg )
 				}
 				fprintf( stderr, "\r%d / %d (thread %d)                    \r", iadd, nadd, thread_no );
 				++(*iaddshare);
+				targetseq = seq[norg+iadd];
 				pthread_mutex_unlock( targ->mutex_counter );
 			}
 			else
@@ -1667,11 +1702,18 @@ static void	*addsinglethread( void *arg )
 			{
 				iadd++;
 				if( iadd == nadd ) break;
+				targetseq = seq[norg+iadd];
 				fprintf( stderr, "\r%d / %d                    \r", iadd, nadd );
 			}
 
 			for( i=0; i<norg; i++ ) strcpy( bseq[i], seq[i] );
-			gappick0( bseq[norg], seq[norg+iadd] );
+//			gappick0( bseq[norg], seq[norg+iadd] );
+			gappick0( bseq[norg], targetseq );
+
+			if( allowlongadds ) // missed in v7.220
+				nogaplenjusttodecideaddhereornot[norg] = 0;
+			else
+				nogaplenjusttodecideaddhereornot[norg] = strlen( bseq[norg] );
 
 			mtxcpy( norg, njobc, &iscorec, iscore );
 	
@@ -1724,27 +1766,32 @@ static void	*addsinglethread( void *arg )
 //			if( iadd == 0 )
 //			{
 //			}
-//			fixed_musclesupg_float_realloc_nobk_halfmtx( njobc, iscorec, topolc, lenc, depc, 0, 1 );
-			neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot );
+//			fixed_musclesupg_double_realloc_nobk_halfmtx( njobc, iscorec, topolc, lenc, depc, 0, 1 );
+			neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot, noalign );
+
+
+			FreeFloatHalfMtx( iscorec, njobc );
 
-			if( noalign ) 
-			{
-				FreeFloatHalfMtx( iscorec, njobc );
-				continue;
-			}
 	
 			if( tbrweight )
 			{
 				weight = 3; 
-				counteff_simple_float_nostatic( njobc, topolc, lenc, effc );
+				counteff_simple_double_nostatic( njobc, topolc, lenc, effc );
 			}
 			else
 			{
 				for( i=0; i<njobc; i++ ) effc[i] = 1.0;
 			}
 		
-			FreeFloatHalfMtx( iscorec, njobc );
 //			FreeFloatMtx( lenc );
+
+			if( noalign ) // nen no tame weight wo keisan.
+			{
+//				FreeFloatHalfMtx( iscorec, njobc ); // saki ni continue suru baai ha fukkatsu.
+				continue;
+			}
+
+//			reporterr( "iadd = %d\n", iadd );
 		
 #if 0
 			for( i=0; i<njobc-1; i++ )
@@ -1835,6 +1882,7 @@ static void	*addsinglethread( void *arg )
 			fprintf( stdout, "\n" );
 			pthread_mutex_unlock( targ->mutex_counter );
 #endif
+
 			singlerna = NULL;
 			pscore = treebase( njobc, nlenc, bseq, 1, mergeoralign, mseq1, mseq2, topolc, effc, &alloclen, localhomtablec, singlerna, eff_kozo_mapped );
 #if 0
@@ -1854,54 +1902,74 @@ static void	*addsinglethread( void *arg )
 //			fprintf( stdout, "\n>seq[%d, iadd=%d] = \n%s\n", norg+iadd, iadd, seq[norg+iadd] );
 //			fprintf( stdout, "\n>bseq[%d, iadd=%d] = \n%s\n", norg, iadd, bseq[norg] );
 	
-			strcpy( seq[norg+iadd], bseq[norg] );
+//			strcpy( seq[norg+iadd], bseq[norg] );
+
 	
-			rep = -1;
-			for( i=0; i<norg; i++ )
+			if( keeplength )
 			{
-//				fprintf( stderr, "Checking %d/%d\n", i, norg );
-				if( strchr( bseq[i], '=' ) ) break;
+//				reporterr( "deletelist = %p\n", deletelist );
+//				reporterr( "deletelist+iadd = %p\n", deletelist+iadd );
+				ndeleted += deletenewinsertions_whole_eq( norg, 1, bseq, bseq+norg, deletelist+iadd );
+//				for( i=0; i<norg+1; i++ ) reporterr( ">\n%s\n", bseq[i] );
+				strcpy( targetseq, bseq[norg] );
+				i = norg; // no new gap!!
 			}
+			else
+			{
+				strcpy( targetseq, bseq[norg] );
+				rep = -1;
+				for( i=0; i<norg; i++ )
+				{
+//					fprintf( stderr, "Checking %d/%d\n", i, norg );
+					if( strchr( bseq[i], '=' ) ) break;
+				}
+			}
+
 			if( i == norg ) 
 				istherenewgap[iadd] = 0;
 			else
 			{
 				rep = i;
 				istherenewgap[iadd] = 1;
+
+
 				makenewgaplist( newgaplist[iadd], bseq[rep] );
 //				for( i=0; newgaplist[iadd][i]!=-1; i++ ) fprintf( stderr, "%d: %d\n", i, newgaplist[iadd][i] );
 			}
-			eq2dash( seq[norg+iadd] );
+			eq2dash( targetseq );
 
 		}
 
 
-		if( constraint )
+#if 1
+		if( constraint && localhomtablec )
 		{
 			for( i=0; i<njobc; i++ ) free( localhomtablec[i] );
 			free( localhomtablec );
+			localhomtablec = NULL;
 		}
-		free( mergeoralign );
-		free( nogaplenjusttodecideaddhereornot );
-		free( alnleninnode );
-		free( tmpseq );
-		FreeCharMtx( bseq );
-		free( namec );
-		free( nlenc  );
-		free( depc );
-		FreeIntCub( topolc );
-		FreeFloatMtx( lenc );
-		FreeDoubleVec( effc );
-		free( memlist0 );
-		free( memlist1 );
-		free( addmem );
-		free( mseq1 );
-		free( mseq2 );
+		if( mergeoralign ) free( mergeoralign );  mergeoralign = NULL;
+		if( nogaplenjusttodecideaddhereornot ) free( nogaplenjusttodecideaddhereornot ); nogaplenjusttodecideaddhereornot = NULL;
+		if( alnleninnode ) free( alnleninnode ); alnleninnode = NULL;
+		if( tmpseq ) free( tmpseq ); tmpseq = NULL;
+		if( bseq ) FreeCharMtx( bseq ); bseq = NULL;
+		if( namec ) free( namec ); namec = NULL;
+		if( nlenc ) free( nlenc  ); nlenc = NULL;
+		if( depc ) free( depc ); depc = NULL;
+		if( topolc ) FreeIntCub( topolc ); topolc = NULL;
+		if( lenc ) FreeFloatMtx( lenc ); lenc = NULL;
+		if( effc ) FreeDoubleVec( effc ); effc = NULL;
+		if( memlist0 ) free( memlist0 ); memlist0 = NULL;
+		if( memlist1 ) free( memlist1 ); memlist1 = NULL;
+		if( addmem ) free( addmem ); addmem = NULL;
+		if( mseq1 ) free( mseq1 ); mseq1 = NULL;
+		if( mseq2 ) free( mseq2 ); mseq2 = NULL;
 		Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
 		A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 		if( commonIP ) FreeIntMtx( commonIP );
 		commonIP = NULL;
 		commonAlloc1 = commonAlloc2 = 0;
+#endif
 //		FreeFloatHalfMtx( iscorecbk, norg );
 
 		return( NULL );
@@ -2139,14 +2207,14 @@ void *dndprethread( void *arg )
 	dndprethread_arg_t *targ = (dndprethread_arg_t *)arg;
 	int njob = targ->njob;
 	int thread_no = targ->thread_no;
-	float *selfscore = targ->selfscore;
-	float **mtx = targ->mtx;
+	double *selfscore = targ->selfscore;
+	double **mtx = targ->mtx;
 	char **seq = targ->seq;
 	Jobtable2d *jobpospt = targ->jobpospt;
 
 	int i, j;
-	float ssi, ssj, bunbo;
-	float mtxv;
+	double ssi, ssj, bunbo;
+	double mtxv;
 
 	if( njob == 1 ) return( NULL );
 	
@@ -2182,7 +2250,7 @@ void *dndprethread( void *arg )
 		if( bunbo == 0.0 )
 			mtxv = maxdist;
 		else
-			mtxv = maxdist * ( 1.0 - (float)naivepairscore11( seq[i], seq[j], penalty * 10  ) / bunbo );
+			mtxv = maxdist * ( 1.0 - (double)naivepairscore11( seq[i], seq[j], penalty * 10  ) / bunbo );
 #if 1
 		if( mtxv > 9.0 || mtxv < 0.0 )
 		{
@@ -2247,12 +2315,12 @@ static void *distancematrixthread( void *arg )
 	int norg = targ->norg;
 	int *jobpospt = targ->jobpospt;
 	int **pointt = targ->pointt;
-	float **imtx = targ->imtx;
-	float **nmtx = targ->nmtx;
-	float *selfscore = targ->selfscore;
+	double **imtx = targ->imtx;
+	double **nmtx = targ->nmtx;
+	double *selfscore = targ->selfscore;
 	int *nogaplen = targ->nogaplen;
 
-	float lenfac, bunbo, longer, shorter, mtxv;
+	double lenfac, bunbo, longer, shorter, mtxv;
 	int *table1;
 	int i, j;
 
@@ -2279,16 +2347,16 @@ static void *distancematrixthread( void *arg )
 	
 		for( j=i+1; j<njob; j++ ) 
 		{
-			mtxv = (float)commonsextet_p( table1, pointt[j] );
+			mtxv = (double)commonsextet_p( table1, pointt[j] );
 			if( nogaplen[i] > nogaplen[j] )
 			{
-				longer=(float)nogaplen[i];
-				shorter=(float)nogaplen[j];
+				longer=(double)nogaplen[i];
+				shorter=(double)nogaplen[j];
 			}
 			else
 			{
-				longer=(float)nogaplen[j];
-				shorter=(float)nogaplen[i];
+				longer=(double)nogaplen[j];
+				shorter=(double)nogaplen[i];
 			}
 			lenfac = 1.0 / ( shorter / longer * lenfacd + lenfacb / ( longer + lenfacc ) + lenfaca );
 			bunbo = MIN( selfscore[i], selfscore[j] );
@@ -2312,16 +2380,16 @@ static void *distancematrixthread( void *arg )
 		free( table1 );
 
 //		for( j=i+1; j<norg; j++ ) 
-//			imtx[i][j-i] = (float)commonsextet_p( table1, pointt[j] );
+//			imtx[i][j-i] = (double)commonsextet_p( table1, pointt[j] );
 //		for( j=norg; j<njob; j++ ) 
-//			nmtx[i][j-norg] = (float)commonsextet_p( table1, pointt[j] );
+//			nmtx[i][j-norg] = (double)commonsextet_p( table1, pointt[j] );
 //		free( table1 );
 	}
 }
 #endif
 
 
-void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **name, float **imtx, float **nmtx )
+void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **name, double **imtx, double **nmtx )
 {
 	char *tmpseq;
 	int *grpseq;
@@ -2329,8 +2397,8 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 	int i, j;
 	int *nogaplen;
 	int *table1;
-	float lenfac, bunbo, longer, shorter, mtxv;
-	float *selfscore;
+	double lenfac, bunbo, longer, shorter, mtxv;
+	double *selfscore;
 	selfscore = AllocateFloatVec( nseq );
 
 	fprintf( stderr, "\n\nMaking a distance matrix ..\n" );
@@ -2408,7 +2476,7 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 		if( !table1 ) ErrorExit( "Cannot allocate table1\n" );
 		makecompositiontable_p( table1, pointt[i] );
 
-		selfscore[i] = (float)commonsextet_p( table1, pointt[i] );
+		selfscore[i] = (double)commonsextet_p( table1, pointt[i] );
 		free( table1 );
 	}
 
@@ -2466,16 +2534,16 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 	
 			for( j=i+1; j<nseq; j++ ) 
 			{
-				mtxv = (float)commonsextet_p( table1, pointt[j] );
+				mtxv = (double)commonsextet_p( table1, pointt[j] );
 				if( nogaplen[i] > nogaplen[j] )
 				{
-					longer=(float)nogaplen[i];
-					shorter=(float)nogaplen[j];
+					longer=(double)nogaplen[i];
+					shorter=(double)nogaplen[j];
 				}
 				else
 				{
-					longer=(float)nogaplen[j];
-					shorter=(float)nogaplen[i];
+					longer=(double)nogaplen[j];
+					shorter=(double)nogaplen[i];
 				}
 				lenfac = 1.0 / ( shorter / longer * lenfacd + lenfacb / ( longer + lenfacc ) + lenfaca );
 				bunbo = MIN( selfscore[i], selfscore[j] );
@@ -2528,18 +2596,18 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 #endif
 }
 
-void dndpre( int nseq, char **seq, float **mtx ) // not used yet
+void dndpre( int nseq, char **seq, double **mtx ) // not used yet
 {
 	int i, j, ilim;
-	float *selfscore;
-	float mtxv;
-	float ssi, ssj, bunbo;
+	double *selfscore;
+	double mtxv;
+	double ssi, ssj, bunbo;
 
 	selfscore = AllocateFloatVec( nseq );
 
 	for( i=0; i<nseq; i++ )
 	{
-		selfscore[i] = (float)naivepairscore11( seq[i], seq[i], 0 );
+		selfscore[i] = (double)naivepairscore11( seq[i], seq[i], 0 );
 	}
 #ifdef enablemultithread
 	if( nthread > 0 )
@@ -2592,7 +2660,7 @@ void dndpre( int nseq, char **seq, float **mtx ) // not used yet
 				if( bunbo == 0.0 )
 					mtxv = maxdist;
 				else
-					mtxv = maxdist * ( 1.0 - (float)naivepairscore11( seq[i], seq[j], penalty * 10 ) / bunbo );
+					mtxv = maxdist * ( 1.0 - (double)naivepairscore11( seq[i], seq[j], penalty * 10 ) / bunbo );
 
 #if 1
 				if( mtxv > 9.0 || mtxv < 0.0 )
@@ -2624,6 +2692,144 @@ void dndpre( int nseq, char **seq, float **mtx ) // not used yet
 
 }
 
+static int searchlet( char *p1, char *p2 )
+{
+	char *p;
+	for( p=p1; p<=p2; p++ )
+	{
+		if( *p != '-' )
+		{
+			return( p-p1 );
+		}
+	}
+	return( -1 );
+}
+
+static void smoothing2( int njob, int nadd, int lenfull, char **seq, Blocktorealign *realign )
+{
+	int i, j, norg = njob-nadd;
+
+	reporterr( "Smoothing2\n" );
+	for( i=2; i<lenfull+1; i++ )
+	{
+		int postoshiftfrom;
+		int shiftonadd;
+		int postoshiftto;
+		if( realign[i-2].nnewres && realign[i-1].nnewres == 0 && realign[i].nnewres ) 
+		{
+			postoshiftto = realign[i-2].start;
+			postoshiftfrom = realign[i-2].end + 1;
+			if( postoshiftfrom != realign[i].start -2 )
+			{
+				reporterr( "Unexpected pattern??? i=%d, realign[i-1].end=%d, realign[i].start=%d\n", i, realign[i-1].end, realign[i].start );
+				exit( 1 );
+			}
+
+			realign[i].nnewres += realign[i-2].nnewres; 
+			realign[i].start = realign[i-2].start+2; 
+			realign[i-2].nnewres = 0;
+			realign[i-2].start = realign[i-2].end = 0;
+
+
+//			reporterr( "SHIFT %d -> %d\n", postoshiftfrom, postoshiftto );
+			for( j=0; j<norg; j++ )
+			{
+				if( seq[j][postoshiftto] != '-' )
+				{
+					reporterr( "Unexpected pattern 2. i=%d, postoshiftto=%d, postoshiftfrom=%d, seq[%d][%d]=%c\n", i, postoshiftto, postoshiftfrom, j, postoshiftto, seq[j][postoshiftto] );
+//					reporterr( seq[j] );
+					exit( 1 );
+				}
+				seq[j][postoshiftto] = seq[j][postoshiftfrom];
+				seq[j][postoshiftfrom] = '-';
+
+				if( seq[j][postoshiftto+1] != '-' )
+				{
+					reporterr( "Unexpected pattern 3???\n" );
+					exit( 1 );
+				}
+				seq[j][postoshiftto+1] = seq[j][postoshiftfrom+1];
+				seq[j][postoshiftfrom+1] = '-';
+			}
+			for( j=norg; j<njob; j++ )
+			{
+				if( seq[j][postoshiftto] == '-' )
+				{
+					shiftonadd = searchlet( seq[j]+postoshiftto, seq[j]+postoshiftfrom );
+					if( shiftonadd != -1 )
+					{
+						seq[j][postoshiftto] = seq[j][postoshiftto+shiftonadd];
+						seq[j][postoshiftto+shiftonadd] = '-';
+					}
+				}
+				if( seq[j][postoshiftto+1] == '-' )
+				{
+					shiftonadd = searchlet( seq[j]+postoshiftto+1, seq[j]+postoshiftfrom+1 );
+					if( shiftonadd != -1 )
+					{
+						seq[j][postoshiftto+1] = seq[j][postoshiftto+1+shiftonadd];
+						seq[j][postoshiftto+1+shiftonadd] = '-';
+					}
+				}
+			}
+		}
+	}
+//	for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
+}
+static void smoothing1( int njob, int nadd, int lenfull, char **seq, Blocktorealign *realign )
+{
+	int i, j, norg = njob-nadd;
+
+	reporterr( "Smoothing1\n" );
+	for( i=1; i<lenfull+1; i++ )
+	{
+		int postoshiftfrom;
+		int shiftonadd;
+		int postoshiftto;
+		if( realign[i-1].nnewres && realign[i].nnewres ) 
+		{
+			postoshiftto = realign[i-1].start;
+			postoshiftfrom = realign[i-1].end + 1;
+			if( postoshiftfrom != realign[i].start -1 )
+			{
+				reporterr( "Unexpected pattern??? i=%d, realign[i-1].end=%d, realign[i].start=%d\n", i, realign[i-1].end, realign[i].start );
+				exit( 1 );
+			}
+
+			realign[i].nnewres += realign[i-1].nnewres; 
+			realign[i].start = realign[i-1].start+1; 
+			realign[i-1].nnewres = 0;
+			realign[i-1].start = realign[i-1].end = 0;
+
+
+//			reporterr( "SHIFT %d -> %d\n", postoshiftfrom, postoshiftto );
+			for( j=0; j<norg; j++ )
+			{
+				if( seq[j][postoshiftto] != '-' )
+				{
+					reporterr( "Unexpected pattern 2???\n" );
+					exit( 1 );
+				}
+				seq[j][postoshiftto] = seq[j][postoshiftfrom];
+				seq[j][postoshiftfrom] = '-';
+			}
+			for( j=norg; j<njob; j++ )
+			{
+				if( seq[j][postoshiftto] == '-' )
+				{
+					shiftonadd = searchlet( seq[j]+postoshiftto, seq[j]+postoshiftfrom );
+					if( shiftonadd != -1 )
+					{
+						seq[j][postoshiftto] = seq[j][postoshiftto+shiftonadd];
+						seq[j][postoshiftto+shiftonadd] = '-';
+					}
+				}
+			}
+		}
+	}
+//	for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
+}
+	
 int main( int argc, char *argv[] )
 {
 	static int  *nlen;	
@@ -2631,13 +2837,13 @@ int main( int argc, char *argv[] )
 	static char  **tmpseq;
 	static char  *tmpseq1;
 //	static char  *check1, *check2;
-	static float **iscore, **iscore_kozo;
+	static double **iscore, **iscore_kozo;
 	static double *eff_kozo, *eff_kozo_mapped = NULL;
 	int i, j, f, ien;
 	int iadd;
 	static int ***topol_kozo;
 	Treedep *dep;
-	static float **len_kozo;
+	static double **len_kozo;
 	FILE *prep;
 	FILE *infp;
 	FILE *hat2p;
@@ -2661,9 +2867,12 @@ int main( int argc, char *argv[] )
 	Blocktorealign *realign;
 	RNApair ***singlerna;
 	int ***topol;
-	float **len;
-	float **iscoreo, **nscore;
+	double **len;
+	double **iscoreo, **nscore;
 	FILE *fp;
+	int **deletelist = NULL;
+	char **addbk = NULL;
+	char *originalgaps = NULL;
 	Addtree *addtree;
 
 
@@ -2672,6 +2881,7 @@ int main( int argc, char *argv[] )
 	nthread = 0;
 #endif
 
+
 	if( fastathreshold < 0.0001 ) constraint = 0;
 
 	if( inputfile )
@@ -2711,6 +2921,8 @@ int main( int argc, char *argv[] )
 	name = AllocateCharMtx( njob, B+1 );
 	nlen = AllocateIntVec( njob );
 
+	ndeleted = 0;
+
 
 	if( multidist || tuplesize > 0 )
 	{
@@ -2897,7 +3109,7 @@ int main( int argc, char *argv[] )
 //			fprintf( stderr, "Loading 'hat2i' (aligned sequences) ... " );
 //			prep = fopen( "hat2i", "r" );
 //			if( prep == NULL ) ErrorExit( "Make hat2i." );
-//			readhat2_floathalf_pointer( prep, njob-nadd, name, iscore );
+//			readhat2_doublehalf_pointer( prep, njob-nadd, name, iscore );
 //			fclose( prep );
 //			fprintf( stderr, "done.\n" );
 
@@ -2917,14 +3129,14 @@ int main( int argc, char *argv[] )
 			fprintf( stderr, "Loading 'hat2n' (aligned sequences - new sequences) ... " );
 			prep = fopen( "hat2n", "r" );
 			if( prep == NULL ) ErrorExit( "Make hat2n." );
-			readhat2_floathalf_part_pointer( prep, njob, nadd, name, nscore );
+			readhat2_doublehalf_part_pointer( prep, njob, nadd, name, nscore );
 			fclose( prep );
 			fprintf( stderr, "done.\n" );
 		
 			fprintf( stderr, "Loading 'hat2i' (aligned sequences) ... " );
 			prep = fopen( "hat2i", "r" );
 			if( prep == NULL ) ErrorExit( "Make hat2i." );
-			readhat2_floathalf_pointer( prep, njob-nadd, name, iscore );
+			readhat2_doublehalf_pointer( prep, njob-nadd, name, iscore );
 			fclose( prep );
 			fprintf( stderr, "done.\n" );
 		}
@@ -2933,7 +3145,7 @@ int main( int argc, char *argv[] )
 			fprintf( stderr, "Loading 'hat2' ... " );
 			prep = fopen( "hat2", "r" );
 			if( prep == NULL ) ErrorExit( "Make hat2." );
-			readhat2_floathalf_pointer( prep, njob, name, iscore );
+			readhat2_doublehalf_pointer( prep, njob, name, iscore );
 			fclose( prep );
 			fprintf( stderr, "done.\n" );
 		}
@@ -2942,22 +3154,90 @@ int main( int argc, char *argv[] )
 #if 1
 	if( distout )
 	{
-		fprintf( stderr, "Error in v6.936!! Please contact kazutaka.katoh@aist.go.jp\n" );
-		exit( 1 );
+		fprintf( stderr, "Writing distances between new sequences and existing msa.\n" );
 		hat2p = fopen( "hat2", "w" );
-		WriteFloatHat2_pointer_halfmtx( hat2p, norg, name, iscore );
+		if( multidist || tuplesize > 0 )
+		{
+			for( iadd=0; iadd<nadd; iadd++ ) 
+			{
+				fprintf( hat2p, "Distance between new sequence %d and %d sequences in existing msa\n", iadd+1, norg );
+				for( i=0; i<norg; i++ ) 
+				{
+					fprintf( hat2p, "%5.3f ", nscore[i][iadd] );
+					if( (i+1) % 12 == 0 ) fprintf( hat2p, "\n" );
+				}
+				fprintf( hat2p, "\n\n" );
+			}
+		}
+		else
+		{
+			for( iadd=0; iadd<nadd; iadd++ ) 
+			{
+				fprintf( hat2p, "Distance between new sequence %d and %d sequences in existing msa\n", iadd+1, norg );
+				for( i=0; i<norg; i++ ) 
+				{
+					fprintf( hat2p, "%5.3f ", iscore[i][norg+iadd-i] );
+					if( (i+1) % 12 == 0 ) fprintf( hat2p, "\n" );
+				}
+				fprintf( hat2p, "\n\n" );
+			}
+		}
 		fclose( hat2p );
-		exit( 1 );
+//		exit( 1 );
+//		hat2p = fopen( "hat2", "w" );
+//		WriteFloatHat2_pointer_halfmtx( hat2p, norg, name, iscore );
+//		fclose( hat2p );
+//		exit( 1 );
 	}
 #endif
 
 
 	singlerna = NULL;
 
-	commongappick( norg, seq );
 
+	if( keeplength )
+	{
+		lenfull = strlen( seq[0] );
+		originalgaps = (char *)calloc( lenfull+1, sizeof( char) );
+		recordoriginalgaps( originalgaps, norg, seq );
+
+
+		deletelist = (int **)calloc( nadd+1, sizeof( int * ) );
+		for( i=0; i<nadd; i++ )
+		{
+			deletelist[i] = calloc( 1, sizeof( int ) );
+			deletelist[i][0] = -1;
+		}
+		deletelist[nadd] = NULL;
+
+	}
+	else
+	{
+		originalgaps = NULL;
+		deletelist = NULL;
+	}
+
+	commongappick( norg, seq );
 	lenfull = strlen( seq[0] );
 
+	if( keeplength && mapout )
+	{
+		addbk = (char **)calloc( nadd+1, sizeof( char * ) );
+		for( i=0; i<nadd; i++ )
+		{
+			ien = strlen( seq[norg+i] );
+			addbk[i] = (char *)calloc( ien + 1, sizeof( char ) );
+			gappick0( addbk[i], seq[norg+i] );
+		}
+		addbk[nadd] = NULL;
+	}
+	else
+	{
+		addbk = NULL;
+	}
+
+	
+
 //	newgaplist_o = AllocateIntMtx( nadd, alloclen ); //ookisugi
 	newgaplist_o = AllocateIntMtx( nadd, lenfull*2 );
 	newgaplist_compact = AllocateIntVec( lenfull*2 );
@@ -2996,10 +3276,16 @@ int main( int argc, char *argv[] )
 //	}
 
 //	fprintf( stderr, "building a tree.." );
-	if( treeout )
-		fixed_musclesupg_float_realloc_nobk_halfmtx_treeout( norg, iscoreo, topol, len, name, nlen, dep, 1 );
+	if( treein )
+	{
+		reporterr(       "Loading a tree ... " );
+		loadtop( norg, iscoreo, topol, len, name, NULL, dep ); // nogaplen?
+		reporterr( "\ndone.\n\n" );
+	}
+	else if( treeout )
+		fixed_musclesupg_double_realloc_nobk_halfmtx_treeout( norg, iscoreo, topol, len, name, nlen, dep, 1 );
 	else
-		fixed_musclesupg_float_realloc_nobk_halfmtx( norg, iscoreo, topol, len, dep, 0, 1 );
+		fixed_musclesupg_double_realloc_nobk_halfmtx( norg, iscoreo, topol, len, dep, 0, 1 );
 //	fprintf( stderr, "done.\n" );
 
 	if( norg > 1 ) 
@@ -3046,6 +3332,7 @@ int main( int argc, char *argv[] )
 			targ[i].topol = topol;
 			targ[i].len = len;
 			targ[i].addtree = addtree;
+			targ[i].deletelist = deletelist;
 			targ[i].mutex_counter = &mutex_counter;
 			pthread_create( handle+i, NULL, addsinglethread, (void *)(targ+i) );
 		}
@@ -3081,6 +3368,7 @@ int main( int argc, char *argv[] )
 		targ[0].topol = topol;
 		targ[0].len = len;
 		targ[0].addtree = addtree;
+		targ[0].deletelist = deletelist;
 		addsinglethread( targ );
 		free( targ );
 	}
@@ -3088,6 +3376,7 @@ int main( int argc, char *argv[] )
 	FreeFloatMtx( len );
 	if( multidist || tuplesize > 0 ) FreeFloatMtx( nscore );
 
+
 //	for( i=0; i<nadd; i++ ) fprintf( stdout, ">%s (%d) \n%s\n", name[norg+i], norg+i, seq[norg+i] );
 
 	if( treeout )
@@ -3163,6 +3452,8 @@ int main( int argc, char *argv[] )
 	fflush( stderr );
 	tmpseqlen = alloclen * 100;
 	tmpseq = AllocateCharMtx( 1, tmpseqlen );
+
+
 //	check1 = AllocateCharVec( tmpseqlen );
 //	check2 = AllocateCharVec( tmpseqlen );
 //	gappick0( check2, seq[0] );
@@ -3271,8 +3562,8 @@ int main( int argc, char *argv[] )
 #if 0
 	for( i=0; i<njob; i++ )
 	{
-		fprintf( stdout, ">%s\n", name[i] );
-		fprintf( stdout, "%s\n", seq[i] );
+		fprintf( stderr, ">%s\n", name[i] );
+		fprintf( stderr, "%s\n", seq[i] );
 	}
 #endif
 
@@ -3283,8 +3574,18 @@ int main( int argc, char *argv[] )
 		fprintf( stderr, "%d ", realign[i].nnewres );
 	}
 	fprintf( stderr, "\n" );
+	for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
 #endif
 
+	
+	if( smoothing )
+	{
+//		for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
+		smoothing1( njob, nadd, lenfull, seq, realign );
+//		for( i=0; i<lenfull+1; i++ ) fprintf( stderr, "i=%d, nnewres=%d, start=%d, end=%d\n", i, realign[i].nnewres, realign[i].start, realign[i].end );
+		smoothing2( njob, nadd, lenfull, seq, realign );
+	}
+
 	for( i=0; i<lenfull+1; i++ )
 	{
 		if( realign[i].nnewres > 1 ) 
@@ -3315,10 +3616,33 @@ int main( int argc, char *argv[] )
 	}
 	FreeIntCub( topol );
 	fprintf( stderr, "\r   done.                      \n\n" );
-
 	fflush( stderr );
 
 
+	if( keeplength )
+	{
+		FILE *dlf;
+		restoreoriginalgaps( njob, seq, originalgaps );
+
+		dlf = fopen( "_deletelist", "w" );
+		for( i=0; i<nadd; i++ )
+		{
+			if( deletelist[i] )
+				for( j=0; deletelist[i][j]!=-1; j++ )
+					fprintf( dlf, "%d %d\n", njob-nadd+i, deletelist[i][j] ); // 0origin
+		}
+		fclose( dlf );
+
+		if( mapout )
+		{
+			dlf = fopen( "_deletemap", "w" );
+			reconstructdeletemap( nadd, addbk, deletelist, seq+njob-nadd, dlf, name+njob-nadd );
+			fclose( dlf );
+		}
+	}
+
+
+
 	FreeIntMtx( newgaplist_o );
 	FreeIntVec( newgaplist_compact );
 	FreeIntVec( posmap );
@@ -3327,8 +3651,13 @@ int main( int argc, char *argv[] )
 	FreeIntMtx( follower );
 	free( follows );
 	free( ordertable );
+	free( kozoarivec );
+	free( nlen );
 	FreeCharMtx( tmpseq );
-
+	freeconstants();
+	if( addbk ) FreeCharMtx( addbk ); addbk = NULL;
+	if( deletelist ) FreeIntMtx( deletelist ); deletelist = NULL;
+	if( originalgaps ) free( originalgaps ); originalgaps = NULL;
 
 	writeData_pointer( prep_g, njob, name, nlen, seq );
 #if 0
@@ -3353,5 +3682,13 @@ int main( int argc, char *argv[] )
 	}
 
 	SHOWVERSION;
+	if( ndeleted > 0 )
+	{
+		reporterr( "\nTo keep the alignment length, %d letters were DELETED.\n", ndeleted );
+		if( mapout )
+			reporterr( "The deleted letters are shown in the (filename).map file.\n" );
+		else
+			reporterr( "To know the positions of deleted letters, rerun the same command with the --mapout option.\n" );
+	}
 	return( 0 );
 }
