@@ -1269,7 +1269,7 @@ void constants( int nseq, char **seq )
     for( i=0; i<nalphabets; i++) for( j=0; j<nalphabets; j++ )
 	{
         amino_dis[(int)amino[i]][(int)amino[j]] = n_dis[i][j];
-		n_dis_consweight_multi[i][j] = (float)n_dis[i][j] * consweight_multi;
+		n_dis_consweight_multi[i][j] = (double)n_dis[i][j] * consweight_multi;
 		amino_dis_consweight_multi[(int)amino[i]][(int)amino[j]] = (double)n_dis[i][j] * consweight_multi;
 	}
 
