@@ -84,7 +84,7 @@ int tbrweight;
 int disopt;
 int pamN;
 int checkC;
-float geta2;
+double geta2;
 int treemethod;
 int kimuraR;
 char *swopt;
@@ -97,8 +97,10 @@ int addprofile = 1;
 int rnakozo;
 char rnaprediction;
 int scoreout = 0;
+int spscoreout = 0;
 int outnumber = 0;
 int legacygapcost = 0;
+double minimumweight = 0.0005;
 
 char *signalSM;
 FILE *prep_g;
@@ -106,8 +108,8 @@ FILE *trap_g;
 char **seq_g;
 char **res_g;
 
-float consweight_multi = 1.0;
-float consweight_rna = 0.0;
+double consweight_multi = 1.0;
+double consweight_rna = 0.0;
 char RNAscoremtx = 'n';
 
 char TLS *newgapstr = "-";
