@@ -13,11 +13,16 @@ static int topin;
 static int treeout;
 static int noalign;
 static int distout;
-static float lenfaca, lenfacb, lenfacc, lenfacd;
+static double lenfaca, lenfacb, lenfacc, lenfacd;
 static int tuplesize;
 static int subalignment;
 static int subalignmentoffset;
 static int nguidetree;
+static int sparsepickup;
+static int keeplength;
+static int ndeleted;
+static int mapout;
+static int smoothing;
 #if 0
 #define PLENFACA 0.0123
 #define PLENFACB 10252
@@ -52,8 +57,8 @@ typedef struct _msadistmtxthread_arg
 {
 	int njob;
 	int thread_no;
-	float *selfscore;
-	float **iscore;
+	double *selfscore;
+	double **iscore;
 	char **seq;
 	int **skiptable;
 	Jobtable *jobpospt;
@@ -78,8 +83,8 @@ typedef struct _treebasethread_arg
 	int *alloclenpt;
 	int *fftlog;
 	char *mergeoralign;
-	float **newdistmtx;
-	float *selfscore;
+	double **newdistmtx;
+	double *selfscore;
 	pthread_mutex_t *mutex;
 	pthread_cond_t *treecond;
 } treebasethread_arg_t;
@@ -90,7 +95,7 @@ typedef struct _distancematrixthread_arg
 	int njob;
 	int *jobpospt;
 	int **pointt;
-	float **mtx;
+	double **mtx;
 	pthread_mutex_t *mutex;
 } distancematrixthread_arg_t;
 #endif
@@ -155,12 +160,17 @@ void arguments( int argc, char *argv[] )
 	fftThreshold = NOTSPECIFIED;
 	TMorJTT = JTT;
 	scoreout = 0;
+	spscoreout = 0;
 	tuplesize = 6;
 	subalignment = 0;
 	subalignmentoffset = 0;
 	legacygapcost = 0;
 	specificityconsideration = 0.0;
 	nguidetree = 1;
+	sparsepickup = 0;
+	keeplength = 0;
+	mapout = 0;
+	smoothing = 0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -288,7 +298,15 @@ void arguments( int argc, char *argv[] )
 				case 's':
 					treemethod = 's';
 					break;
+				case 'q':
+					treemethod = 'q'; // minimum
+					break;
 #endif
+				case 'q':
+					sparsepickup = myatoi( *++argv );
+					reporterr(       "sparsepickup = %d\n", sparsepickup );
+					--argc; 
+					goto nextoption;
 				case 'X':
 					treemethod = 'X';
 					sueff_global = atof( *++argv );
@@ -300,9 +318,6 @@ void arguments( int argc, char *argv[] )
 					reporterr(       "nguidetree = %d\n", nguidetree );
 					--argc; 
 					goto nextoption;
-				case 'q':
-					treemethod = 'q'; // minimum
-					break;
 #if 0
 				case 'a':
 					alg = 'a';
@@ -310,10 +325,10 @@ void arguments( int argc, char *argv[] )
 				case 'H':
 					alg = 'H';
 					break;
-#endif
 				case 'R':
 					alg = 'R';
 					break;
+#endif
 				case 'A':
 					alg = 'A';
 					break;
@@ -323,10 +338,16 @@ void arguments( int argc, char *argv[] )
 				case 'M':
 					alg = 'M';
 					break;
-				case 'S':
-					scoreout = 1;
+#if 0
+				case 'S' :
+					scoreout = 1; // for checking parallel calculation
 					break;
-				case 'B':
+#else
+				case 'S' :
+					spscoreout = 1; // 2014/Dec/30, sp score
+					break;
+#endif
+				case 'B': // hitsuyou! memopt -M -B no tame
 					break;
 				case 'F':
 					use_fft = 1;
@@ -377,9 +398,20 @@ void arguments( int argc, char *argv[] )
 					tuplesize = myatoi( *++argv );
 					--argc;
 					goto nextoption;
+#if 0
 				case 'Z':
 					checkC = 1;
 					break;
+#endif
+				case 'Y':
+					keeplength = 1;
+					break;
+				case 'Z':
+					mapout = 1;
+					break;
+				case 'p':
+					smoothing = 1;
+					break;
                 default:
                     reporterr(       "illegal option %c\n", c );
                     argc = 0;
@@ -407,6 +439,104 @@ void arguments( int argc, char *argv[] )
 }
 
 
+static void pickup( int n, int *seqlen, int ***topol, char **name, char **seq )
+{
+	int i, j, k, m;
+	int **longestseq;
+	int **longestlen;
+	int *select;
+	char **nameout, **seqout;
+	int *nlenout;
+	char **namenotused, **seqnotused;
+	int *nlennotused;
+	FILE *notusedfp;
+
+	longestseq = AllocateIntMtx( n-1, 2 );
+	longestlen = AllocateIntMtx( n-1, 2 );
+	select = AllocateIntVec( n );
+	for( i=0; i<n; i++ ) select[i] = 0;
+	nameout = AllocateCharMtx( n, 0 );
+	seqout = AllocateCharMtx( n, 0 );
+	nlenout = AllocateIntVec( n );
+	namenotused = AllocateCharMtx( n, 0 );
+	seqnotused = AllocateCharMtx( n, 0 );
+	nlennotused = AllocateIntVec( n );
+
+	for( i=0; i<n-1; i++ )
+	{
+//		reporterr( "STEP %d\n", i );
+		longestlen[i][0] = -1;
+		longestseq[i][0] = -1;
+		for( j=0; (m=topol[i][0][j])!=-1; j++ ) // sukoshi muda
+		{
+			if( seqlen[m] > longestlen[i][0] )
+			{
+				longestlen[i][0] = seqlen[m];
+				longestseq[i][0] = m;
+			}
+//			reporterr( "%d ", topol[i][0][j] );
+		}
+//		reporterr( "longest = %d (%d)\n", longestlen[i][0], longestseq[i][0] );
+
+
+		longestlen[i][1] = -1;
+		longestseq[i][1] = -1;
+		for( j=0; (m=topol[i][1][j])!=-1; j++ ) // sukoshi muda
+		{
+			if( seqlen[m] > longestlen[i][1] )
+			{
+				longestlen[i][1] = seqlen[m];
+				longestseq[i][1] = m;
+			}
+//			reporterr( "%d ", topol[i][1][j] );
+		}
+//		reporterr( "longest = %d (%d)\n", longestlen[i][1], longestseq[i][1] );
+	}
+
+	m = 1;
+	for( i=n-2; i>-1; i-- )
+	{
+//		reporterr( "longest[%d][0] = %d (%d)\n", i, longestlen[i][0], longestseq[i][0] );
+//		reporterr( "longest[%d][1] = %d (%d)\n", i, longestlen[i][1], longestseq[i][1] );
+		select[longestseq[i][0]] = 1;
+		select[longestseq[i][1]] = 1;
+		m += 1;
+		if( m >= sparsepickup ) break;
+	}
+	for( i=0, k=0, j=0; i<n; i++ ) 
+	{
+		if( select[i] )
+		{
+			nameout[k] = name[i];
+			seqout[k] = seq[i];
+			nlenout[k] = strlen( seqout[k] );
+			k++;
+		}
+		else
+		{
+			namenotused[j] = name[i];
+			seqnotused[j] = seq[i];
+			nlennotused[j] = strlen( seqnotused[j] );
+			j++;
+		}
+	}
+	writeData_pointer( stdout, m, nameout, nlenout, seqout );
+
+	notusedfp = fopen( "notused", "w" );
+	writeData_pointer( notusedfp, n-m, namenotused, nlennotused, seqnotused );
+	fclose( notusedfp );
+
+
+	free( nameout );
+	free( nlenout );
+	free( seqout );
+	free( namenotused );
+	free( nlennotused );
+	free( seqnotused );
+	FreeIntMtx( longestseq );
+	FreeIntMtx( longestlen );
+	free( select );
+}
 
 
 static int maxl;
@@ -642,14 +772,14 @@ static void *msadistmtxthread( void *arg ) // enablemultithread == 0 demo tsukau
 	msadistmtxthread_arg_t *targ = (msadistmtxthread_arg_t *)arg;
 	int njob = targ->njob;
 	int thread_no = targ->thread_no;
-	float *selfscore = targ->selfscore;
-	float **iscore = targ->iscore;
+	double *selfscore = targ->selfscore;
+	double **iscore = targ->iscore;
 	char **seq = targ->seq;
 	int **skiptable = targ->skiptable;
 	Jobtable *jobpospt = targ->jobpospt;
 
 
-	float ssi, ssj, bunbo;
+	double ssi, ssj, bunbo, iscoretmp;
 	int i, j;
 
 	while( 1 )
@@ -690,12 +820,17 @@ static void *msadistmtxthread( void *arg ) // enablemultithread == 0 demo tsukau
 		ssi = selfscore[i];
 		ssj = selfscore[j];
 		bunbo = MIN( ssi, ssj );
+//fprintf( stderr, "bunbo = %f\n", bunbo );
+//fprintf( stderr, "naivepairscorefast() = %f\n", naivepairscorefast( seq[i], seq[j], skiptable[i], skiptable[j], penalty_dist ) );
 		if( bunbo == 0.0 )
-			iscore[i][j-i] = 2.0; // 2013/Oct/17
+			iscoretmp = 2.0; // 2013/Oct/17
 		else
-//			iscore[i][j-i] = 0.0; // BUG!!!!!!! 2014/Oct/2
-//			iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo ) * 2.0; // 2013/Oct/17
-			iscore[i][j-i] = ( 1.0 - naivepairscorefast( seq[i], seq[j], skiptable[i], skiptable[j], penalty_dist ) / bunbo ) * 2.0; // 2014/Aug/15 fast 
+		{
+			iscoretmp = ( 1.0 - naivepairscorefast( seq[i], seq[j], skiptable[i], skiptable[j], penalty_dist ) / bunbo ) * 2.0; // 2014/Aug/15 fast 
+			if( iscoretmp > 10 ) iscoretmp = 10.0;  // 2015/Mar/17
+
+		}
+		iscore[i][j-i] = iscoretmp;
 	}
 }
 
@@ -707,7 +842,7 @@ static void *distancematrixthread( void *arg )
 	int njob = targ->njob;
 	int *jobpospt = targ->jobpospt;
 	int **pointt = targ->pointt;
-	float **mtx = targ->mtx;
+	double **mtx = targ->mtx;
 
 	int *table1;
 	int i, j;
@@ -735,7 +870,7 @@ static void *distancematrixthread( void *arg )
 
 		for( j=i; j<njob; j++ ) 
 		{
-			mtx[i][j-i] = (float)commonsextet_p( table1, pointt[j] );
+			mtx[i][j-i] = (double)commonsextet_p( table1, pointt[j] );
 		} 
 		free( table1 );
 	}
@@ -757,8 +892,8 @@ static void *treebasethread( void *arg )
 	int *alloclen = targ->alloclenpt;
 	int *fftlog = targ->fftlog;
 	char *mergeoralign = targ->mergeoralign;
-	float **newdistmtx = targ->newdistmtx;
-	float *selfscore = targ->selfscore;
+	double **newdistmtx = targ->newdistmtx;
+	double *selfscore = targ->selfscore;
 
 	char **mseq1, **mseq2;
 	char **localcopy;
@@ -766,15 +901,16 @@ static void *treebasethread( void *arg )
 	int immin, immax;
 	int len1, len2;
 	int clus1, clus2;
-	float pscore, tscore;
+	double pscore, tscore;
 	char *indication1, *indication2;
 	double *effarr1 = NULL;
 	double *effarr2 = NULL;
-	float dumfl = 0.0;
+//	double dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	int m1, m2;
 	double **dynamicmtx;
-	float ssi, ssm, bunbo;
+	double ssi, ssm, bunbo;
 	int tm, ti;
 #if SKIP
 	int **skiptable1 = NULL, **skiptable2 = NULL;
@@ -909,8 +1045,8 @@ static void *treebasethread( void *arg )
 		pthread_mutex_unlock( targ->mutex );
 
 #if 1 // CHUUI@@@@
-		clus1 = fastconjuction_noname( topol[l][0], localcopy, mseq1, effarr1, effarr, indication1 );
-		clus2 = fastconjuction_noname( topol[l][1], localcopy, mseq2, effarr2, effarr, indication2 );
+		clus1 = fastconjuction_noname( topol[l][0], localcopy, mseq1, effarr1, effarr, indication1, 0.0 );
+		clus2 = fastconjuction_noname( topol[l][1], localcopy, mseq2, effarr2, effarr, indication2, 0.0 );
 #else
 		clus1 = fastconjuction_noweight( topol[l][0], localcopy, mseq1, effarr1,  indication1 );
 		clus2 = fastconjuction_noweight( topol[l][1], localcopy, mseq2, effarr2,  indication2 );
@@ -995,7 +1131,7 @@ static void *treebasethread( void *arg )
 		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000);
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000); // v6.708
-//		reporterr(       "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (float)len1/fftlog[m1], clus1, (float)len2/fftlog[m2], clus2 );
+//		reporterr(       "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
 
 		if( force_fft || ( use_fft && ffttry ) )
 		{
@@ -1033,7 +1169,7 @@ static void *treebasethread( void *arg )
 					else
 					{
 //						reporterr(       "%d-%d", clus1, clus2 );
-						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					}
 					break;
 				default:
@@ -1142,25 +1278,27 @@ static void *treebasethread( void *arg )
 }
 #endif
 
-static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, Treedep *dep, double *effarr, float **newdistmtx, float *selfscore, int *alloclen, int (*callback)(int, int, char*) )
+static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq1, char **mseq2, int ***topol, Treedep *dep, double *effarr, double **newdistmtx, double *selfscore, int *alloclen, int (*callback)(int, int, char*) )
 {
 	int l, len1, len2, i, m, immin, immax;
 	int len1nocommongap, len2nocommongap;
 	int clus1, clus2;
-	float pscore, tscore;
+	double pscore, tscore;
 	char *indication1 = NULL, *indication2 = NULL;
 	double *effarr1 = NULL;
 	double *effarr2 = NULL;
 	int *fftlog = NULL; // fixed at 2006/07/26
-	float dumfl = 0.0;
+//	double dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	int m1, m2;
 	int *gaplen = NULL;
 	int *gapmap = NULL;
 	int *alreadyaligned = NULL;
 	double **dynamicmtx = NULL;
-	float ssi, ssm, bunbo;
+	double ssi, ssm, bunbo;
 	int tm, ti;
+	int gapmaplen;
 #if SKIP
 	int **skiptable1 = NULL, **skiptable2 = NULL;
 #endif
@@ -1244,12 +1382,13 @@ static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 		}
 
 #if 1 // CHUUI@@@@
-		clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1 );
-		clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2 );
+		clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1, 0.0 );
+		clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2, 0.0 );
 #else
 		clus1 = fastconjuction_noweight( topol[l][0], aseq, mseq1, effarr1,  indication1 );
 		clus2 = fastconjuction_noweight( topol[l][1], aseq, mseq2, effarr2,  indication2 );
 #endif
+
 		if( mergeoralign[l] == '1' || mergeoralign[l] == '2' )
 		{
 			newgapstr = "=";
@@ -1361,7 +1500,7 @@ static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000);
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000); // v6.708
-//		reporterr(       "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (float)len1/fftlog[m1], clus1, (float)len2/fftlog[m2], clus2 );
+//		reporterr(       "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
 
 		if( force_fft || ( use_fft && ffttry ) )
 		{
@@ -1400,7 +1539,7 @@ static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 					else
 					{
 //						reporterr(       "%d-%d", clus1, clus2 );
-						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+						pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					}
 					break;
 				default:
@@ -1420,27 +1559,41 @@ static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 
 		if( mergeoralign[l] == '1' ) // jissainiha nai. atarashii hairetsu ha saigo dakara.
 		{
-			adjustgapmap( strlen( mseq2[0] )-len2nocommongap+len2, gapmap, mseq2[0] );
-			restorecommongaps( njob, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
-			findnewgaps( clus2, 0, mseq2, gaplen );
-			insertnewgaps( njob, alreadyaligned, aseq, topol[l][1], topol[l][0], gaplen, gapmap, *alloclen, alg, '-' );
-			for( i=0; i<njob; i++ ) eq2dash( aseq[i] );
-			for( i=0; (m=topol[l][0][i])>-1; i++ ) alreadyaligned[m] = 1;
+			reporterr( "Check source!!!\n" );
+			exit( 1 );
 		}
 		if( mergeoralign[l] == '2' )
 		{
+//			if( localkeeplength ) ndeleted += deletenewinsertions( clus1, clus2, mseq1, mseq2, NULL );
 //			for( i=0; i<clus1; i++ ) reporterr(       ">STEP0 mseq1[%d] = \n%s\n", i, mseq1[i] );
 //			for( i=0; i<clus2; i++ ) reporterr(       ">STEP0 mseq2[%d] = \n%s\n", i, mseq2[i] );
-			adjustgapmap( strlen( mseq1[0] )-len1nocommongap+len1, gapmap, mseq1[0] );
-//			for( i=0; i<clus1; i++ ) reporterr(       ">STEP1 mseq1[%d] = \n%s\n", i, mseq1[i] );
-//			for( i=0; i<clus2; i++ ) reporterr(       ">STEP1 mseq2[%d] = \n%s\n", i, mseq2[i] );
-			restorecommongaps( njob, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
-//			for( i=0; i<clus1; i++ ) reporterr(       ">STEP2 mseq1[%d] = \n%s\n", i, mseq1[i] );
-//			for( i=0; i<clus2; i++ ) reporterr(       ">STEP2 mseq2[%d] = \n%s\n", i, mseq2[i] );
-			findnewgaps( clus1, 0, mseq1, gaplen );
-			insertnewgaps( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, *alloclen, alg, '-' );
-//			for( i=0; i<clus1; i++ ) reporterr(       ">STEP3 mseq1[%d] = \n%s\n", i, mseq1[i] );
-//			for( i=0; i<clus2; i++ ) reporterr(       ">STEP3 mseq2[%d] = \n%s\n", i, mseq2[i] );
+			gapmaplen = strlen( mseq1[0] )-len1nocommongap+len1;
+			adjustgapmap( gapmaplen, gapmap, mseq1[0] );
+#if 0
+			reporterr( "\n" );
+			for( i=0; i<clus1; i++ ) reporterr(       ">STEP1 mseq1[%d] = \n%s\n", i, mseq1[i] );
+			for( i=0; i<clus2; i++ ) reporterr(       ">STEP1 mseq2[%d] = \n%s\n", i, mseq2[i] );
+#endif
+//			if( clus1 + clus2 < njob ) restorecommongaps( njob, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+			if( smoothing )
+			{
+				restorecommongapssmoothly( njob, njob-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+				findnewgaps( clus1, 0, mseq1, gaplen );
+				insertnewgaps_bothorders( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, gapmaplen, *alloclen, alg, '-' );
+			}
+			else
+			{
+				restorecommongaps( njob, njob-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+				findnewgaps( clus1, 0, mseq1, gaplen );
+				insertnewgaps( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, *alloclen, alg, '-' );
+			}
+
+#if 0
+			reporterr( "\n" );
+			for( i=0; i<clus1; i++ ) reporterr(       ">STEP3 mseq1[%d] = \n%s\n", i, mseq1[i] );
+			for( i=0; i<clus2; i++ ) reporterr(       ">STEP3 mseq2[%d] = \n%s\n", i, mseq2[i] );
+#endif
+
 #if 0
 			for( i=0; i<njob; i++ ) eq2dash( aseq[i] );
 			for( i=0; i<clus1; i++ ) 
@@ -1457,10 +1610,12 @@ static int treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char
 			}
 			for( i=0; i<clus1; i++ ) eq2dash( mseq1[i] );
 			for( i=0; i<clus2; i++ ) eq2dash( mseq2[i] );
-#else
+#endif
+
+
 			eq2dashmatometehayaku( mseq1, clus1 );
 			eq2dashmatometehayaku( mseq2, clus2 );
-#endif
+
 			for( i=0; (m=topol[l][1][i])>-1; i++ ) alreadyaligned[m] = 1;
 		}
 
@@ -1643,20 +1798,20 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	int ***topol = NULL;
 	int *addmem = NULL;
 	Treedep *dep = NULL;
-	float **len = NULL;
+	double **len = NULL;
 	FILE *infp = NULL;
 //	FILE *adfp;
 	char c;
 	int alloclen;
-	float longer, shorter;
-	float lenfac;
-	float bunbo;
+	double longer, shorter;
+	double lenfac;
+	double bunbo;
 
 	FILE *orderfp = NULL, *hat2p = NULL;
 	int *grpseq = NULL;
 	char *tmpseq = NULL;
 	int  **pointt = NULL;
-	float **mtx = NULL; // by D. Mathog
+	double **mtx = NULL; // by D. Mathog
 	int *table1 = NULL;
 	char b[B];
 	int ien, nlim;
@@ -1665,7 +1820,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	int alignmentlength;
 	char *mergeoralign = NULL;
 	int foundthebranch;
-	int nsubalignments, maxmem;
+	int nsubalignments = 0, maxmem;
 	int **subtable = NULL;
 	int *insubtable = NULL;
 	int *preservegaps = NULL;
@@ -1673,10 +1828,14 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	int val;
 	char **tmpargv = NULL;
 	int iguidetree;
-	float *selfscore = NULL;
+	double *selfscore = NULL;
 	int calcpairdists;
 	int	**skiptable = NULL;
 	char algbackup;
+	char *originalgaps = NULL;
+	char **addbk = NULL;
+	int **deletelist = NULL;
+	FILE *dlf = NULL;
 
 
 	if( ngui )
@@ -1704,6 +1863,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	nthread = 0;
 #endif
 
+
 	if( ngui )
 	{
 		for( i=0; i<argc; i++ ) 
@@ -1745,6 +1905,20 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 		exit( 1 );
 	}
 
+	if( specificityconsideration != 0.0 && nlenmax)
+	{
+		if( nlenmax > 100000 )
+		{
+			reporterr( "\n" );
+			reporterr( "Too long to apply --allowshift or --unalignlevel>0\n" );
+			reporterr( "Please use the normal mode.\n" );
+			reporterr( "Please also note that MAFFT does not assume genomic rearrangements.\n" );
+			reporterr( "\n" );
+			exit( 1 );
+		}
+	}
+
+
 	if( subalignment )
 	{
 		readsubalignmentstable( njob, NULL, NULL, &nsubalignments, &maxmem );
@@ -1794,7 +1968,6 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	constants( njob, seq );
 
 
-
 #if 0
 	reporterr(       "params = %d, %d, %d\n", penalty, penalty_ex, offset );
 #endif
@@ -1943,7 +2116,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 		
 				for( j=i; j<njob; j++ ) 
 				{
-					mtx[i][j-i] = (float)commonsextet_p( table1, pointt[j] );
+					mtx[i][j-i] = (double)commonsextet_p( table1, pointt[j] );
 				} 
 				free( table1 ); table1 = NULL;
 			}
@@ -1957,13 +2130,13 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			{
 				if( nogaplen[i] > nogaplen[j] )
 				{
-					longer=(float)nogaplen[i];
-					shorter=(float)nogaplen[j];
+					longer=(double)nogaplen[i];
+					shorter=(double)nogaplen[j];
 				}
 				else
 				{
-					longer=(float)nogaplen[j];
-					shorter=(float)nogaplen[i];
+					longer=(double)nogaplen[j];
+					shorter=(double)nogaplen[i];
 				}
 //				if( tuplesize == 6 )
 				lenfac = 1.0 / ( shorter / longer * lenfacd + lenfacb / ( longer + lenfacc ) + lenfaca );
@@ -2007,23 +2180,54 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 		reporterr(       "Loading 'hat2' ... " );
 		prep = fopen( "hat2", "r" );
 		if( prep == NULL ) ErrorExit( "Make hat2." );
-		readhat2_float( prep, njob, name, mtx ); // name chuui
+		readhat2_double( prep, njob, name, mtx ); // name chuui
 		fclose( prep );
 		reporterr(       "done.\n" );
 	}
 #endif
 
+	if( nadd && keeplength )
+	{
+		originalgaps = (char *)calloc( nlenmax+1, sizeof( char) );
+		recordoriginalgaps( originalgaps, njob-nadd, seq );
+
+		if( mapout )
+		{
+			addbk = (char **)calloc( nadd+1, sizeof( char * ) );
+			for( i=0; i<nadd; i++ )
+			{
+				ien = strlen( seq[njob-nadd+i] );
+				addbk[i] = (char *)calloc( ien + 1, sizeof( char ) );
+				gappick0( addbk[i], seq[njob-nadd+i] );
+			}
+			addbk[nadd] = NULL;
+		}
+		else
+			addbk = NULL;
+	}
+	else
+	{
+		originalgaps = NULL;
+		addbk = NULL;
+	}
+	
+
+
 	for( iguidetree=0; iguidetree<nguidetree; iguidetree++ )
 //	for( iguidetree=0; ; iguidetree++ )
 	{
+
 		alg = algbackup; // tbfast wo disttbfast ni ketsugou shitatame.
 
+
+
 		topol = AllocateIntCub( njob, 2, 0 );
 		len = AllocateFloatMtx( njob, 2 );
 
 		if( iguidetree == nguidetree - 1 ) calcpairdists = 0;
 		else                               calcpairdists = 1;
 
+
 		if( calcpairdists ) selfscore = AllocateFloatVec( njob );
 
 		if( callback && callback( 0, 25, "Guide tree" ) ) goto chudan;
@@ -2033,6 +2237,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			nguidetree = 1; //  iranai
 			reporterr(       "Loading a tree ... " );
 			loadtree( njob, topol, len, name, nogaplen, dep );
+//			loadtop( njob, topol, len, name, NULL, dep ); // 2015/Jan/13, not yet checked
 		}
 		else if( topin )
 		{
@@ -2054,7 +2259,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			if( subalignment ) // merge error no tame
 			{
 				reporterr(       "Constructing a UPGMA tree ... " );
-				fixed_supg_float_realloc_nobk_halfmtx_treeout_constrained( njob, mtx, topol, len, name, nlen, dep, nsubalignments, subtable, !calcpairdists );
+				fixed_supg_double_realloc_nobk_halfmtx_treeout_constrained( njob, mtx, topol, len, name, nlen, dep, nsubalignments, subtable, !calcpairdists );
 				if( !calcpairdists ) 
 				{
 					FreeFloatHalfMtx( mtx, njob ); mtx = NULL;
@@ -2063,7 +2268,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			else if( treeout ) // merge error no tame
 			{
 				reporterr(       "Constructing a UPGMA tree ... " );
-				fixed_musclesupg_float_realloc_nobk_halfmtx_treeout( njob, mtx, topol, len, name, nogaplen, dep, !calcpairdists );
+				fixed_musclesupg_double_realloc_nobk_halfmtx_treeout( njob, mtx, topol, len, name, nogaplen, dep, !calcpairdists );
 				if( !calcpairdists )
 				{
 					FreeFloatHalfMtx( mtx, njob ); mtx = NULL;
@@ -2072,7 +2277,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			else
 			{
 				reporterr(       "Constructing a UPGMA tree ... " );
-				fixed_musclesupg_float_realloc_nobk_halfmtx( njob, mtx, topol, len, dep, 1, !calcpairdists );
+				fixed_musclesupg_double_realloc_nobk_halfmtx( njob, mtx, topol, len, dep, 1, !calcpairdists );
 				if( !calcpairdists )
 				{
 					FreeFloatHalfMtx( mtx, njob ); mtx = NULL;
@@ -2083,6 +2288,16 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 //			ErrorExit( "Incorrect tree\n" );
 		reporterr(       "\ndone.\n\n" );
 		if( callback && callback( 0, 50, "Guide tree" ) ) goto chudan;
+
+		if( sparsepickup && iguidetree == nguidetree-1 )
+		{
+			reporterr(       "Sparsepickup! \n" );
+			pickup( njob, nogaplen, topol, name, seq );
+			reporterr(       "done. \n" );
+			SHOWVERSION;
+			goto chudan;
+		}
+
 	
 		orderfp = fopen( "order", "w" );
 		if( !orderfp )
@@ -2099,6 +2314,8 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			fprintf( orderfp, "%d\n", j );
 		}
 		fclose( orderfp );
+
+
 	
 		if( ( treeout || distout )  && noalign ) 
 		{
@@ -2115,7 +2332,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 #if 0
 			utree = 0; counteff( njob, topol, len, eff ); utree = 1;
 #else
-			counteff_simple_float_nostatic( njob, topol, len, eff );
+			counteff_simple_double_nostatic( njob, topol, len, eff );
 #endif
 		}
 		else
@@ -2134,7 +2351,8 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	
 		bseq = AllocateCharMtx( njob, nlenmax*2+1 );
 		alloclen = nlenmax*2+1;
-	
+
+
 	
 		if( nadd )
 		{
@@ -2148,7 +2366,8 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 					reporterr(       "# The original %d sequences must be aligned\n", njob-nadd );
 					reporterr(       "# alignmentlength = %d, but strlen(seq[%d])=%d\n", alignmentlength, i, (int)strlen( seq[i] ) );
 					reporterr(       "#################################################################################\n" );
-					exit( 1 );
+					goto chudan; // TEST!!
+					//exit( 1 );
 				}
 			}
 			if( addprofile )
@@ -2260,8 +2479,10 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 				for( i=njob-nadd; i<njob; i++ ) gappick0( bseq[i], seq[i] );
 			}
 	
+//			if( !keeplength ) commongappick( njob-nadd, seq );
 			commongappick( njob-nadd, seq );
 			for( i=0; i<njob-nadd; i++ ) strcpy( bseq[i], seq[i] );
+
 		}
 //--------------- kokokara ----
 		else if( subalignment )
@@ -2302,7 +2523,8 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 						}
 						reporterr(       "###############################################################################\n" );
 						reporterr(       "\n" );
-						exit( 1 );
+						goto chudan; // TEST!!
+						//exit( 1 );
 					}
 					insubtable[subtable[i][j]] = 1;
 				}
@@ -2344,7 +2566,8 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 					}
 					reporterr(       "############################################################################### \n" );
 					reporterr(       "\n" );
-					exit( 1 );
+					goto chudan; // TEST!!
+					//exit( 1 );
 				}
 //				commongappick( seq[subtable[i]], subalignment[i] ); // irukamo
 			}
@@ -2475,6 +2698,7 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 			else
 #endif
 			{
+//				if( treebase( keeplength && (iguidetree==nguidetree-1), nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, dep, eff, NULL, NULL, deletemap, deletelag, &alloclen, callback ) ) goto chudan;
 				if( treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, dep, eff, NULL, NULL, &alloclen, callback ) ) goto chudan;
 			}
 		}
@@ -2487,6 +2711,12 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 
 
 
+//		reporterr( "\nbseq[njob-3] = %s\n", bseq[njob-3] );
+//		reporterr( "bseq[njob-2] = %s\n", bseq[njob-2] );
+//		reporterr( "bseq[njob-1] = %s\n", bseq[njob-1] );
+
+
+
 #if 1
 // Distance matrix from MSA SEPARATELYCALCPAIRDISTS
 //		if( iguidetree < nguidetree-1 )
@@ -2568,11 +2798,12 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 				free( targ );
 #endif
 			}
-			FreeIntMtx( skiptable );
+			if( skiptable) FreeIntMtx( skiptable ); skiptable = NULL;
 			reporterr(       "\ndone.\n\n" );
 		}
 // Distance matrix from MSA end
 #endif
+
 		if( calcpairdists ) 
 		{
 			free( selfscore );
@@ -2586,6 +2817,42 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 #endif
 //	fclose( trap_g );
 
+	if( keeplength )
+	{
+
+		dlf = fopen( "_deletelist", "w" );
+		deletelist = (int **)calloc( nadd+1, sizeof( int * ) );
+		for( i=0; i<nadd; i++ )
+		{
+			deletelist[i] = calloc( 1, sizeof( int ) );
+			deletelist[i][0] = -1;
+		}
+		deletelist[nadd] = NULL;
+		ndeleted = deletenewinsertions_whole( njob-nadd, nadd, bseq, bseq+njob-nadd, deletelist );
+
+		for( i=0; i<nadd; i++ )
+		{
+			if( deletelist[i] )
+				for( j=0; deletelist[i][j]!=-1; j++ )
+					fprintf( dlf, "%d %d\n", njob-nadd+i, deletelist[i][j] ); // 0origin
+		}
+		fclose( dlf );
+
+		restoreoriginalgaps( njob, bseq, originalgaps );
+
+		if( mapout )
+		{
+			dlf = fopen( "_deletemap", "w" );
+			reconstructdeletemap( nadd, addbk, deletelist, bseq+njob-nadd, dlf, name+njob-nadd );
+			FreeCharMtx( addbk );
+			addbk = NULL;
+			fclose( dlf );
+		}
+
+		FreeIntMtx( deletelist );
+		deletelist = NULL;
+	}
+
 	if( scoreout )
 	{
 		unweightedspscore = plainscore( njob, bseq );
@@ -2626,7 +2893,18 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 		writeData_pointer( stdout, njob, name, nlen, bseq );
 	} 
 
+	if( spscoreout ) reporterr( "Unweighted sum-of-pairs score = %10.5f\n", sumofpairsscore( njob, bseq ) );
 	SHOWVERSION;
+	if( ndeleted > 0 )
+	{
+		reporterr( "\nTo keep the alignment length, %d letters were DELETED.\n", ndeleted );
+		if( mapout )
+			reporterr( "The deleted letters are shown in the (filename).map file.\n" );
+		else
+			reporterr( "To know the positions of deleted letters, rerun the same command with the --mapout option.\n" );
+	}
+
+
 
 	if( subalignment )
 	{
@@ -2659,6 +2937,9 @@ int disttbfast( int ngui, int lgui, char **namegui, char **seqgui, int argc, cha
 	freeconstants();
 	closeFiles();
 	FreeCommonIP();
+	if( originalgaps ) free( originalgaps ); originalgaps = NULL;
+	if( deletelist ) FreeIntMtx( deletelist ); deletelist = NULL;
+
 	return( val );
 
 chudan:
@@ -2700,6 +2981,18 @@ chudan:
 	if( bseq ) FreeCharMtx( bseq ); bseq = NULL;
 	if( selfscore ) free( selfscore ); selfscore = NULL;
 	if( skiptable ) FreeIntMtx( skiptable ); skiptable = NULL;
+	if( originalgaps ) free( originalgaps ); originalgaps = NULL;
+	if( deletelist ) FreeIntMtx( deletelist ); deletelist = NULL;
+
+
+	if( subtable ) FreeIntMtx( subtable ); subtable = NULL;
+	if( insubtable ) free( insubtable ); insubtable = NULL;
+	for( i=0; i<nsubalignments; i++ ) 
+	{
+		if( subalnpt[i] ) free( subalnpt[i] ); subalnpt[i] = NULL;
+	}
+	if( subalnpt ) free( subalnpt ); subalnpt = NULL;
+	if( preservegaps ) free( preservegaps ); preservegaps = NULL;
 
 	freeconstants();
 	closeFiles();
