@@ -16,7 +16,7 @@ static double autosubalignment;
 static void calcmaxdistclass( void )
 {
 	int c;
-	float rep;
+	double rep;
 	for( c=0; c<ndistclass; c++ )
 	{
 		rep = (double) 2 * c / ndistclass; // dist:0-2 for dist2offset 
@@ -39,6 +39,7 @@ void arguments( int argc, char *argv[] )
 	nthread = 1;
 	randomseed = 0;
 	scoreout = 0;
+	spscoreout = 0;
 	parallelizationstrategy = BAATARI1;
 	intop = 0;
 	intree = 0;
@@ -222,9 +223,15 @@ void arguments( int argc, char *argv[] )
 //					fprintf( stderr, "specificityconsideration = %f\n", specificityconsideration );
 					--argc; 
 					goto nextoption;
+#if 0
 				case 'S' :
-					scoreout = 1;
+					scoreout = 1; // for checking parallel calculation
 					break;
+#else
+				case 'S' :
+					spscoreout = 1; // 2014/Dec/30, sp score
+					break;
+#endif
 #if 0
 				case 's' :
 					RNAscoremtx = 'r';
@@ -351,6 +358,11 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "autosubalignment = %f\n", autosubalignment );
 					--argc;
 					goto nextoption;
+				case 'W':
+					minimumweight = atof( *++argv );
+					fprintf( stderr, "minimumweight = %f\n", minimumweight );
+					--argc;
+					goto nextoption;
 				case 'z':
 					fftThreshold = myatoi( *++argv );
 					--argc;
@@ -1017,6 +1029,8 @@ exit( 1 );
 #endif
 
 
+	if( spscoreout ) reporterr( "Unweighted sum-of-pairs score = %10.5f\n", sumofpairsscore( njob, res_g ) );
+
 	SHOWVERSION;
 	return( 0 );
 }
