@@ -16,13 +16,13 @@
 #include <math.h>
 #include <ctype.h>
 #include "mtxutl.h"
-#include <float.h>
+//#include <double.h>
 #include <stdarg.h>
 #ifdef enablemultithread
 #include <pthread.h>
 #endif
 
-#define VERSION "7.221"
+#define VERSION "7.245"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION " alg=%c, model=%s, amax=%3.1f\n%d thread(s)\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
@@ -126,7 +126,7 @@ extern int tbrweight;
 extern int disopt;
 extern int pamN;
 extern int checkC;
-extern float geta2;
+extern double geta2;
 extern int treemethod;
 extern int kimuraR;
 extern char *swopt;
@@ -135,8 +135,8 @@ extern int score_check;
 extern char *inputfile;
 extern char *addfile;
 extern int addprofile;
-extern float consweight_multi;
-extern float consweight_rna;
+extern double consweight_multi;
+extern double consweight_rna;
 extern char RNAscoremtx;
 
 extern char *signalSM;
@@ -156,24 +156,24 @@ extern double Cscore_m_1( char **, int, int, double ** );
 extern double score_m_1(  char **, int, int, double ** );
 extern double score_calc0( char **, int, double **, int );
 extern char seqcheck( char ** );
-extern float substitution( char *, char * );
-extern float substitution_score( char *, char * );
-extern float substitution_nid( char *, char * );
-extern float substitution_hosei( char *, char * );
+extern double substitution( char *, char * );
+extern double substitution_score( char *, char * );
+extern double substitution_nid( char *, char * );
+extern double substitution_hosei( char *, char * );
 extern double ipower( double, int );
-extern float translate_and_Calign();
-extern float A__align();
-extern float A__align11();
-extern float A__align_gapmap();
-extern float partA__align();
-extern float L__align11( double **scoringmtx, float scoreoffset, char **seq1, char **seq2, int alloclen, int *off1pt, int *off2pt );
-extern float G__align11();
-extern float Falign();
-extern float Falign_localhom();
-extern float Conalign();
-extern float Aalign();
-extern float imp_match_out_sc( int, int );
-extern float part_imp_match_out_sc( int, int );
+extern double translate_and_Calign();
+extern double A__align();
+extern double A__align11();
+extern double A__align_gapmap();
+extern double partA__align();
+extern double L__align11( double **scoringmtx, double scoreoffset, char **seq1, char **seq2, int alloclen, int *off1pt, int *off2pt );
+extern double G__align11();
+extern double Falign();
+extern double Falign_localhom();
+extern double Conalign();
+extern double Aalign();
+extern double imp_match_out_sc( int, int );
+extern double part_imp_match_out_sc( int, int );
 extern void ErrorExit();
 extern void cpmx_calc();
 extern void intergroup_score( char **, char **, double *, double *, int, int, int, double * );
@@ -194,7 +194,7 @@ typedef struct _LocalHom
 	int overlapaa;
 	int extended;
 	double importance;
-	float fimportance;
+	double fimportance;
 	double wimportance;
 	char korh;
 } LocalHom;
@@ -259,17 +259,17 @@ typedef struct _Fukusosuu
 typedef struct _Gappattern
 {
 	int len;
-	float freq;
+	double freq;
 } Gappat;
 
 typedef struct _RNApair
 {
 	int uppos;
-	float upscore;
+	double upscore;
 	int downpos;
-	float downscore;
+	double downscore;
 	int bestpos;
-	float bestscore;
+	double bestscore;
 } RNApair;
 
 typedef struct _Treedep
@@ -277,15 +277,15 @@ typedef struct _Treedep
 	int child0;
 	int child1;
 	int done;
-	float distfromtip;
+	double distfromtip;
 } Treedep;
 
 typedef struct _Addtree
 {
 	int nearest;
-	float dist1;
+	double dist1;
 	char *neighbors;
-	float dist2;
+	double dist2;
 } Addtree;
 
 #include "fft.h"
@@ -315,6 +315,7 @@ extern int spscoreout;
 extern int outnumber;
 
 extern int legacygapcost;
+extern double minimumweight;
 
 extern TLS char *newgapstr;
 
