@@ -19,6 +19,7 @@ static int laste;
 static int lastm;
 static int lastsubopt;
 static int lastonce;
+static int usenaivescoreinsteadofalignmentscore;
 
 typedef struct _lastres
 {
@@ -232,10 +233,10 @@ static int countcomma( char *s )
 	return( v );
 }
 
-static float recallpairfoldalign( char **mseq1, char **mseq2, int m1, int m2, int *of1pt, int *of2pt, int alloclen )
+static double recallpairfoldalign( char **mseq1, char **mseq2, int m1, int m2, int *of1pt, int *of2pt, int alloclen )
 {
 	static FILE *fp = NULL;
-	float value;
+	double value;
 	char *aln1;
 	char *aln2;
 	int of1tmp, of2tmp;
@@ -268,7 +269,7 @@ static float recallpairfoldalign( char **mseq1, char **mseq2, int m1, int m2, in
 		value = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, of1pt, of2pt );
 	}
 
-//	value = (float)naivepairscore11( *mseq1, *mseq2, penalty ); // nennnotame
+//	value = (double)naivepairscore11( *mseq1, *mseq2, penalty ); // nennnotame
 
 	if( aln1[0] == 0 )
 	{
@@ -1210,7 +1211,7 @@ static void calllara( int nseq, char **mseq, char *laraarg )
 	}
 }
 
-static float recalllara( char **mseq1, char **mseq2, int alloclen )
+static double recalllara( char **mseq1, char **mseq2, int alloclen )
 {
 	static FILE *fp = NULL;
 	static char *ungap1;
@@ -1219,7 +1220,7 @@ static float recalllara( char **mseq1, char **mseq2, int alloclen )
 	static char *ori2;
 //	int res;
 	static char com[10000];
-	float value;
+	double value;
 
 
 	if( fp == NULL )
@@ -1265,7 +1266,7 @@ static float recalllara( char **mseq1, char **mseq2, int alloclen )
 		exit( 1 );
 	}
 
-	value = (float)naivepairscore11( *mseq1, *mseq2, penalty );
+	value = (double)naivepairscore11( *mseq1, *mseq2, penalty );
 
 //	fclose( fp ); // saigo dake yatta houga yoi.
 
@@ -1273,12 +1274,12 @@ static float recalllara( char **mseq1, char **mseq2, int alloclen )
 }
 
 
-static float calldafs_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char **bpp2, int alloclen, int i, int j )
+static double calldafs_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char **bpp2, int alloclen, int i, int j )
 {
 	FILE *fp;
 	int res;
 	char *com;
-	float value;
+	double value;
 	char *dirname;
 
 
@@ -1371,7 +1372,7 @@ static float calldafs_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char
 //	fprintf( stderr, "*mseq1 = %s\n", *mseq1 );
 //	fprintf( stderr, "*mseq2 = %s\n", *mseq2 );
 
-	value = (float)naivepairscore11( *mseq1, *mseq2, penalty );
+	value = (double)naivepairscore11( *mseq1, *mseq2, penalty );
 
 #if 0
 	sprintf( com, "rm -rf %s > /dev/null 2>&1", dirname );
@@ -1390,12 +1391,12 @@ static float calldafs_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char
 	return( value );
 }
 
-static float callmxscarna_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char **bpp2, int alloclen, int i, int j )
+static double callmxscarna_giving_bpp( char **mseq1, char **mseq2, char **bpp1, char **bpp2, int alloclen, int i, int j )
 {
 	FILE *fp;
 	int res;
 	char *com;
-	float value;
+	double value;
 	char *dirname;
 
 
@@ -1490,7 +1491,7 @@ static float callmxscarna_giving_bpp( char **mseq1, char **mseq2, char **bpp1, c
 //	fprintf( stderr, "*mseq1 = %s\n", *mseq1 );
 //	fprintf( stderr, "*mseq2 = %s\n", *mseq2 );
 
-	value = (float)naivepairscore11( *mseq1, *mseq2, penalty );
+	value = (double)naivepairscore11( *mseq1, *mseq2, penalty );
 
 #if 0
 	sprintf( com, "rm -rf %s > /dev/null 2>&1", dirname );
@@ -1541,7 +1542,7 @@ static void readhat4( FILE *fp, char ***bpp )
 		}
 		fgets( oneline, 999, fp );
 //		fprintf( stderr, "oneline=%s\n", oneline );
-//		sscanf( oneline, "%d %d %f", &posi, &posj, &prob );
+//		sscanf( oneline, "%d %d %lf", &posi, &posj, &prob );
 //		fprintf( stderr, "%d %d -> %f\n", posi, posj, prob );
 		*bpp = realloc( *bpp, (bppsize+2) * sizeof( char * ) );
 		(*bpp)[bppsize] = calloc( 100, sizeof( char ) );
@@ -1629,6 +1630,7 @@ void arguments( int argc, char *argv[] )
 	RNAppenalty = NOTSPECIFIED;
 	RNApthr = NOTSPECIFIED;
 	specificityconsideration = 0.0;
+	usenaivescoreinsteadofalignmentscore = 0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -1805,6 +1807,9 @@ void arguments( int argc, char *argv[] )
 				case 'Y':
 					alg = 'Y'; // nadd>0 no toki nomi. moto no hairetsu to atarashii hairetsuno alignmnt -> L;
 					break;
+				case 'Z':
+					usenaivescoreinsteadofalignmentscore = 1;
+					break;
 				case 's':
 					alg = 's';
 					break;
@@ -1906,11 +1911,12 @@ int countamino( char *s, int end )
 	return( val );
 }
 
-static float score2dist( float pscore, double selfscore1, double selfscore2)
+static double score2dist( double pscore, double selfscore1, double selfscore2)
 {
-	float val;
+	double val;
 	double bunbo;
 //	fprintf( stderr, "In score2dist\n" );
+
 	if( (bunbo=MIN( selfscore1, selfscore2 )) == 0.0 )
 		val = 2.0;
 	else if( bunbo < pscore ) // mondai ari
@@ -1927,14 +1933,14 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 	int i, ilim, j, jst;
 	int off1, off2, dum1, dum2, thereisx;
 	int intdum;
-	float pscore = 0.0; // by D.Mathog
+	double pscore = 0.0; // by D.Mathog
 	double *effarr1;
 	double *effarr2;
 	char **mseq1, **mseq2, **distseq1, **distseq2, **dumseq1, **dumseq2;
 	char **aseq;
 	double **dynamicmtx = NULL;
-	float dist;
-	float scoreoffset;
+	double dist;
+	double scoreoffset;
 
 // thread_arg
 	int thread_no = targ->thread_no;
@@ -2085,11 +2091,11 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 					if( nadd && njob-nadd <= j && njob-nadd <= i ) // new sequence doushi ha mushi
 						pscore = 0.0;
 					else
-						pscore = (float)lastresx[i][j].score; // all pair
+						pscore = (double)lastresx[i][j].score; // all pair
 					break;
 				case( 'r' ):
 					if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) )
-						pscore = (float)lastresx[i][j-(njob-nadd)].score;
+						pscore = (double)lastresx[i][j-(njob-nadd)].score;
 					else
 						pscore = 0.0;
 					break;
@@ -2098,91 +2104,123 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 						pscore = 0.0;
 					else
 					{
-						if( store_localhom )
+						if( usenaivescoreinsteadofalignmentscore )
 						{
-							pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
-							if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
-#if 1
-							if( specificityconsideration > 0.0 )
-							{
-								dist = score2dist( pscore, selfscore[i], selfscore[j] );
-								if( ( scoreoffset = dist2offset( dist ) ) < 0.0 )
-								{
-									makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
-									strcpy( mseq1[0], seq[i] );
-									strcpy( mseq2[0], seq[j] );
-									L__align11( dynamicmtx, scoreoffset, mseq1, mseq2, alloclen, &off1, &off2 );
-								}
-							}
-#endif
+							L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+							pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
 						}
 						else
-							pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+						{
+							if( store_localhom )
+							{
+								pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+								if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
+#if 1
+								if( specificityconsideration > 0.0 )
+								{
+									dist = score2dist( pscore, selfscore[i], selfscore[j] );
+									if( ( scoreoffset = dist2offset( dist ) ) < 0.0 )
+									{
+										makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
+										strcpy( mseq1[0], seq[i] );
+										strcpy( mseq2[0], seq[j] );
+										L__align11( dynamicmtx, scoreoffset, mseq1, mseq2, alloclen, &off1, &off2 );
+									}
+								}
+#endif
+							}
+							else
+								pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+						}
 					}
 //					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
 					break;
 				case( 'Y' ):
 					if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) ) // new sequence vs exiting sequence nomi keisan
 					{
-						if( store_localhom )
+						if( usenaivescoreinsteadofalignmentscore )
 						{
-							pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
-							if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
+							L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+							pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
 						}
 						else
-							pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+						{
+							if( store_localhom )
+							{
+								pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+								if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
+							}
+							else
+								pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+						}
 					}
 					else
 						pscore = 0.0;
 					break;
 				case( 'A' ):
-					if( store_localhom )
+					if( usenaivescoreinsteadofalignmentscore )
 					{
-						pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
-						if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+						G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+						pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
+					}
+					else
+					{
+						if( store_localhom )
+						{
+							pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+							if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+#if 1
+							if( specificityconsideration > 0.0 )
+							{
+								dist = score2dist( pscore, selfscore[i], selfscore[j] );
+//								dist = score2dist( L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ), selfscore[i], selfscore[j] ); // 2014/Feb/20
+								if( dist2offset( dist ) < 0.0 )
+								{
+									makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
+									strcpy( mseq1[0], seq[i] );
+									strcpy( mseq2[0], seq[j] );
+									G__align11( dynamicmtx, mseq1, mseq2, alloclen, outgap, outgap );
+					
+								}
+//								pscore = (double)naivepairscore11( *mseq1, *mseq2, 0.0 );
+							}
+#endif
+						}
+						else
+							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+					}
+					off1 = off2 = 0;
+					break;
+				case( 'N' ):
+					if( usenaivescoreinsteadofalignmentscore )
+					{
+						genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
+						pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
+					}
+					else
+					{
+//						pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
+						pscore = genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
+						if( thereisx )
+						{
+							strcpy( dumseq1[0], distseq1[0] );
+							strcpy( dumseq2[0], distseq2[0] );
+							pscore = genL__align11( n_dis_consweight_multi, dumseq1, dumseq2, alloclen, &dum1, &dum2 ); // uwagaki
+						}
 #if 1
 						if( specificityconsideration > 0.0 )
 						{
 							dist = score2dist( pscore, selfscore[i], selfscore[j] );
-//							dist = score2dist( L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ), selfscore[i], selfscore[j] ); // 2014/Feb/20
 							if( dist2offset( dist ) < 0.0 )
 							{
 								makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
 								strcpy( mseq1[0], seq[i] );
 								strcpy( mseq2[0], seq[j] );
-								G__align11( dynamicmtx, mseq1, mseq2, alloclen, outgap, outgap );
-				
+								genL__align11( dynamicmtx, mseq1, mseq2, alloclen, &off1, &off2 );
 							}
-//							pscore = (float)naivepairscore11( *mseq1, *mseq2, 0.0 );
 						}
 #endif
 					}
-					else
-						pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
-					off1 = off2 = 0;
-					break;
-				case( 'N' ):
-//					pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
-					pscore = genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
-					if( thereisx )
-					{
-						strcpy( dumseq1[0], distseq1[0] );
-						strcpy( dumseq2[0], distseq2[0] );
-						pscore = genL__align11( n_dis_consweight_multi, dumseq1, dumseq2, alloclen, &dum1, &dum2 ); // uwagaki
-					}
-#if 1
-					if( specificityconsideration > 0.0 )
-					{
-						dist = score2dist( pscore, selfscore[i], selfscore[j] );
-						if( dist2offset( dist ) < 0.0 )
-						{
-							makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
-							strcpy( mseq1[0], seq[i] );
-							strcpy( mseq2[0], seq[j] );
-							genL__align11( dynamicmtx, mseq1, mseq2, alloclen, &off1, &off2 );
-						}
-					}
-#endif
 					break;
 				case( 't' ):
 					off1 = off2 = 0;
@@ -2245,6 +2283,11 @@ static void *athread( void *arg ) // alg='R', alg='r' -> tsukawarenai.
 					putlocalhom2( mseq1[0], mseq2[0], localhomtable[i]+j, off1, off2, (int)pscore, strlen( mseq1[0] ) );
 			}
 			pscore = score2dist( pscore, selfscore[i], selfscore[j] );
+
+//			pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 );
+//			pscore = score2dist( pscore, selfscore[i], selfscore[j] );
+//			reporterr( "->pscore = %f\n", pscore );
+
 		}
 		else
 		{
@@ -2287,7 +2330,7 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 {
 	int i, j, ilim, jst, jj;
 	int off1, off2, dum1, dum2, thereisx;
-	float pscore = 0.0; // by D.Mathog
+	double pscore = 0.0; // by D.Mathog
 	FILE *hat2p, *hat3p;
 	double **distancemtx;
 	double *selfscore;
@@ -2300,8 +2343,8 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 	char ***bpp = NULL; // mxscarna no toki dake
 	char **distseq1, **distseq2;
 	char **dumseq1, **dumseq2;
-	float dist;
-	float scoreoffset;
+	double dist;
+	double scoreoffset;
 
 	if( store_localhom )
 	{
@@ -2564,63 +2607,79 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 							off1 = off2 = 0;
 							break;
 						case( 'A' ):
-							if( store_localhom )
+							if( usenaivescoreinsteadofalignmentscore )
 							{
-								pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
-								if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+								G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+								pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
+							}
+							else
+							{
+								if( store_localhom )
+								{
+									pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, outgap, outgap );
+									if( thereisx ) pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+#if 1
+									if( specificityconsideration > 0.0 )
+									{
+										dist = score2dist( pscore, selfscore[i], selfscore[j] );
+//										dist = score2dist( L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ), selfscore[i], selfscore[j] ); // 2014/Feb/20
+										if( dist2offset( dist ) < 0.0 )
+										{
+											makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
+											strcpy( mseq1[0], seq[i] );
+											strcpy( mseq2[0], seq[j] );
+											G__align11( dynamicmtx, mseq1, mseq2, alloclen, outgap, outgap );
+										}
+//										pscore = (double)naivepairscore11( *mseq1, *mseq2, 0.0 );
+									}
+#endif
+								}
+								else
+									pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
+							}
+							off1 = off2 = 0;
+							break;
+						case( 'N' ):
+//							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
+							if( usenaivescoreinsteadofalignmentscore )
+							{
+								genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
+								pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
+							}
+							else
+							{
+								pscore = genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
+								if( thereisx )
+								{
+									strcpy( dumseq1[0], distseq1[0] );
+									strcpy( dumseq2[0], distseq2[0] );
+									pscore = genL__align11( n_dis_consweight_multi, dumseq1, dumseq2, alloclen, &dum1, &dum2 ); // uwagaki
+								}
 #if 1
 								if( specificityconsideration > 0.0 )
 								{
+//									fprintf( stderr, "dist = %f\n", score2dist( pscore, selfscore[i], selfscore[j] ) );
 									dist = score2dist( pscore, selfscore[i], selfscore[j] );
-//									dist = score2dist( L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ), selfscore[i], selfscore[j] ); // 2014/Feb/20
 									if( dist2offset( dist ) < 0.0 )
 									{
 										makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
 										strcpy( mseq1[0], seq[i] );
 										strcpy( mseq2[0], seq[j] );
-										G__align11( dynamicmtx, mseq1, mseq2, alloclen, outgap, outgap );
+										genL__align11( dynamicmtx, mseq1, mseq2, alloclen, &off1, &off2 );
 									}
-//									pscore = (float)naivepairscore11( *mseq1, *mseq2, 0.0 );
 								}
 #endif
 							}
-							else
-								pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // uwagaki
-							off1 = off2 = 0;
-							break;
-						case( 'N' ):
-//							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, alloclen );
-							pscore = genL__align11( n_dis_consweight_multi, mseq1, mseq2, alloclen, &off1, &off2 );
-							if( thereisx )
-							{
-								strcpy( dumseq1[0], distseq1[0] );
-								strcpy( dumseq2[0], distseq2[0] );
-								pscore = genL__align11( n_dis_consweight_multi, dumseq1, dumseq2, alloclen, &dum1, &dum2 ); // uwagaki
-							}
-#if 1
-							if( specificityconsideration > 0.0 )
-							{
-//								fprintf( stderr, "dist = %f\n", score2dist( pscore, selfscore[i], selfscore[j] ) );
-								dist = score2dist( pscore, selfscore[i], selfscore[j] );
-								if( dist2offset( dist ) < 0.0 )
-								{
-									makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
-									strcpy( mseq1[0], seq[i] );
-									strcpy( mseq2[0], seq[j] );
-									genL__align11( dynamicmtx, mseq1, mseq2, alloclen, &off1, &off2 );
-								}
-							}
-#endif
 							break;
 						case( 'R' ):
 							if( nadd && njob-nadd <= j && njob-nadd <= i ) // new sequence doushi ha mushi
 								pscore = 0.0;
 							else
-								pscore = (float)lastresx[i][j].score; // all pair
+								pscore = (double)lastresx[i][j].score; // all pair
 							break;
 						case( 'r' ):
 							if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) )
-								pscore = (float)lastresx[i][j-(njob-nadd)].score;
+								pscore = (double)lastresx[i][j-(njob-nadd)].score;
 							else
 								pscore = 0.0;
 							break;
@@ -2629,39 +2688,55 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 								pscore = 0.0;
 							else
 							{
-								if( store_localhom )
+								if( usenaivescoreinsteadofalignmentscore )
 								{
-									pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 ); // all pair
-									if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // all pair
-#if 1
-									if( specificityconsideration > 0.0 )
-									{
-										dist = score2dist( pscore, selfscore[i], selfscore[j] );
-										if( ( scoreoffset = dist2offset( dist ) ) < 0.0 )
-										{
-											makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
-											strcpy( mseq1[0], seq[i] );
-											strcpy( mseq2[0], seq[j] );
-											L__align11( dynamicmtx, scoreoffset, mseq1, mseq2, alloclen, &off1, &off2 );
-										}
-									}
-#endif
+									L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+									pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
 								}
 								else
-									pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // all pair
+								{
+									if( store_localhom )
+									{
+										pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 ); // all pair
+										if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // all pair
+#if 1
+										if( specificityconsideration > 0.0 )
+										{
+											dist = score2dist( pscore, selfscore[i], selfscore[j] );
+											if( ( scoreoffset = dist2offset( dist ) ) < 0.0 )
+											{
+												makedynamicmtx( dynamicmtx, n_dis_consweight_multi, 0.5 * dist ); // upgma ni awaseru.
+												strcpy( mseq1[0], seq[i] );
+												strcpy( mseq2[0], seq[j] );
+												L__align11( dynamicmtx, scoreoffset, mseq1, mseq2, alloclen, &off1, &off2 );
+											}
+										}
+#endif
+									}
+									else
+										pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // all pair
+								}
 							}
 //							pscore = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, distseq1, distseq2, alloclen ); // CHUUI!!!!!!
 							break;
 						case( 'Y' ):
 							if( nadd == 0 || ( i < njob-nadd && njob-nadd <= j ) ) // new sequence vs exiting sequence nomi keisan
 							{
-								if( store_localhom )
+								if( usenaivescoreinsteadofalignmentscore )
 								{
-									pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
-									if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
+									L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+									pscore = (double)naivepairscore11( mseq1[0], mseq2[0], 0.0 ); // uwagaki
 								}
 								else
-									pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+								{
+									if( store_localhom )
+									{
+										pscore = L__align11( n_dis_consweight_multi, 0.0, mseq1, mseq2, alloclen, &off1, &off2 );
+										if( thereisx ) pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 ); // uwagaki
+									}
+									else
+										pscore = L__align11_noalign( n_dis_consweight_multi, distseq1, distseq2 );
+								}
 							}
 							else
 								pscore = 0.0;
