@@ -9,15 +9,15 @@
 #define FASTMATCHCALC 1
 
 #if 0
-static void st_OpeningGapCount( float *ogcp, int clus, char **seq, double *eff, int len )
+static void st_OpeningGapCount( double *ogcp, int clus, char **seq, double *eff, int len )
 {
 	int i, j, gc, gb; 
-	float feff;
+	double feff;
 	
 	for( i=0; i<len; i++ ) ogcp[i] = 0.0;
 	for( j=0; j<clus; j++ ) 
 	{
-		feff = (float)eff[j];
+		feff = (double)eff[j];
 		gc = 0;
 		for( i=0; i<len; i++ ) 
 		{
@@ -30,15 +30,15 @@ static void st_OpeningGapCount( float *ogcp, int clus, char **seq, double *eff,
 	}
 }
 
-static void st_FinalGapCount( float *fgcp, int clus, char **seq, double *eff, int len )
+static void st_FinalGapCount( double *fgcp, int clus, char **seq, double *eff, int len )
 {
 	int i, j, gc, gb; 
-	float feff;
+	double feff;
 	
 	for( i=0; i<len; i++ ) fgcp[i] = 0.0;
 	for( j=0; j<clus; j++ ) 
 	{
-		feff = (float)eff[j];
+		feff = (double)eff[j];
 		gc = ( seq[j][0] == '-' );
 		for( i=1; i<len+1; i++ ) 
 		{
@@ -57,8 +57,8 @@ static void st_FinalGapCount( float *fgcp, int clus, char **seq, double *eff, in
 		
 
 static TLS int impalloclen = 0;
-static TLS float **impmtx = NULL;
-float part_imp_match_out_sc( int i1, int j1 )
+static TLS double **impmtx = NULL;
+double part_imp_match_out_sc( int i1, int j1 )
 {
 //	fprintf( stderr, "impalloclen = %d\n", impalloclen );
 //	fprintf( stderr, "i1,j1=%d,%d -> impmtx=%f\n", i1, j1, impmtx[i1][j1] );
@@ -68,10 +68,10 @@ float part_imp_match_out_sc( int i1, int j1 )
 	return( impmtx[i1+start1][j1+start2] );
 #endif
 }
-static void part_imp_match_out_vead_gapmap( float *imp, int i1, int lgth2, int start2, int *gapmap2 )
+static void part_imp_match_out_vead_gapmap( double *imp, int i1, int lgth2, int start2, int *gapmap2 )
 {
 #if FASTMACHCALC
-	float *pt = imp;
+	double *pt = imp;
 	int *gapmappt = gapmap2;
 	while( lgth2-- )
 		*pt++ += impmtx[i1][start2+*gapmappt++];
@@ -84,10 +84,10 @@ static void part_imp_match_out_vead_gapmap( float *imp, int i1, int lgth2, int s
 #endif
 }
 
-static void part_imp_match_out_vead_tate_gapmap( float *imp, int j1, int lgth1, int start1, int *gapmap1 )
+static void part_imp_match_out_vead_tate_gapmap( double *imp, int j1, int lgth1, int start1, int *gapmap1 )
 {
 #if FASTMACHCALC
-	float *pt = imp;
+	double *pt = imp;
 	int *gapmappt = gapmap1;
 	while( lgth1-- )
 		*pt++ = impmtx[start1+*gapmappt++][j1];
@@ -100,7 +100,7 @@ static void part_imp_match_out_vead_tate_gapmap( float *imp, int j1, int lgth1,
 #endif
 }
 
-void part_imp_match_init_strict( float *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, double *eff1_kozo, double *eff2_kozo, LocalHom ***localhom, int forscore )
+void part_imp_match_init_strict( double *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, double *eff1_kozo, double *eff2_kozo, LocalHom ***localhom, int forscore )
 {
 	int i, j, k1, k2, tmpint, start1, start2, end1, end2;
 	double effij, effijx, effij_kozo; 
@@ -275,7 +275,7 @@ void part_imp_rna( int nseq1, int nseq2, char **seq1, char **seq2, double *eff1,
 }
 
 
-void part_imp_match_init( float *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, LocalHom ***localhom )
+void part_imp_match_init( double *imp, int clus1, int clus2, int lgth1, int lgth2, char **seq1, char **seq2, double *eff1, double *eff2, LocalHom ***localhom )
 {
 	int dif, i, j, k1, k2, tmpint, start1, start2, end1, end2;
 	static TLS int impalloclen = 0;
@@ -428,17 +428,17 @@ for( i = 0; i<impalloclen; i++ )
 }
 
 
-static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc( double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 #if FASTMATCHCALC
 	int j, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *matchpt, *cpmxpdpt, **cpmxpdptpt;
+	double *matchpt, *cpmxpdpt, **cpmxpdptpt;
 	int *cpmxpdnpt, **cpmxpdnptpt;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 	if( initialize )
 	{
 		int count = 0;
@@ -482,11 +482,11 @@ static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int
 	free( scarr );
 #else
 	int j, k, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 	// simple
 	if( initialize )
 	{
@@ -523,23 +523,23 @@ static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int
 }
 
 
-static void fillzero( float *s, int l )
+static void fillzero( double *s, int l )
 {
 	while( l-- ) *s++ = 0.0;
 }
 
-static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc_add( double **scoreingmtx, double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 #if FASTMATCHCALC
 //	fprintf( stderr, "\nmatch_calc... %d", i1 );
 	int j, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *matchpt, *cpmxpdpt, **cpmxpdptpt;
+	double *matchpt, *cpmxpdpt, **cpmxpdptpt;
 	int *cpmxpdnpt, **cpmxpdnptpt;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 	if( initialize )
 	{
 		int count = 0;
@@ -585,11 +585,11 @@ static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, f
 //	fprintf( stderr, "done\n" );
 #else
 	int j, k, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 // simple
 	if( initialize )
 	{
@@ -627,7 +627,7 @@ static void match_calc_add( double **scoreingmtx, float *match, float **cpmx1, f
 #endif
 }
 
-static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *lastverticalw, 
+static void Atracking_localhom( double *impwmpt, double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
@@ -638,7 +638,7 @@ static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *l
 	int i, j, l, iin, jin, ifi, jfi, lgth1, lgth2, k, limk;
 //	char gap[] = "-";
 	char *gap;
-	float wm;
+	double wm;
 	gap = newgapstr;
 	lgth1 = strlen( seq1[0] );
 	lgth2 = strlen( seq2[0] );
@@ -762,7 +762,7 @@ static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *l
 		}
 		if( iin != lgth1 && jin != lgth2 ) // ??
 		{
-			*impwmpt += part_imp_match_out_sc( gapmap1[iin]+start1, gapmap2[jin]+start2 );
+			*impwmpt += (double)part_imp_match_out_sc( gapmap1[iin]+start1, gapmap2[jin]+start2 );
 //			fprintf( stderr, "impwm = %f (iin=%d, jin=%d) seq1=%c, seq2=%c\n", *impwmpt, iin, jin, seq1[0][iin], seq2[0][jin] );
 		}
 		if( iin <= 0 || jin <= 0 ) break;
@@ -775,7 +775,7 @@ static void Atracking_localhom( float *impwmpt, float *lasthorizontalw, float *l
 	}
 }
 
-static float Atracking( float *lasthorizontalw, float *lastverticalw, 
+static double Atracking( double *lasthorizontalw, double *lastverticalw, 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
@@ -785,7 +785,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 //	char gap[] = "-";
 	char *gap;
 	gap = newgapstr;
-	float wm = 0.0;
+	double wm = 0.0;
 	lgth1 = strlen( seq1[0] );
 	lgth2 = strlen( seq2[0] );
 
@@ -917,7 +917,7 @@ static float Atracking( float *lasthorizontalw, float *lastverticalw,
 	return( 0.0 );
 }
 
-float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, float *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
+double partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -925,51 +925,51 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 	int lasti, lastj; /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 	static TLS int **ijp;
 	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS char **mseq1;
 	static TLS char **mseq2;
 	static TLS char **mseq;
-	static TLS float *ogcp1;
-	static TLS float *ogcp2;
-	static TLS float *fgcp1;
-	static TLS float *fgcp2;
-	static TLS float **cpmx1;
-	static TLS float **cpmx2;
-	static TLS float *gapfreq1;
-	static TLS float *gapfreq2;
+	static TLS double *ogcp1;
+	static TLS double *ogcp2;
+	static TLS double *fgcp1;
+	static TLS double *fgcp2;
+	static TLS double **cpmx1;
+	static TLS double **cpmx2;
+	static TLS double *gapfreq1;
+	static TLS double *gapfreq2;
 	static TLS int **intwork;
-	static TLS float **floatwork;
+	static TLS double **doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
-	float fpenalty = (float)penalty;
-	float fpenalty_shift = (float)penalty_shift;
+	double fpenalty = (double)penalty;
+	double fpenalty_shift = (double)penalty_shift;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
-	float *fgcp2pt;
-	float *ogcp2pt;
-	float fgcp1va;
-	float ogcp1va;
-	float *gf2pt;
-	float *gf2ptpre;
-	float gf1va;
-	float gf1vapre;
-	float headgapfreq1;
-	float headgapfreq2;
+	double *fgcp2pt;
+	double *ogcp2pt;
+	double fgcp1va;
+	double ogcp1va;
+	double *gf2pt;
+	double *gf2ptpre;
+	double gf1va;
+	double gf1vapre;
+	double headgapfreq1;
+	double headgapfreq2;
 
 	int *warpis = NULL;
 	int *warpjs = NULL;
@@ -977,12 +977,12 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
 
@@ -1021,7 +1021,7 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 
 		}
@@ -1139,7 +1139,7 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatMtx( floatwork );
+			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
 		}
 
@@ -1174,10 +1174,10 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 		gapfreq2 = AllocateFloatVec( ll2+2 );
 
 #if FASTMATCHCALC
-		floatwork = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
+		doublework = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 		intwork = AllocateIntMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 #else
-		floatwork = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
+		doublework = AllocateFloatMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 #endif
 
@@ -1283,12 +1283,12 @@ float partA__align( char **seq1, char **seq2, double *eff1, double *eff2, int ic
 	previousw = w2;
 
 
-	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, floatwork, intwork, 1 );
+	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, doublework, intwork, 1 );
 	if( localhom )
 		part_imp_match_out_vead_tate_gapmap( initverticalw, gapmap2[0]+start2, lgth1, start1, gapmap1 );
 
 
-	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, floatwork, intwork, 1 );
+	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, doublework, intwork, 1 );
 	if( localhom )
 		part_imp_match_out_vead_gapmap( currentw, gapmap1[0]+start1, lgth2, start2, gapmap2 );
 #if 0 // -> tbfast.c
@@ -1370,7 +1370,7 @@ for( i=0; i<lgth2; i++ )
 
 		previousw[0] = initverticalw[i-1];
 
-		match_calc( currentw, cpmx1, cpmx2, i, lgth2, floatwork, intwork, 0 );
+		match_calc( currentw, cpmx1, cpmx2, i, lgth2, doublework, intwork, 0 );
 #if 0
 fprintf( stderr, "\n" );
 fprintf( stderr, "i=%d\n", i );
@@ -1605,7 +1605,7 @@ fprintf( stderr, "\n" );
 	return( wm );
 }
 
-float partA__align_variousdist( double **pairoffset, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, float *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
+double partA__align_variousdist( double **pairoffset, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -1613,51 +1613,51 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 	int lasti, lastj; /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lgth1, lgth2;
 	int resultlen;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if 1
-	float *wtmp;
+	double *wtmp;
 	int *ijppt;
-	float *mjpt, *prept, *curpt;
+	double *mjpt, *prept, *curpt;
 	int *mpjpt;
 #endif
-	static TLS float mi, *m;
+	static TLS double mi, *m;
 	static TLS int **ijp;
 	static TLS int mpi, *mp;
-	static TLS float *w1, *w2;
-	static TLS float *match;
-	static TLS float *initverticalw;    /* kufuu sureba iranai */
-	static TLS float *lastverticalw;    /* kufuu sureba iranai */
+	static TLS double *w1, *w2;
+	static TLS double *match;
+	static TLS double *initverticalw;    /* kufuu sureba iranai */
+	static TLS double *lastverticalw;    /* kufuu sureba iranai */
 	static TLS char **mseq1;
 	static TLS char **mseq2;
 	static TLS char **mseq;
-	static TLS float *ogcp1;
-	static TLS float *ogcp2;
-	static TLS float *fgcp1;
-	static TLS float *fgcp2;
-	static TLS float ***cpmx1s;
-	static TLS float ***cpmx2s;
-	static TLS float *gapfreq1;
-	static TLS float *gapfreq2;
+	static TLS double *ogcp1;
+	static TLS double *ogcp2;
+	static TLS double *fgcp1;
+	static TLS double *fgcp2;
+	static TLS double ***cpmx1s;
+	static TLS double ***cpmx2s;
+	static TLS double *gapfreq1;
+	static TLS double *gapfreq2;
 	static TLS int ***intwork;
-	static TLS float ***floatwork;
+	static TLS double ***doublework;
 	static TLS int orlgth1 = 0, orlgth2 = 0;
-	float fpenalty = (float)penalty;
-	float fpenalty_shift = (float)penalty_shift;
+	double fpenalty = (double)penalty;
+	double fpenalty_shift = (double)penalty_shift;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
-	float *fgcp2pt;
-	float *ogcp2pt;
-	float fgcp1va;
-	float ogcp1va;
-	float *gf2pt;
-	float *gf2ptpre;
-	float gf1va;
-	float gf1vapre;
-	float headgapfreq1;
-	float headgapfreq2;
+	double *fgcp2pt;
+	double *ogcp2pt;
+	double fgcp1va;
+	double ogcp1va;
+	double *gf2pt;
+	double *gf2ptpre;
+	double gf1va;
+	double gf1vapre;
+	double headgapfreq1;
+	double headgapfreq2;
 
 	int *warpis = NULL;
 	int *warpjs = NULL;
@@ -1665,12 +1665,12 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 	int *warpj = NULL;
 	int *prevwarpi = NULL;
 	int *prevwarpj = NULL;
-	float *wmrecords = NULL;
-	float *prevwmrecords = NULL;
+	double *wmrecords = NULL;
+	double *prevwmrecords = NULL;
 	int warpn = 0;
 	int warpbase;
-	float curm = 0.0;
-	float *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
+	double curm = 0.0;
+	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
 
 
@@ -1709,7 +1709,7 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatCub( floatwork );
+			FreeFloatCub( doublework );
 			FreeIntCub( intwork );
 
 		}
@@ -1825,7 +1825,7 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 			FreeFloatVec( gapfreq1 );
 			FreeFloatVec( gapfreq2 );
 
-			FreeFloatCub( floatwork );
+			FreeFloatCub( doublework );
 			FreeIntCub( intwork );
 		}
 
@@ -1859,7 +1859,7 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 		gapfreq1 = AllocateFloatVec( ll1+2 );
 		gapfreq2 = AllocateFloatVec( ll2+2 );
 
-		floatwork = AllocateFloatCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets ); 
+		doublework = AllocateFloatCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets ); 
 		intwork = AllocateIntCub( maxdistclass, MAX( ll1, ll2 )+2, nalphabets ); 
 
 #if DEBUG
@@ -1969,19 +1969,19 @@ float partA__align_variousdist( double **pairoffset, double ***matrices, double
 	previousw = w2;
 
 
-//	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, floatwork, intwork, 1 );
+//	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, doublework, intwork, 1 );
 	fillzero( initverticalw, lgth1 );
 	for( c=0; c<maxdistclass; c++ )
-		match_calc_add( matrices[c], initverticalw, cpmx2s[c], cpmx1s[c], 0, lgth1, floatwork[c], intwork[c], 1 );
+		match_calc_add( matrices[c], initverticalw, cpmx2s[c], cpmx1s[c], 0, lgth1, doublework[c], intwork[c], 1 );
 
 	if( localhom )
 		part_imp_match_out_vead_tate_gapmap( initverticalw, gapmap2[0]+start2, lgth1, start1, gapmap1 );
 
 
-//	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, floatwork, intwork, 1 );
+//	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, doublework, intwork, 1 );
 	fillzero( currentw, lgth2 );
 	for( c=0; c<maxdistclass; c++ )
-		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, floatwork[c], intwork[c], 1 );
+		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, doublework[c], intwork[c], 1 );
 	if( localhom )
 		part_imp_match_out_vead_gapmap( currentw, gapmap1[0]+start1, lgth2, start2, gapmap2 );
 #if 0 // -> tbfast.c
@@ -2063,10 +2063,10 @@ for( i=0; i<lgth2; i++ )
 
 		previousw[0] = initverticalw[i-1];
 
-//		match_calc( currentw, cpmx1, cpmx2, i, lgth2, floatwork, intwork, 0 );
+//		match_calc( currentw, cpmx1, cpmx2, i, lgth2, doublework, intwork, 0 );
 		fillzero( currentw, lgth2 );
 		for( c=0; c<maxdistclass; c++ )
-			match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], i, lgth2, floatwork[c], intwork[c], 0 );
+			match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], i, lgth2, doublework[c], intwork[c], 0 );
 #if 0
 fprintf( stderr, "\n" );
 fprintf( stderr, "i=%d\n", i );
