@@ -929,13 +929,13 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 {
 	int l, len1, len2;
 	int clus1, clus2;
-	float pscore, tscore;
+	double pscore, tscore;
 	static int *fftlog;
 	static char *indication1, *indication2;
 	static double *effarr1 = NULL;
 	static double *effarr2 = NULL;
 	static char **mseq1, **mseq2;
-	float dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	int m1, m2;
 #if 0
@@ -969,8 +969,8 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 	}
 
 #if WEIGHT
-	clus1 = fastconjuction_noname( mem1, seq, mseq1, effarr1, weight, indication1 );
-	clus2 = fastconjuction_noname( mem2, seq, mseq2, effarr2, weight, indication2 );
+	clus1 = fastconjuction_noname( mem1, seq, mseq1, effarr1, weight, indication1, 0.0 );
+	clus2 = fastconjuction_noname( mem2, seq, mseq2, effarr2, weight, indication2, 0.0 );
 #else
 	clus1 = fastconjuction_noweight( mem1, seq, mseq1, effarr1, indication1 );
 	clus2 = fastconjuction_noweight( mem2, seq, mseq2, effarr2, indication2 );
@@ -1046,7 +1046,7 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 				else
 				{
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 				}
 				break;
 			default:
@@ -1161,8 +1161,8 @@ static int splitseq_mq( Scores *scores, int nin, int *nlen, char **seq, char **o
 	int selfscore0;
 	double **dfromc;
 	double **dfromcp;
-	float **pickmtx;
-	float **yukomtx;
+	double **pickmtx;
+	double **yukomtx;
 	static short *table1;
 	Scores **outs, *ptr;
 	int *numin;
@@ -1189,10 +1189,10 @@ static int splitseq_mq( Scores *scores, int nin, int *nlen, char **seq, char **o
 	int ***topol;
 	int *treeorder;
 	int picktmp;
-	float **len;
+	double **len;
 	double minscore;
 //	double *minscoreinpick;
-	float *hanni;
+	double *hanni;
 	double lenfac;
 	double longer;
 	double shorter;
@@ -1200,7 +1200,7 @@ static int splitseq_mq( Scores *scores, int nin, int *nlen, char **seq, char **o
 	static char **mseq2 = NULL;
 	double *blastresults = NULL; // by Mathog, a guess
 	static int palloclen = 0;
-	float maxdist;
+	double maxdist;
 
 	if( orderpos == NULL )
 		orderpos = order;
@@ -1599,7 +1599,7 @@ exit( 1 );
 	{
 		if( s_p_map[j] != -1 )
 		{
-			pickmtx[0][s_p_map[j]] = (float)scores[j].score;
+			pickmtx[0][s_p_map[j]] = (double)scores[j].score;
 //			fprintf( stderr, "pickmtx[0][%d] = %f\n", s_p_map[j], pickmtx[0][s_p_map[j]] );
 		}
 	}
@@ -1744,10 +1744,10 @@ exit( 1 );
 	fprintf( stderr, "DIANA!!\n" );
 	if( npick > 2 )
 	{
-		float avdist;
-		float avdist1;
-		float avdist2;
-		float maxavdist;
+		double avdist;
+		double avdist1;
+		double avdist2;
+		double maxavdist;
 		int splinter;
 		int count;
 		int dochokoho;
@@ -1805,7 +1805,7 @@ exit( 1 );
 					}
 				}
 				if( count < 1 ) avdist1 = 0.0;
-				else avdist1 /= (float)count;
+				else avdist1 /= (double)count;
 				fprintf( stderr, "docho %d (%dinori), avdist1 = %f\n", dochokoho, p_o_map[dochokoho] + 1, avdist1 );
 
 				count = 0;
@@ -1826,7 +1826,7 @@ exit( 1 );
 					}
 				}
 				if( count < 1 ) avdist2 = 0.0;
-				else avdist2 /= (float)count;
+				else avdist2 /= (double)count;
 				fprintf( stderr, "docho %d (%dinori), avdist2 = %f\n", dochokoho, p_o_map[dochokoho] + 1, avdist2 );
 
 				if( avdist2 < avdist1 ) 
@@ -1885,8 +1885,8 @@ exit( 1 );
 	if( npick > 2 )
 	{
 #if 0
-		float avdist;
-		float maxavdist;
+		double avdist;
+		double maxavdist;
 		int count;
 		int splinter;
 		maxavdist = 0.0;
@@ -1922,9 +1922,9 @@ exit( 1 );
 			if( tsukau[i] == 0 ) continue;
 			for( j=i+1; j<npick; j++ )
 			{
-//				float kijun = maxdist *  1/(npick-2);
-//				float kijun = maxavdist * tokyoripara;
-				float kijun;
+//				double kijun = maxdist *  1/(npick-2);
+//				double kijun = maxavdist * tokyoripara;
+				double kijun;
 				kijun = maxdist * tokyoripara;  // atode kakunin
 //				fprintf( stderr, "%d-%d\n", i, j );
 //				fprintf( stderr, "maxdist = %f\n", maxdist );
@@ -2289,8 +2289,8 @@ exit( 1 );
 		if( nyuko > 2 )
 		{
 			fprintf( stderr, "upgma       " );
-//			veryfastsupg_float_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len );
-			fixed_musclesupg_float_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len, NULL, 1, 1 );
+//			veryfastsupg_double_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len );
+			fixed_musclesupg_double_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len, NULL, 1, 1 );
 			fprintf( stderr, "\r                      \r" );
 		}
 		else
@@ -2414,9 +2414,9 @@ exit( 1 );
 			mem2 = AllocateIntVec( njob+1 );
 		}
 
-//		veryfastsupg_float_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len );
+//		veryfastsupg_double_realloc_nobk_halfmtx( nyuko, yukomtx, topol, len );
 	
-//		counteff_simple_float( nyuko, topol, len, eff );
+//		counteff_simple_double( nyuko, topol, len, eff );
 
 
 		nlim = nyuko-1;
