@@ -13,6 +13,10 @@ static int noalign;
 static int multidist;
 static int subalignment;
 static int subalignmentoffset;
+static int keeplength;
+static int ndeleted;
+static int mapout;
+static int smoothing;
 
 #ifdef enablemultithread
 typedef struct _jobtable
@@ -25,8 +29,8 @@ typedef struct _distancematrixthread_arg
 {
 	int njob;
 	int thread_no;
-	float *selfscore;
-	float **iscore;
+	double *selfscore;
+	double **iscore;
 	char **seq;
 	int **skiptable;
 	Jobtable *jobpospt;
@@ -62,6 +66,7 @@ void arguments( int argc, char *argv[] )
 	nthread = 1;
 	outnumber = 0;
 	scoreout = 0;
+	spscoreout = 0;
 	treein = 0;
 	topin = 0;
 	rnaprediction = 'm';
@@ -123,6 +128,9 @@ void arguments( int argc, char *argv[] )
 	subalignmentoffset = 0;
 	legacygapcost = 0;
 	specificityconsideration = 0.0;
+	keeplength = 0;
+	mapout = 0;
+	smoothing = 0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -258,9 +266,15 @@ void arguments( int argc, char *argv[] )
 					fftNoAnchStop = 1;
 					break;
 #endif
-				case 'S':
-					scoreout = 1;
+#if 0
+				case 'S' :
+					scoreout = 1; // for checking parallel calculation
 					break;
+#else
+				case 'S' :
+					spscoreout = 1; // 2014/Dec/30, sp score
+					break;
+#endif
 				case 'H':
 					subalignment = 1;
 					subalignmentoffset = myatoi( *++argv );
@@ -315,7 +329,7 @@ void arguments( int argc, char *argv[] )
 				case 'N':
 					nevermemsave = 1;
 					break;
-				case 'B':
+				case 'B': // hitsuyou! memopt -M -B no tame
 					break;
 				case 'F':
 					use_fft = 1;
@@ -360,9 +374,25 @@ void arguments( int argc, char *argv[] )
 					fftWinSize = myatoi( *++argv );
 					--argc;
 					goto nextoption;
+				case 'W':
+					minimumweight = atof( *++argv );
+					fprintf( stderr, "minimumweight = %f\n", minimumweight );
+					--argc;
+					goto nextoption;
+#if 0
 				case 'Z':
 					checkC = 1;
 					break;
+#endif
+				case 'Y':
+					keeplength = 1;
+					break;
+				case 'Z':
+					mapout = 1;
+					break;
+				case 'p':
+					smoothing = 1;
+					break;
                 default:
                     fprintf( stderr, "illegal option %c\n", c );
                     argc = 0;
@@ -400,12 +430,12 @@ static void *distancematrixthread2( void *arg )
 	distancematrixthread_arg_t *targ = (distancematrixthread_arg_t *)arg;
 	int njob = targ->njob;
 	int thread_no = targ->thread_no;
-	float *selfscore = targ->selfscore;
-	float **iscore = targ->iscore;
+	double *selfscore = targ->selfscore;
+	double **iscore = targ->iscore;
 	char **seq = targ->seq;
 	Jobtable *jobpospt = targ->jobpospt;
 
-	float ssi, ssj, bunbo;
+	double ssi, ssj, bunbo;
 	int i, j;
 
 	while( 1 )
@@ -437,18 +467,18 @@ static void *distancematrixthread2( void *arg )
 #endif
 
 #ifdef enablemultithread
-static void *distancematrixthread( void *arg )
+static void *distancematrixthread( void *arg ) // v7.2 ijou deha tsukawanaihazu
 {
 	distancematrixthread_arg_t *targ = (distancematrixthread_arg_t *)arg;
 	int njob = targ->njob;
 	int thread_no = targ->thread_no;
-	float *selfscore = targ->selfscore;
-	float **iscore = targ->iscore;
+	double *selfscore = targ->selfscore;
+	double **iscore = targ->iscore;
 	char **seq = targ->seq;
 	int **skiptable = targ->skiptable;
 	Jobtable *jobpospt = targ->jobpospt;
 
-	float ssi, ssj, bunbo;
+	double ssi, ssj, bunbo;
 	int i, j;
 
 	while( 1 )
@@ -481,6 +511,7 @@ static void *distancematrixthread( void *arg )
 		else
 //			iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo ) * 2.0; // 2013/Oct/17
 			iscore[i][j-i] = ( 1.0 - naivepairscorefast( seq[i], seq[j], skiptable[i], skiptable[j], penalty_dist ) / bunbo ) * 2.0; // 2014/Aug/15 fast
+		if( iscore[i][j-i] > 10 ) iscore[i][j-i] = 10.0; // 2015/Mar/17
 	}
 }
 
@@ -508,7 +539,7 @@ static void *treebasethread( void *arg )
 	int i, j, l;
 	int len1, len2;
 	int clus1, clus2;
-	float pscore;
+	double pscore;
 	char *indication1, *indication2;
 	double *effarr1 = NULL;
 	double *effarr2 = NULL;
@@ -516,7 +547,8 @@ static void *treebasethread( void *arg )
 	double *effarr2_kozo = NULL;
 	LocalHom ***localhomshrink = NULL;
 	int m1, m2;
-	float dumfl = 0.0;
+//	double dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	RNApair ***grouprna1 = NULL, ***grouprna2 = NULL;
 	double **dynamicmtx;
@@ -694,8 +726,8 @@ static void *treebasethread( void *arg )
 		}
 		else
 		{
-			clus1 = fastconjuction_noname( topol[l][0], localcopy, mseq1, effarr1, effarr, indication1 );
-			clus2 = fastconjuction_noname( topol[l][1], localcopy, mseq2, effarr2, effarr, indication2 );
+			clus1 = fastconjuction_noname( topol[l][0], localcopy, mseq1, effarr1, effarr, indication1, minimumweight );
+			clus2 = fastconjuction_noname( topol[l][1], localcopy, mseq2, effarr2, effarr, indication2, minimumweight );
 		}
 
 
@@ -768,7 +800,7 @@ static void *treebasethread( void *arg )
 		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000 );
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000 ); // v6.708
-//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (float)len1/fftlog[m1], clus1, (float)len2/fftlog[m2], clus2 );
+//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
 //		fprintf( stderr, "f=%d, clus1=%d, fftlog[m1]=%d, clus2=%d, fftlog[m2]=%d\n", ffttry, clus1, fftlog[m1], clus2, fftlog[m2] );
 		if( constraint == 2 )
 		{
@@ -782,7 +814,7 @@ static void *treebasethread( void *arg )
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'Q' )
 			{
@@ -815,7 +847,7 @@ static void *treebasethread( void *arg )
 					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
@@ -873,7 +905,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	int len1nocommongap, len2nocommongap;
 	int len1, len2;
 	int clus1, clus2;
-	float pscore, tscore;
+	double pscore, tscore;
 	static char *indication1, *indication2;
 	static double *effarr1 = NULL;
 	static double *effarr2 = NULL;
@@ -885,10 +917,12 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	static int *gaplen;
 	static int *gapmap;
 	static int *alreadyaligned;
-	float dumfl = 0.0;
+//	double dumfl = 0.0;
+	double dumdb = 0.0;
 	int ffttry;
 	RNApair ***grouprna1 = NULL, ***grouprna2 = NULL;
 	static double **dynamicmtx;
+	int gapmaplen;
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -994,8 +1028,8 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 		}
 		else
 		{
-			clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1 );
-			clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2 );
+			clus1 = fastconjuction_noname( topol[l][0], aseq, mseq1, effarr1, effarr, indication1, minimumweight );
+			clus2 = fastconjuction_noname( topol[l][1], aseq, mseq2, effarr2, effarr, indication2, minimumweight );
 		}
 
 		if( mergeoralign[l] == '1' || mergeoralign[l] == '2' ) // only in serial version
@@ -1088,7 +1122,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 		if( fftlog[m1] && fftlog[m2] ) ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 1000 && clus2 < 1000 );
 		else						   ffttry = 0;
 //		ffttry = ( nlen[m1] > clus1 && nlen[m2] > clus2 && clus1 < 5000 && clus2 < 5000 ); // v6.708
-//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (float)len1/fftlog[m1], clus1, (float)len2/fftlog[m2], clus2 );
+//		fprintf( stderr, "f=%d, len1/fftlog[m1]=%f, clus1=%d, len2/fftlog[m2]=%f, clus2=%d\n", ffttry, (double)len1/fftlog[m1], clus1, (double)len2/fftlog[m2], clus2 );
 //		fprintf( stderr, "f=%d, clus1=%d, fftlog[m1]=%d, clus2=%d, fftlog[m2]=%d\n", ffttry, clus1, fftlog[m1], clus2, fftlog[m2] );
 		if( constraint == 2 )
 		{
@@ -1102,7 +1136,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 			{
 				imp_match_init_strict( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
 			else if( alg == 'Q' )
 			{
@@ -1135,7 +1169,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 					pscore = MSalignmm( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				case( 'A' ):
-					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
@@ -1163,21 +1197,28 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 
 		if( mergeoralign[l] == '1' ) // jissainiha nai. atarashii hairetsu ha saigo dakara.
 		{
-			adjustgapmap( strlen( mseq2[0] )-len2nocommongap+len2, gapmap, mseq2[0] );
-			restorecommongaps( njob, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
-			findnewgaps( clus2, 0, mseq2, gaplen );
-			insertnewgaps( njob, alreadyaligned, aseq, topol[l][1], topol[l][0], gaplen, gapmap, *alloclen, alg, '-' );
-			for( i=0; i<njob; i++ ) eq2dash( aseq[i] );
-			for( i=0; (m=topol[l][0][i])>-1; i++ ) alreadyaligned[m] = 1;
+			reporterr( "Check source!!\n" );
+			exit( 1 );
 		}
 		if( mergeoralign[l] == '2' )
 		{
 //			fprintf( stderr, ">mseq1[0] = \n%s\n", mseq1[0] );
 //			fprintf( stderr, ">mseq2[0] = \n%s\n", mseq2[0] );
-			adjustgapmap( strlen( mseq1[0] )-len1nocommongap+len1, gapmap, mseq1[0] );
-			restorecommongaps( njob, aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
-			findnewgaps( clus1, 0, mseq1, gaplen );
-			insertnewgaps( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, *alloclen, alg, '-' );
+//			if( keeplength ) ndeleted += deletenewinsertions( clus1, clus2, mseq1, mseq2, NULL );
+			gapmaplen = strlen( mseq1[0] )-len1nocommongap+len1;
+			adjustgapmap( gapmaplen, gapmap, mseq1[0] );
+			if( smoothing )
+			{
+				restorecommongapssmoothly( njob, njob-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+				findnewgaps( clus1, 0, mseq1, gaplen );
+				insertnewgaps_bothorders( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, gapmaplen, *alloclen, alg, '-' );
+			}
+			else
+			{
+				restorecommongaps( njob, njob-(clus1+clus2), aseq, topol[l][0], topol[l][1], gapmap, *alloclen, '-' );
+				findnewgaps( clus1, 0, mseq1, gaplen );
+				insertnewgaps( njob, alreadyaligned, aseq, topol[l][0], topol[l][1], gaplen, gapmap, *alloclen, alg, '-' );
+			}
 #if 0
 			for( i=0; i<njob; i++ ) eq2dash( aseq[i] );
 			for( i=0; i<clus1; i++ ) eq2dash( mseq1[i] );
@@ -1286,19 +1327,19 @@ static void WriteOptions( FILE *fp )
 int main( int argc, char *argv[] )
 {
 	static int  *nlen;	
-	static float *selfscore;
+	static double *selfscore;
 	int nogaplen;
 	static char **name, **seq;
 	static char **mseq1, **mseq2;
 	static char **bseq;
-	static float **iscore, **iscore_kozo;
+	static double **iscore, **iscore_kozo;
 	int **skiptable;
 	static double *eff, *eff_kozo, *eff_kozo_mapped = NULL;
 	int i, j, ien, ik, jk;
 	static int ***topol, ***topol_kozo;
 	static int *addmem;
 	static Treedep *dep;
-	static float **len, **len_kozo;
+	static double **len, **len_kozo;
 	FILE *prep;
 	FILE *infp;
 	FILE *orderfp;
@@ -1312,12 +1353,16 @@ int main( int argc, char *argv[] )
 	int *insubtable;
 	int *preservegaps;
 	char ***subalnpt;
+	char *originalgaps = NULL;
+	char **addbk = NULL;
+	int **deletelist = NULL;
+	FILE *dlf = NULL;
 
 	char c;
 	int alloclen;
 	LocalHom **localhomtable = NULL;
 	RNApair ***singlerna = NULL;
-	float ssi, ssj, bunbo;
+	double ssi, ssj, bunbo;
 	static char *kozoarivec;
 	int nkozo;
 
@@ -1386,6 +1431,8 @@ int main( int argc, char *argv[] )
 	dep = (Treedep *)calloc( njob, sizeof( Treedep ) );
 	if( nadd ) addmem = AllocateIntVec( nadd+1 );
 
+	ndeleted = 0;
+
 	if( constraint )
 	{
 		localhomtable = (LocalHom **)calloc( njob, sizeof( LocalHom *) );
@@ -1467,6 +1514,31 @@ int main( int argc, char *argv[] )
 
 //	writePre( njob, name, nlen, seq, 0 );
 
+	if( nadd && keeplength )
+	{
+		originalgaps = (char *)calloc( nlenmax+1, sizeof( char) );
+		recordoriginalgaps( originalgaps, njob-nadd, seq );
+
+		if( mapout )
+		{
+			addbk = (char **)calloc( nadd+1, sizeof( char * ) );
+			for( i=0; i<nadd; i++ )
+			{
+				ien = strlen( seq[njob-nadd+i] );
+				addbk[i] = (char *)calloc( ien + 1, sizeof( char ) );
+				gappick0( addbk[i], seq[njob-nadd+i] );
+			}
+			addbk[nadd] = NULL;
+		}
+		else
+			addbk = NULL;
+	}
+	else
+	{
+		originalgaps = NULL;
+		addbk = NULL;
+	}
+
 	if( treein )
 	{
 #if 0
@@ -1478,6 +1550,7 @@ int main( int argc, char *argv[] )
 #endif
 		fprintf( stderr, "Loading a tree ... " );
 		loadtree( njob, topol, len, name, nlen, dep );
+//		loadtop( njob, topol, len, name, NULL, dep ); // 2015/Jan/13, not yet checked
 		fprintf( stderr, "\ndone.\n\n" );
 	}
 	else
@@ -1493,7 +1566,7 @@ int main( int argc, char *argv[] )
 				}
 			}
 	
-			fprintf( stderr, "Making a distance matrix .. \n" );
+			fprintf( stderr, "Making a distance matrix .. (Should not be used in versions >7.2) \n" );
 			fflush( stderr );
 			skiptable = AllocateIntMtx( njob, 0 );
 			makeskiptable( njob, skiptable, seq ); // allocate suru.
@@ -1563,6 +1636,7 @@ int main( int argc, char *argv[] )
 //							iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / MIN( selfscore[i], selfscore[j] );
 //							iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo ) * 2.0; // 2013/Oct/17 2bai
 							iscore[i][j-i] = ( 1.0 - naivepairscorefast( seq[i], seq[j], skiptable[i], skiptable[j], penalty_dist ) / bunbo ) * 2.0; // 2014/Aug/15 fast
+						if( iscore[i][j-i] > 10 ) iscore[i][j-i] = 10.0; // 2015/Mar/17
 //exit( 1 );
 		
 #if 0
@@ -1585,14 +1659,14 @@ int main( int argc, char *argv[] )
 				fprintf( stderr, "Loading 'hat2n' (aligned sequences - new sequences) ... " );
 				prep = fopen( "hat2n", "r" );
 				if( prep == NULL ) ErrorExit( "Make hat2." );
-				readhat2_floathalf_pointer( prep, njob, name, iscore );
+				readhat2_doublehalf_pointer( prep, njob, name, iscore );
 				fclose( prep );
 				fprintf( stderr, "done.\n" );
 			
 				fprintf( stderr, "Loading 'hat2i' (aligned sequences) ... " );
 				prep = fopen( "hat2i", "r" );
 				if( prep == NULL ) ErrorExit( "Make hat2i." );
-				readhat2_floathalf_pointer( prep, njob-nadd, name, iscore );
+				readhat2_doublehalf_pointer( prep, njob-nadd, name, iscore );
 				fclose( prep );
 				fprintf( stderr, "done.\n" );
 			}
@@ -1601,7 +1675,7 @@ int main( int argc, char *argv[] )
 				fprintf( stderr, "Loading 'hat2' ... " );
 				prep = fopen( "hat2", "r" );
 				if( prep == NULL ) ErrorExit( "Make hat2." );
-				readhat2_floathalf_pointer( prep, njob, name, iscore );
+				readhat2_doublehalf_pointer( prep, njob, name, iscore );
 				fclose( prep );
 				fprintf( stderr, "done.\n" );
 			}
@@ -1645,15 +1719,15 @@ int main( int argc, char *argv[] )
 		}
 		else if( subalignment ) // merge error no tame
 		{
-			fixed_supg_float_realloc_nobk_halfmtx_treeout_constrained( njob, iscore, topol, len, name, nlen, dep, nsubalignments, subtable, 1 );
+			fixed_supg_double_realloc_nobk_halfmtx_treeout_constrained( njob, iscore, topol, len, name, nlen, dep, nsubalignments, subtable, 1 );
 		}
 		else if( treeout ) // merge error no tame
 		{
-			fixed_musclesupg_float_realloc_nobk_halfmtx_treeout( njob, iscore, topol, len, name, nlen, dep, 1 );
+			fixed_musclesupg_double_realloc_nobk_halfmtx_treeout( njob, iscore, topol, len, name, nlen, dep, 1 );
 		}
 		else
 		{
-			fixed_musclesupg_float_realloc_nobk_halfmtx( njob, iscore, topol, len, dep, 1, 1 );
+			fixed_musclesupg_double_realloc_nobk_halfmtx( njob, iscore, topol, len, dep, 1, 1 );
 		}
 //		else 
 //			ErrorExit( "Incorrect tree\n" );
@@ -1663,7 +1737,7 @@ int main( int argc, char *argv[] )
 //			for( i=0; i<nkozo-1; i++ )
 //				for( j=i+1; j<nkozo; j++ )
 //					fprintf( stderr, "iscore_kozo[%d][%d] =~ %f\n", i, j, iscore_kozo[i][j-i] );
-			fixed_musclesupg_float_realloc_nobk_halfmtx( nkozo, iscore_kozo, topol_kozo, len_kozo, NULL, 1, 1 );
+			fixed_musclesupg_double_realloc_nobk_halfmtx( nkozo, iscore_kozo, topol_kozo, len_kozo, NULL, 1, 1 );
 		}
 		fprintf( stderr, "\ndone.\n\n" );
 		fflush( stderr );
@@ -1701,7 +1775,7 @@ int main( int argc, char *argv[] )
 #if 0
 		utree = 0; counteff( njob, topol, len, eff ); utree = 1;
 #else
-		counteff_simple_float_nostatic( njob, topol, len, eff );
+		counteff_simple_double_nostatic( njob, topol, len, eff );
 		for( i=njob-nadd; i<njob; i++ ) eff[i] /= (double)100;
 #if 0
 		fprintf( stderr, "######  WEIGHT = \n" );
@@ -1713,7 +1787,7 @@ int main( int argc, char *argv[] )
 #endif
 		if( nkozo )
 		{
-//			counteff_simple_float( nkozo, topol_kozo, len_kozo, eff_kozo ); // single weight nanode iranai
+//			counteff_simple_double( nkozo, topol_kozo, len_kozo, eff_kozo ); // single weight nanode iranai
 			for( i=0,j=0; i<njob; i++ )
 			{
 				if( kozoarivec[i] )
@@ -2096,6 +2170,46 @@ int main( int argc, char *argv[] )
 
 		treebase( nlen, bseq, nadd, mergeoralign, mseq1, mseq2, topol, dep, eff, &alloclen, localhomtable, singlerna, eff_kozo_mapped );
 	fprintf( stderr, "\ndone.\n" );
+
+	
+	if( keeplength )
+	{
+
+		dlf = fopen( "_deletelist", "w" );
+		deletelist = (int **)calloc( nadd+1, sizeof( int * ) );
+		for( i=0; i<nadd; i++ )
+		{
+			deletelist[i] = calloc( 1, sizeof( int ) );
+			deletelist[i][0] = -1;
+		}
+		deletelist[nadd] = NULL;
+		ndeleted = deletenewinsertions_whole( njob-nadd, nadd, bseq, bseq+njob-nadd, deletelist );
+
+		for( i=0; i<nadd; i++ )
+		{
+			if( deletelist[i] )
+				for( j=0; deletelist[i][j]!=-1; j++ )
+					fprintf( dlf, "%d %d\n", njob-nadd+i, deletelist[i][j] ); // 0origin
+		}
+		fclose( dlf );
+
+		restoreoriginalgaps( njob, bseq, originalgaps );
+
+		if( mapout )
+		{
+			dlf = fopen( "_deletemap", "w" );
+			reconstructdeletemap( nadd, addbk, deletelist, bseq+njob-nadd, dlf, name+njob-nadd );
+			FreeCharMtx( addbk );
+			addbk = NULL;
+			fclose( dlf );
+		}
+
+		FreeIntMtx( deletelist );
+		deletelist = NULL;
+	}
+
+
+
 	if( scoreout )
 	{
 		unweightedspscore = plainscore( njob, bseq );
@@ -2158,6 +2272,15 @@ int main( int argc, char *argv[] )
 
 	if( constraint ) FreeLocalHomTable( localhomtable, njob );
 
+	if( spscoreout ) reporterr( "Unweighted sum-of-pairs score = %10.5f\n", sumofpairsscore( njob, bseq ) );
 	SHOWVERSION;
+	if( ndeleted > 0 )
+	{
+		reporterr( "\nTo keep the alignment length, %d letters were DELETED.\n", ndeleted );
+		if( mapout )
+			reporterr( "The deleted letters are shown in the (filename).map file.\n" );
+		else
+			reporterr( "To know the positions of deleted letters, rerun the same command with the --mapout option.\n" );
+	}
 	return( 0 );
 }
