@@ -49,11 +49,11 @@ void mdfymtx( char **pair, int s1, double **partialmtx, double **mtx )
 }
 
 		
-float score_calc( char **seq, int s )  /* method 3  */
+double score_calc( char **seq, int s )  /* method 3  */
 {
     int i, j, k, c;
     int len = strlen( seq[0] );
-    float score;
+    double score;
     int tmpscore;
     char *mseq1, *mseq2;
 
@@ -123,12 +123,12 @@ float score_calc( char **seq, int s )  /* method 3  */
             score += (double)tmpscore / (double)c;
         }
     }
-    score = (float)score / ( ( (double)s * ((double)s-1.0) ) / 2.0 );
+    score = (double)score / ( ( (double)s * ((double)s-1.0) ) / 2.0 );
 	fprintf( stderr, "score in score_calc = %f\n", score );
     return( score );
 }
 
-void cpmx_calc( char **seq, float **cpmx, double *eff, int lgth, int clus )
+void cpmx_calc( char **seq, double **cpmx, double *eff, int lgth, int clus )
 {
 	int  i, j, k;
 	double totaleff = 0.0;
@@ -136,19 +136,19 @@ void cpmx_calc( char **seq, float **cpmx, double *eff, int lgth, int clus )
 	for( i=0; i<clus; i++ ) totaleff += eff[i]; 
 	for( i=0; i<nalphabets; i++ ) for( j=0; j<lgth; j++ ) cpmx[i][j] = 0.0;
 	for( j=0; j<lgth; j++ ) for( k=0; k<clus; k++ )
-			cpmx[(int)amino_n[(int)seq[k][j]]][j] += (float)eff[k] / totaleff;
+			cpmx[(int)amino_n[(int)seq[k][j]]][j] += (double)eff[k] / totaleff;
 }
 
 
-void cpmx_calc_new_bk( char **seq, float **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0 
+void cpmx_calc_new_bk( char **seq, double **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0 
 {
     int  i, j, k;
-    float feff;
+    double feff;
 
     for( i=0; i<nalphabets; i++ ) for( j=0; j<lgth; j++ ) cpmx[i][j] = 0.0;
     for( k=0; k<clus; k++ )
     {
-        feff = (float)eff[k];
+        feff = (double)eff[k];
         for( j=0; j<lgth; j++ ) 
         {
             cpmx[(int)amino_n[(int)seq[k][j]]][j] += feff;
@@ -156,11 +156,11 @@ void cpmx_calc_new_bk( char **seq, float **cpmx, double *eff, int lgth, int clus
     }
 }
 
-void cpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
+void cpmx_calc_new( char **seq, double **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
 {
 	int  i, j, k;
-	float feff;
-	float *cpmxpt, **cpmxptpt;
+	double feff;
+	double *cpmxpt, **cpmxptpt;
 	char *seqpt;
 
 	j = nalphabets;
@@ -174,7 +174,7 @@ void cpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus )
 	}
 	for( k=0; k<clus; k++ )
 	{
-		feff = (float)eff[k];
+		feff = (double)eff[k];
 		seqpt = seq[k];
 //		fprintf( stderr, "seqpt = %s, lgth=%d\n", seqpt, lgth );
 		for( j=0; j<lgth; j++ )
@@ -183,11 +183,11 @@ void cpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus )
 		}
 	}
 }
-void MScpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
+void MScpmx_calc_new( char **seq, double **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
 {
 	int  i, j, k;
-	float feff;
-	float **cpmxptpt, *cpmxpt;
+	double feff;
+	double **cpmxptpt, *cpmxpt;
 	char *seqpt;
 
 	j = lgth;
@@ -201,7 +201,7 @@ void MScpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus
 	}
 	for( k=0; k<clus; k++ )
 	{
-		feff = (float)eff[k];
+		feff = (double)eff[k];
 		seqpt = seq[k];
 		cpmxptpt = cpmx;
 		j = lgth;
@@ -212,18 +212,18 @@ void MScpmx_calc_new( char **seq, float **cpmx, double *eff, int lgth, int clus
 	for( j=0; j<lgth; j++ ) for( i=0; i<nalphabets; i++ ) cpmx[j][i] = 0.0;
 	for( k=0; k<clus; k++ )
 	{
-		feff = (float)eff[k];
+		feff = (double)eff[k];
 		for( j=0; j<lgth; j++ ) 
 			cpmx[j][(int)amino_n[(int)seq[k][j]]] += feff;
 	}
 #endif
 }
 
-void cpmx_ribosum( char **seq, char **seqr, char *dir, float **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
+void cpmx_ribosum( char **seq, char **seqr, char *dir, double **cpmx, double *eff, int lgth, int clus ) // summ eff must be 1.0
 {
 	int  i, j, k;
-	float feff;
-	float **cpmxptpt, *cpmxpt;
+	double feff;
+	double **cpmxptpt, *cpmxpt;
 	char *seqpt, *seqrpt, *dirpt;
 	int code, code1, code2;
 
@@ -238,7 +238,7 @@ void cpmx_ribosum( char **seq, char **seqr, char *dir, float **cpmx, double *eff
 	}
 	for( k=0; k<clus; k++ )
 	{
-		feff = (float)eff[k];
+		feff = (double)eff[k];
 		seqpt = seq[k];
 		seqrpt = seqr[k];
 		dirpt = dir;
@@ -448,7 +448,7 @@ int fastconjuction_noname_kozo( int *memlist, char **seq, char **aseq, double *p
 }
 
 
-int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff, double *eff, char *d )
+int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff, double *eff, char *d, double mineff  )
 {
 	int m, k, dln;
 	char b[B];
@@ -471,13 +471,17 @@ int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff,
 		strcat( d, b );
 #endif
 		aseq[k] = seq[m];
-		peff[k] = eff[m];
+		if( eff[m] < mineff )
+			peff[k] = mineff;
+		else
+			peff[k] = eff[m];
+
 		total += peff[k];
 	}
 #if 1
 	for( m=0; m<k; m++ )
 	{
-//		fprintf( stderr, "peff[%d] = %f\n", m, peff[m] );
+//		fprintf( stderr, "Apr17   peff[%d] = %f\n", m, peff[m] );
 		peff[m] /= total;
 	}
 #endif
@@ -600,7 +604,7 @@ int conjuction( char **pair, int s, char **seq, char **aseq, double *peff, doubl
 	return( k );
 }
 			
-void floatdelete( float **cpmx, int d, int len )
+void doubledelete( double **cpmx, int d, int len )
 {
 	int i, j;
 
