@@ -32,9 +32,9 @@ typedef struct _threadarg
 	int maxiter;
 	int nkozo;
 	int *subgenerationpt;
-	float *basegainpt;
-	float *gainlist;
-	float *tscorelist;
+	double *basegainpt;
+	double *gainlist;
+	double *tscorelist;
 	int *generationofinput;
 	char *kozoarivec;	
 	char **mastercopy;
@@ -47,7 +47,7 @@ typedef struct _threadarg
 	Node *stopol;
 	int ***topol;
 //	double **len;
-	float **tscorehistory_detail;
+	double **tscorehistory_detail;
 	int *finishpt;
 	int **skipthisbranch;
 	double **distmtx;
@@ -81,7 +81,7 @@ static void shuffle( int *arr, int n )
 static void makescoringmatrices( double ***matrices, double **originalmtx )
 {
 	int c;
-	float rep;
+	double rep;
 	for( c=0; c<maxdistclass; c++ )
 	{
 		rep = (double) 2 * c / ndistclass; // rep:0..2
@@ -225,7 +225,7 @@ static void Writeoptions( FILE *fp )
 #ifdef enablemultithread
 
 static void freelocalarrays( 
-	float *tscorehistory,
+	double *tscorehistory,
 	RNApair ***grouprna1, RNApair ***grouprna2,
 	RNApair *rnapairboth,
 	char *indication1, char *indication2,
@@ -314,11 +314,11 @@ static void *athread( void *arg )
 	int *collectingpt = targ->collectingpt;
 	int *jobposintpt = targ->jobposintpt;
 	int nkozo = targ->nkozo;
-	float *gainlist = targ->gainlist;
-	float *tscorelist = targ->tscorelist;
+	double *gainlist = targ->gainlist;
+	double *tscorelist = targ->tscorelist;
 	int *generationofinput = targ->generationofinput;
 	int *subgenerationpt = targ->subgenerationpt;
-	float *basegainpt = targ->basegainpt;
+	double *basegainpt = targ->basegainpt;
 	char *kozoarivec = targ->kozoarivec;	
 	char **mastercopy = targ->mastercopy;
 	char ***candidates = targ->candidates;
@@ -330,13 +330,13 @@ static void *athread( void *arg )
 	Node * stopol = targ->stopol;
 	int ***topol = targ->topol;
 //	double **len = targ->len;
-	float **tscorehistory_detail = targ->tscorehistory_detail;
+	double **tscorehistory_detail = targ->tscorehistory_detail;
 	int *finishpt = targ->finishpt;
 	int **skipthisbranch = targ->skipthisbranch;
 	double **distmtx = targ->distmtx;
 
 	int i, k, l, ii;
-	float gain;
+	double gain;
 	int iterate;
 	int **memlist;
 	char *pairbuf;
@@ -353,18 +353,20 @@ static void *athread( void *arg )
 	RNApair *rnapairboth;
 	LocalHom ***localhomshrink;
 	int *gapmap1, *gapmap2;
-	float tscore, mscore, oimpmatch, impmatch;
+	double tscore, mscore;
+	double oimpmatchdouble;
+	double impmatchdouble;
 	int identity;
 	double tmpdouble;
-//	float naivescore0 = 0, naivescore1;
+//	double naivescore0 = 0, naivescore1;
 	double *effarrforlocalhom;
-	float *tscorehistory;
+	double *tscorehistory;
 	int intdum;
 #if 0
 	int oscillating;
 	int lin, ldf;
 #endif
-	float maxgain;
+	double maxgain;
 	int bestthread;
 	int branchpos;
 	int subgenerationatfirst;
@@ -405,7 +407,7 @@ static void *athread( void *arg )
 		exit( 1 );
 	}
 
-	tscorehistory = calloc( maxiter, sizeof( float ) );
+	tscorehistory = calloc( maxiter, sizeof( double ) );
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -808,8 +810,8 @@ static void *athread( void *arg )
 			{
 //				clus1 = conjuctionfortbfast( pair[0], s1, localcopy, mseq1, effarr1, effarr, indication1 );
 //				clus2 = conjuctionfortbfast( pair[1], s2, localcopy, mseq2, effarr2, effarr, indication2 );
-				clus1 = fastconjuction_noname( memlist[0], localcopy, mseq1, effarr1, effarr, indication1 );
-				clus2 = fastconjuction_noname( memlist[1], localcopy, mseq2, effarr2, effarr, indication2 );
+				clus1 = fastconjuction_noname( memlist[0], localcopy, mseq1, effarr1, effarr, indication1, minimumweight ); // 2015/Apr/18
+				clus2 = fastconjuction_noname( memlist[1], localcopy, mseq2, effarr2, effarr, indication2, minimumweight ); // 2015/Apr/18
 			}
 
 	        if( rnakozo && rnaprediction == 'm' )
@@ -854,7 +856,7 @@ static void *athread( void *arg )
 //					shrinklocalhom( pair, int s1, int s2, localhomtable, localhomshrink );
 //					msshrinklocalhom( pair[0], pair[1], s1, s2, localhomtable, localhomshrink );
 					msshrinklocalhom_fast( memlist[0], memlist[1], localhomtable, localhomshrink );
-					oimpmatch = 0.0;
+					oimpmatchdouble = 0.0;
 					if( use_fft )
 					{
 						if( alg == 'Q' )
@@ -868,7 +870,7 @@ static void *athread( void *arg )
 							if( rnakozo ) part_imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
 							for(  i=length-1; i>=0; i-- )
 							{
-								oimpmatch += part_imp_match_out_sc( i, i );
+								oimpmatchdouble += (double)part_imp_match_out_sc( i, i );
 //								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
 							}
 						}
@@ -890,7 +892,7 @@ static void *athread( void *arg )
 
 							for(  i=length-1; i>=0; i-- )
 							{
-								oimpmatch += imp_match_out_sc( i, i );
+								oimpmatchdouble += (double)imp_match_out_sc( i, i );
 //								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
 							}
 						}
@@ -913,12 +915,12 @@ static void *athread( void *arg )
 						else
 							intergroup_score( mseq1, mseq2, effarr1, effarr2, clus1, clus2, length, &tmpdouble ); // gappick mae denaito dame
 					}
-					oimpmatch = 0.0;
+					oimpmatchdouble = 0.0;
 				}
 
 
 //				fprintf( stderr, "#### tmpdouble = %f\n", tmpdouble );
-				mscore = (double)oimpmatch + tmpdouble;
+				mscore = oimpmatchdouble + tmpdouble;
 			}
 			else
 			{
@@ -968,7 +970,7 @@ static void *athread( void *arg )
 //						else
 //							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 						chudanres = 0;
-						Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
+						Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
 //						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						if( chudanres && parallelizationstrategy == BAATARI2 )
 						{
@@ -984,7 +986,7 @@ static void *athread( void *arg )
 				}
 				else if( use_fft )
 				{
-					float totalwm;
+					double totalwm;
 					chudanres = 0;
 //					totalwm = Falign( smalldistmtx, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
 #if MCD
@@ -1049,7 +1051,7 @@ static void *athread( void *arg )
 						intergroup_score( mseq1, mseq2, effarr1, effarr2, clus1, clus2, length, &tmpdouble );
 #endif
 
-						tscore = impmatch + tmpdouble;
+						tscore = impmatchdouble + tmpdouble;
 
 //						fprintf( stderr, "tmpdouble=%f, impmatch = %f -> %f, tscore = %f\n", tmpdouble, oimpmatch, impmatch, tscore );
 					}
@@ -1225,14 +1227,14 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	static int *branchnode = NULL;
 	static double **branchWeight = NULL;
 	static char **mseq1, **mseq2;
-	static float ***history;
+	static double ***history;
 	FILE *trap;
 	double tscore, mscore;
 	int identity;
 	int converged;
 	int oscillating;
-//	float naivescore0 = 0.0; // by D.Mathog, a guess
-//	float naivescore1;
+//	double naivescore0 = 0.0; // by D.Mathog, a guess
+//	double naivescore1;
 #if 0
 	char pair[njob][njob];
 #else
@@ -1246,7 +1248,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 #endif
 	static char *indication1, *indication2;
 	static LocalHom ***localhomshrink = NULL;
-	float impmatch = 0.0, oimpmatch = 0.0;
+	double impmatchdouble = 0.0;
+	double oimpmatchdouble = 0.0;
 	static int *gapmap1;
 	static int *gapmap2;
 	double tmpdouble;
@@ -1382,10 +1385,10 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		int jobposint;
 		int generationofmastercopy;
 		int subgeneration;
-		float basegain;
+		double basegain;
 		int *generationofinput;
-		float *gainlist;
-		float *tscorelist;
+		double *gainlist;
+		double *tscorelist;
 		int ndone;
 		int ntry;
 		int collecting;
@@ -1393,7 +1396,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		int maxiter;
 		char ***candidates;
 		int *branchtable;
-		float **tscorehistory_detail;
+		double **tscorehistory_detail;
 		int finish;
 
 		nwa = nthread + 1;
@@ -1406,8 +1409,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		pthread_cond_init( &collection_end, NULL );
 		pthread_cond_init( &collection_start, NULL );
 
-		gainlist = calloc( nwa, sizeof( float ) );
-		tscorelist = calloc( nwa, sizeof( float ) );
+		gainlist = calloc( nwa, sizeof( double ) );
+		tscorelist = calloc( nwa, sizeof( double ) );
 		branchtable = calloc( nbranch, sizeof( int ) );
 		generationofinput = calloc( nbranch, sizeof( int ) );
 		if( parallelizationstrategy == BESTFIRST )
@@ -1723,8 +1726,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					{
 //						clus1 = conjuctionfortbfast( pair[0], s1, aseq, mseq1, effarr1, effarr, indication1 );
 //						clus2 = conjuctionfortbfast( pair[1], s2, aseq, mseq2, effarr2, effarr, indication2 );
-						clus1 = fastconjuction_noname( memlist[0], aseq, mseq1, effarr1, effarr, indication1 );
-						clus2 = fastconjuction_noname( memlist[1], aseq, mseq2, effarr2, effarr, indication2 );
+						clus1 = fastconjuction_noname( memlist[0], aseq, mseq1, effarr1, effarr, indication1, minimumweight ); // 2015/Apr/18
+						clus2 = fastconjuction_noname( memlist[1], aseq, mseq2, effarr2, effarr, indication2, minimumweight ); // 2015/Apr/18
 					}
 	
 	
@@ -1759,7 +1762,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 						{
 //							msshrinklocalhom( pair[0], pair[1], s1, s2, localhomtable, localhomshrink );
 							msshrinklocalhom_fast( memlist[0], memlist[1], localhomtable, localhomshrink );
-							oimpmatch = 0.0;
+							oimpmatchdouble = 0.0;
 							if( use_fft )
 							{
 								if( alg == 'Q' )
@@ -1771,7 +1774,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 								{
 									part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 									if( rnakozo ) part_imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-									for(  i=length-1; i>=0; i-- ) oimpmatch += part_imp_match_out_sc( i, i );
+									for(  i=length-1; i>=0; i-- ) oimpmatchdouble += (double)part_imp_match_out_sc( i, i );
 								}
 							}
 							else
@@ -1792,7 +1795,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 						}
 						else
 						{
-							oimpmatch = 0.0;
+							oimpmatchdouble = 0.0;
 						}
 #if 0
 						tmpdouble = 0.0;
@@ -1827,7 +1830,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							iu++;
 						}
 #endif
-						mscore = oimpmatch + tmpdouble;
+						mscore = oimpmatchdouble + tmpdouble;
 					}
 					else if( score_check )
 					{
@@ -1841,7 +1844,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 //							shrinklocalhom( pair, s1, s2, localhomtable, localhomshrink );
 							msshrinklocalhom_fast( memlist[0], memlist[1], localhomtable, localhomshrink );
 		//					weightimportance4( clus1, clus2,  effarr1, effarr2, localhomshrink ); // >>>
-							oimpmatch = 0.0;
+							oimpmatchdouble = 0.0;
 							if( use_fft )
 							{
 								if( alg == 'Q' )
@@ -1855,7 +1858,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 									if( rnakozo ) part_imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
 									for(  i=length-1; i>=0; i-- )
 									{
-										oimpmatch += part_imp_match_out_sc( i, i );
+										oimpmatchdouble += (double)part_imp_match_out_sc( i, i );
 		//								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
 									}
 								}
@@ -1877,7 +1880,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	
 									for(  i=length-1; i>=0; i-- )
 									{
-										oimpmatch += imp_match_out_sc( i, i );
+										oimpmatchdouble += (double)imp_match_out_sc( i, i );
 		//								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
 									}
 								}
@@ -1900,12 +1903,12 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 								else
 									intergroup_score( mseq1, mseq2, effarr1, effarr2, clus1, clus2, length, &tmpdouble ); // gappick mae denaito dame
 							}
-							oimpmatch = 0.0;
+							oimpmatchdouble = 0.0;
 						}
 	
 	
 	//					fprintf( stderr, "#### tmpdouble = %f\n", tmpdouble );
-						mscore = (double)oimpmatch + tmpdouble;
+						mscore = oimpmatchdouble + tmpdouble;
 					}
 					else
 					{
@@ -1917,7 +1920,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	
 						if( constraint )
 						{
-							oimpmatch = 0.0;
+							oimpmatchdouble = 0.0;
 //							shrinklocalhom( pair, s1, s2, localhomtable, localhomshrink );
 							msshrinklocalhom_fast( memlist[0], memlist[1], localhomtable, localhomshrink );
 							if( use_fft )
@@ -2019,7 +2022,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	//							part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
 	//						else
 	//							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
-							Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, NULL, 0, NULL );
+							Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, NULL, 0, NULL );
 	//						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						}
 						else
@@ -2030,7 +2033,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					}
 					else if( use_fft )
 					{
-						float totalwm;
+						double totalwm;
 #if MCD
 						totalwm = Falign( offsetmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, NULL, 0, NULL );
 #else
@@ -2095,7 +2098,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 								intergroup_score( mseq1, mseq2, effarr1, effarr2, clus1, clus2, length, &tmpdouble );
 	#endif
 	
-								tscore = impmatch + tmpdouble;
+								tscore = impmatchdouble + tmpdouble;
 	
 	//							fprintf( stderr, "tmpdouble=%f, impmatch = %f -> %f, tscore = %f\n", tmpdouble, oimpmatch, impmatch, tscore );
 							}
@@ -2179,7 +2182,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					fprintf( stderr, "\r" );
 	
 	
-					history[iterate][l][k] = (float)tscore;
+					history[iterate][l][k] = (double)tscore;
 	
 	//				fprintf( stderr, "tscore = %f\n", tscore );
 		
@@ -2205,7 +2208,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 						oscillating = 0;
 						for( ii=iterate-2; ii>=0; ii-=2 ) 
 						{
-							if( (float)tscore == history[ii][l][k] )
+							if( (double)tscore == history[ii][l][k] )
 							{
 								oscillating = 1;
 								break;
